## Nikon Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0001 | MakerNoteVersion | undef[4] |
> 0x0002 | ISO | int16u[2] |
> 0x0003 | ColorMode | string |
> 0x0004 | Quality | string |
> 0x0005 | WhiteBalance | string |
> 0x0006 | Sharpness | string |
> 0x0007 | FocusMode | string |
> 0x0008 | FlashSetting | string |
> 0x0009 | FlashType | string |
> 0x000b | WhiteBalanceFineTune | int16s[n] |
> 0x000c | WB_RBLevels | rational64u[4] |
> 0x000d | ProgramShift | undef[4] |
> 0x000e | ExposureDifference | undef[4] |
> 0x000f | ISOSelection | string |
> 0x0010 | DataDump | no |
> 0x0011 | PreviewIFD | - | --> Nikon PreviewIFD Tags
> 0x0012 | FlashExposureComp | undef[4] | (may be set even if flash does not fire. Does not include the effect of flash bracketing.)
> 0x0013 | ISOSetting | int16u[2] |
> 0x0014 | ColorBalanceA NRWData | - - | --> Nikon ColorBalanceA Tags --> Nikon ColorBalanceB Tags --> Nikon ColorBalanceC Tags
> 0x0016 | ImageBoundary | int16u[4] |
> 0x0017 | ExternalFlashExposureComp | undef[4] |
> 0x0018 | FlashExposureBracketValue | undef[4] |
> 0x0019 | ExposureBracketValue | rational64s |
> 0x001a | ImageProcessing | string |
> 0x001b | CropHiSpeed | int16u[7] |
> 0 = Off 1 = 1.3x Crop 2 = DX Crop 3 = 5:4 Crop 4 = 3:2 Crop 6 = 16:9 Crop 8 = 2.7x Crop 9 = DX Movie Crop |  | 10 = 1.3x Movie Crop 11 = FX Uncropped 12 = DX Uncropped 13 = 2.8x Movie Crop 14 = 1.4x Movie Crop 15 = 1.5x Movie Crop 17 = 1:1 Crop
> 0x001c | ExposureTuning | undef[3] |
> 0x001d | SerialNumber | string! | (this value is used as a key to decrypt other information -- writing this tag causes the other information to be re-encrypted with the new key)
> 0x001e | ColorSpace | int16u | 1 = sRGB 2 = Adobe RGB 4 = BT.2100
> 0x001f | VRInfo | - | --> Nikon VRInfo Tags
> 0x0020 | ImageAuthentication | int8u | 0 = Off 1 = On
> 0x0021 | FaceDetect | - | --> Nikon FaceDetect Tags
> 0x0022 | ActiveD-Lighting | int16u |
> 0 = Off 1 = Low 3 = Normal 5 = High 7 = Extra High |  | 8 = Extra High 1 9 = Extra High 2 10 = Extra High 3 11 = Extra High 4 65535 = Auto
> 0x0023 | PictureControlData | undef!^ | --> Nikon PictureControl Tags --> Nikon PictureControl2 Tags --> Nikon PictureControl3 Tags --> Nikon PictureControlUnknown Tags
> 0x0024 | WorldTime | - | --> Nikon WorldTime Tags
> 0x0025 | ISOInfo | - | --> Nikon ISOInfo Tags
> 0x002a | VignetteControl | int16u | 0 = Off 1 = Low 3 = Normal 5 = High
> 0x002b | DistortInfo | - | --> Nikon DistortInfo Tags
> 0x002c | UnknownInfo | - | --> Nikon UnknownInfo Tags
> 0x0032 | UnknownInfo2 | - | --> Nikon UnknownInfo2 Tags
> 0x0034 | ShutterMode | int16u |
> 0 = Mechanical 16 = Electronic 48 = Electronic Front Curtain 64 = Electronic (Movie) 80 = Auto (Mechanical) 81 = Auto (Electronic Front Curtain) 96 = Electronic (High Speed)
> 0x0035 | HDRInfo HDRInfo2 | - - | --> Nikon HDRInfo Tags --> Nikon HDRInfo2 Tags
> 0x0037 | MechanicalShutterCount | int32u |
> 0x0039 | LocationInfo | - | --> Nikon LocationInfo Tags
> 0x003d | BlackLevel | int16u[4] |
> 0x003e | ImageSizeRAW | yes | 1 = Large 2 = Medium 3 = Small
> 0x003f | WhiteBalanceFineTune | rational64s[2] |
> 0x0044 | JPGCompression | yes | 1 = Size Priority 3 = Optimal Quality
> 0x0045 | CropArea | int16u[4] | (left, top, width, height)
> 0x004e | NikonSettings | undef!^ | --> NikonSettings Tags
> 0x004f | ColorTemperatureAuto | int16u |
> 0x0080 | ImageAdjustment | string |
> 0x0081 | ToneComp | string |
> 0x0082 | AuxiliaryLens | string |
> 0x0083 | LensType | int8u | Bit 0 = MF Bit 1 = D Bit 2 = G Bit 3 = VR Bit 4 = 1 Bit 5 = FT-1 Bit 6 = E Bit 7 = AF-P
> 0x0084 | Lens | rational64u[4] |
> 0x0085 | ManualFocusDistance | rational64u |
> 0x0086 | DigitalZoom | rational64u |
> 0x0087 | FlashMode | int8u |
> 0 = Did Not Fire 1 = Fired, Manual 3 = Not Ready 7 = Fired, External 8 = Fired, Commander Mode 9 = Fired, TTL Mode 18 = LED Light
> 0x0088 | AFInfo | - | --> Nikon AFInfo Tags --> Nikon AFInfo Tags
> 0x0089 | ShootingMode | int16u~ | (for the D70, Bit 5 = Unused LE-NR Slowdown) Bit 0 = Continuous Bit 1 = Delay Bit 2 = PC Control Bit 3 = Self-timer Bit 4 = Exposure Bracketing Bit 5 = Auto ISO Bit 6 = White-Balance Bracketing Bit 7 = IR Control Bit 8 = D-Lighting Bracketing Bit 11 = Pre-capture
> 0x008b | LensFStops | undef[4] |
> 0x008c | ContrastCurve | undef! |
> 0x008d | ColorHue | string |
> 0x008f | SceneMode | string |
> 0x0090 | LightSource | string |
> 0x0091 | ShotInfoD40 ShotInfoD80 ShotInfoD90 ShotInfoD3a ShotInfoD3b ShotInfoD3X ShotInfoD3S ShotInfoD300a ShotInfoD300b ShotInfoD300S ShotInfoD700 ShotInfoD780 ShotInfoD7500 ShotInfoD800 ShotInfoD810 ShotInfoD850 ShotInfoD5000 ShotInfoD5100 ShotInfoD5200 ShotInfoD7000 ShotInfoD4 ShotInfoD4S ShotInfoD500 ShotInfoD6 ShotInfoD610 ShotInfoZ7II ShotInfoZ8 ShotInfoZ9 ShotInfo02xx ShotInfoUnknown | - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - | --> Nikon ShotInfoD40 Tags --> Nikon ShotInfoD80 Tags --> Nikon ShotInfoD90 Tags --> Nikon ShotInfoD3a Tags --> Nikon ShotInfoD3b Tags --> Nikon ShotInfoD3X Tags --> Nikon ShotInfoD3S Tags --> Nikon ShotInfoD300a Tags --> Nikon ShotInfoD300b Tags --> Nikon ShotInfoD300S Tags --> Nikon ShotInfoD700 Tags --> Nikon ShotInfoD780 Tags --> Nikon ShotInfoD7500 Tags --> Nikon ShotInfoD800 Tags --> Nikon ShotInfoD810 Tags --> Nikon ShotInfoD850 Tags --> Nikon ShotInfoD5000 Tags --> Nikon ShotInfoD5100 Tags --> Nikon ShotInfoD5200 Tags --> Nikon ShotInfoD7000 Tags --> Nikon ShotInfoD4 Tags --> Nikon ShotInfoD4S Tags --> Nikon ShotInfoD500 Tags --> Nikon ShotInfoD6 Tags --> Nikon ShotInfoD610 Tags --> Nikon ShotInfoZ7II Tags --> Nikon ShotInfoZ8 Tags --> Nikon ShotInfoZ9 Tags --> Nikon ShotInfo Tags --> Nikon ShotInfo Tags
> 0x0092 | HueAdjustment | int16s |
> 0x0093 | NEFCompression | int16u | --> Nikon NEFCompression Values
> 0x0094 | SaturationAdj | int16s |
> 0x0095 | NoiseReduction | string |
> 0x0096 | NEFLinearizationTable | undef! |
> 0x0097 | ColorBalance0100 ColorBalance0102 ColorBalance0103 ColorBalance0205 ColorBalance0209 ColorBalance02 ColorBalance0211 ColorBalance0213 ColorBalance0215 ColorBalance0219 ColorBalanceUnknown1 ColorBalanceUnknown2 ColorBalanceUnknown | - - - - - - - - - - - - - | --> Nikon ColorBalance1 Tags --> Nikon ColorBalance2 Tags --> Nikon ColorBalance3 Tags --> Nikon ColorBalance2 Tags --> Nikon ColorBalance4 Tags --> Nikon ColorBalance2 Tags --> Nikon ColorBalance4 Tags --> Nikon ColorBalance2 Tags --> Nikon ColorBalance4 Tags --> Nikon ColorBalance2 Tags --> Nikon ColorBalanceUnknown Tags --> Nikon ColorBalanceUnknown2 Tags --> Nikon ColorBalanceUnknown Tags
> 0x0098 | LensData0100 LensData0101 LensData0201 LensData0204 LensData0400 LensData0402 LensData0403 LensData0800 LensDataUnknown | - - - - - - - - - | --> Nikon LensData00 Tags --> Nikon LensData01 Tags --> Nikon LensData01 Tags --> Nikon LensData0204 Tags --> Nikon LensData0400 Tags --> Nikon LensData0402 Tags --> Nikon LensData0403 Tags --> Nikon LensData0800 Tags --> Nikon LensDataUnknown Tags
> 0x0099 | RawImageCenter | int16u[2] |
> 0x009a | SensorPixelSize | rational64u[2] |
> 0x009c | SceneAssist | string |
> 0x009d | DateStampMode | int16u | (feature to imprint date/time on image) 0 = Off 1 = Date & Time 2 = Date 3 = Date Counter
> 0x009e | RetouchHistory | int16u[10] | [Values 0-9]
> 0 = None 3 = B & W 4 = Sepia 5 = Trim 6 = Small Picture 7 = D-Lighting 8 = Red Eye 9 = Cyanotype 10 = Sky Light 11 = Warm Tone 12 = Color Custom 13 = Image Overlay 14 = Red Intensifier 15 = Green Intensifier 16 = Blue Intensifier 17 = Cross Screen 18 = Quick Retouch 19 = NEF Processing 23 = Distortion Control 25 = Fisheye 26 = Straighten 29 = Perspective Control |  | 30 = Color Outline 31 = Soft Filter 32 = Resize 33 = Miniature Effect 34 = Skin Softening 35 = Selected Frame 37 = Color Sketch 38 = Selective Color 39 = Glamour 40 = Drawing 44 = Pop 45 = Toy Camera Effect 1 46 = Toy Camera Effect 2 47 = Cross Process (red) 48 = Cross Process (blue) 49 = Cross Process (green) 50 = Cross Process (yellow) 51 = Super Vivid 52 = High-contrast Monochrome 53 = High Key 54 = Low Key
> 0x00a0 | SerialNumber | string |
> 0x00a2 | ImageDataSize | int32u |
> 0x00a5 | ImageCount | int32u |
> 0x00a6 | DeletedImageCount | int32u |
> 0x00a7 | ShutterCount | int32u! | (includes both mechanical and electronic shutter activations for models with this feature. This value is used as a key to decrypt other information, and writing this tag causes the other information to be re-encrypted with the new key)
> 0x00a8 | FlashInfo0100 FlashInfo0102 FlashInfo0103 FlashInfo0106 FlashInfo0107 FlashInfo0300 FlashInfoUnknown | - - - - - - - | --> Nikon FlashInfo0100 Tags --> Nikon FlashInfo0102 Tags --> Nikon FlashInfo0103 Tags --> Nikon FlashInfo0106 Tags --> Nikon FlashInfo0107 Tags --> Nikon FlashInfo0300 Tags --> Nikon FlashInfoUnknown Tags
> 0x00a9 | ImageOptimization | string |
> 0x00aa | Saturation | string |
> 0x00ab | VariProgram | string |
> 0x00ac | ImageStabilization | string |
> 0x00ad | AFResponse | string |
> 0x00b0 | MultiExposure MultiExposure2 | - - | --> Nikon MultiExposure Tags --> Nikon MultiExposure Tags --> Nikon MultiExposure2 Tags
> 0x00b1 | HighISONoiseReduction | int16u |
> 0 = Off 1 = Minimal 2 = Low 3 = Medium Low |  | 4 = Normal 5 = Medium High 6 = High
> 0x00b3 | ToningEffect | string |
> 0x00b6 | PowerUpTime | undef | (date/time when camera was last powered up)
> 0x00b7 | AFInfo2 | - | --> Nikon AFInfo2V0400 Tags --> Nikon AFInfo2 Tags
> 0x00b8 | FileInfo | - | --> Nikon FileInfo Tags --> Nikon FileInfo Tags
> 0x00b9 | AFTune | - | --> Nikon AFTune Tags
> 0x00bb | RetouchInfo | - | --> Nikon RetouchInfo Tags
> 0x00bd | PictureControlData | undef!^ | --> Nikon PictureControl Tags
> 0x00bf | SilentPhotography | yes | 0 = Off 1 = On
> 0x00c3 | BarometerInfo | - | --> Nikon BarometerInfo Tags
> 0x0e00 | PrintIM | - | --> PrintIM Tags
> 0x0e01 | NikonCaptureData | undef!^ | --> NikonCapture Tags (this data is dropped when copying Nikon MakerNotes since it may be too large to fit in the EXIF segment of a JPEG image, but it may be copied as a block into existing Nikon MakerNotes later if desired)
> 0x0e09 | NikonCaptureVersion | string^ |
> 0x0e0e | NikonCaptureOffsets | undef^ | --> Nikon CaptureOffsets Tags
> 0x0e10 | NikonScanIFD | - | --> Nikon Scan Tags
> 0x0e13 | NikonCaptureEditVersions NikonCaptureEditVersions | undef^ undef!^ | (the ExtractEmbedded option may be used to decode settings from the stored edit versions, otherwise this is extracted as a binary data block) --> NikonCapture Tags
> 0x0e1d | NikonICCProfile | undef! | --> ICC_Profile Tags
> 0x0e1e | NikonCaptureOutput | undef!^ | --> Nikon CaptureOutput Tags
> 0x0e22 | NEFBitDepth | int16u[4]! | '0 0 0 0' = n/a (JPEG) '8 8 8 0' = 8 x 3 '12 0 0 0' = 12 '14 0 0 0' = 14 '16 16 16 0' = 16 x 3

## Nikon NEFCompression Values

> Value | NEFCompression | Value | NEFCompression
> --- | --- | --- | ---
> 1 | = Lossy (type 1) | 7 | = Unpacked 12 bits
> 2 | = Uncompressed | 8 | = Small
> 3 | = Lossless | 9 | = Packed 12 bits
> 4 | = Lossy (type 2) | 10 | = Packed 14 bits
> 5 | = Striped packed 12 bits | 13 | = High Efficiency
> 6 | = Uncompressed (reduced to 12 bit) | 14 | = High Efficiency*

## Nikon ast Tags

Tags used by Nikon NX Studio in Nikon NKSC sidecar files and trailers.

These tags belong to the ExifTool XMP-ast family 1 group.

> Tag Name | Writable | Values / Notes
> --- | --- | ---
> About | no |
> GPSAltitude | no |
> GPSAltitudeRef | no | 0 = Above Sea Level 1 = Below Sea Level
> GPSImgDirection | no |
> GPSImgDirectionRef | no | 'M' = Magnetic North 'T' = True North
> GPSLatitude | no |
> GPSLatitudeRef | no | 0 = North 1 = South
> GPSLongitude | no |
> GPSLongitudeRef | no | 2 = East 3 = West
> GPSMapDatum | no |
> GPSVersionID | no |
> IPTC | - | --> IPTC Tags
> Version | no |
> XMLPackets | - | --> XMP Tags

## Nikon nine Tags

These tags belong to the ExifTool XMP-nine family 1 group.

> Tag Name | Writable | Values / Notes
> --- | --- | ---
> About | no |
> Label | no |
> NineEdits | - | --> Nikon NineEdits Tags
> Rating | no |
> Trim | no |
> Version | no |

## Nikon NineEdits Tags

XML-based tags used to store editing information.

> Tag Name | Writable | Values / Notes
> --- | --- | ---
> FilterParametersBinary | no |
> FilterParametersCustomCustomData | no |
> FilterParametersExportExportData | no |

## Nikon sdc Tags

These tags belong to the ExifTool XMP-sdc family 1 group.

> Tag Name | Writable | Values / Notes
> --- | --- | ---
> About | no |
> AppName | no |
> AppVersion | no |
> Version | no |

## Nikon PreviewIFD Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x00fe | SubfileType | no | 0x0 = Full-resolution image 0x1 = Reduced-resolution image 0x2 = Single page of multi-page image 0x3 = Single page of multi-page reduced-resolution image 0x4 = Transparency mask 0x5 = Transparency mask of reduced-resolution image 0x6 = Transparency mask of multi-page image 0x7 = Transparency mask of reduced-resolution multi-page image 0x8 = Depth map 0x9 = Depth map of reduced-resolution image 0x10 = Enhanced image data 0x10001 = Alternate reduced-resolution image 0x10004 = Semantic Mask 0xffffffff = invalid Bit 0 = Reduced resolution Bit 1 = Single page Bit 2 = Transparency mask Bit 3 = TIFF/IT final page Bit 4 = TIFF-FX mixed raster content
> 0x0103 | Compression | no | --> EXIF Compression Values
> 0x011a | XResolution | no |
> 0x011b | YResolution | no |
> 0x0128 | ResolutionUnit | no | 1 = None 2 = inches 3 = cm
> 0x0201 | PreviewImageStart | int32u* |
> 0x0202 | PreviewImageLength | int32u* |
> 0x0213 | YCbCrPositioning | no | 1 = Centered 2 = Co-sited

## Nikon ColorBalanceA Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 624 | WB_RBLevels | int16u[2]! | (as shot)
> 626 | WB_RBLevelsAuto | int16u[2]! |
> 628 | WB_RBLevelsDaylight | int16u[14]! | (red/blue levels for 0,+3,+2,+1,-1,-2,-3)
> 642 | WB_RBLevelsIncandescent | int16u[14]! |
> 656 | WB_RBLevelsFluorescent | int16u[6]! | (red/blue levels for fluorescent W,N,D)
> 662 | WB_RBLevelsCloudy | int16u[14]! |
> 676 | WB_RBLevelsFlash | int16u[14]! |
> 690 | WB_RBLevelsShade | int16u[14]! | (not valid for E8700)

## Nikon ColorBalanceB Tags

Color balance tags used by the P6000.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 4 | ColorBalanceVersion | undef[4] |
> 5096 | WB_RGGBLevels | int32u[4]! |
> 5112 | WB_RGGBLevelsDaylight | int32u[4]! |
> 5128 | WB_RGGBLevelsCloudy | int32u[4]! |
> 5160 | WB_RGGBLevelsTungsten | int32u[4]! |
> 5176 | WB_RGGBLevelsFluorescentW | int32u[4]! |
> 5192 | WB_RGGBLevelsFlash | int32u[4]! |
> 5224 | WB_RGGBLevelsCustom | int32u[4]! | (all zero if preset WB not used)
> 5240 | WB_RGGBLevelsAuto | int32u[4]! |

## Nikon ColorBalanceC Tags

Color balance tags used by the P1000, P7000, P7100 and B700.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 4 | ColorBalanceVersion | undef[4] |
> 32 | BlackLevel | int16u |
> 56 | WB_RGGBLevels | int32u[4]! |
> 76 | WB_RGGBLevelsDaylight | int32u[4]! |
> 96 | WB_RGGBLevelsCloudy | int32u[4]! |
> 116 | WB_RGGBLevelsShade | int32u[4]! | (valid only for some models)
> 136 | WB_RGGBLevelsTungsten | int32u[4]! |
> 156 | WB_RGGBLevelsFluorescentW | int32u[4]! |
> 176 | WB_RGGBLevelsFluorescentN | int32u[4]! |
> 196 | WB_RGGBLevelsFluorescentD | int32u[4]! |
> 216 | WB_RGGBLevelsHTMercury | int32u[4]! |
> 256 | WB_RGGBLevelsCustom | int32u[4]! | (all zero if preset WB not used)
> 276 | WB_RGGBLevelsAuto | int32u[4]! |

## Nikon VRInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | VRInfoVersion | no |
> 4 | VibrationReduction | int8u | 0 = n/a 1 = On 2 = Off
> 6 | VRMode | int8u | (Z Series cameras thru October 2023) 0 = Off 1 = Normal 3 = Sport 0 = Normal 1 = On (1) 2 = Active 3 = Sport
> 8 | VRType | int8u | 2 = In-body 3 = In-body + Lens

## Nikon FaceDetect Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 1 | FaceDetectFrameSize | int16u[2] |
> 3 | FacesDetected | int16u |
> 4 | Face1Position | int16u[4] | (top, left, width and height of face detect area in coordinates of FaceDetectFrameSize)
> 8 | Face2Position | int16u[4] |
> 12 | Face3Position | int16u[4] |
> 16 | Face4Position | int16u[4] |
> 20 | Face5Position | int16u[4] |
> 24 | Face6Position | int16u[4] |
> 28 | Face7Position | int16u[4] |
> 32 | Face8Position | int16u[4] |
> 36 | Face9Position | int16u[4] |
> 40 | Face10Position | int16u[4] |
> 44 | Face11Position | int16u[4] |
> 48 | Face12Position | int16u[4] |

## Nikon PictureControl Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | PictureControlVersion | no |
> 4 | PictureControlName | string[20] |
> 24 | PictureControlBase | string[20] |
> 48 | PictureControlAdjust | int8u | 0 = Default Settings 1 = Quick Adjust 2 = Full Control
> 49 | PictureControlQuickAdjust | int8u |
> 50 | Sharpness | int8u |
> 51 | Contrast | int8u |
> 52 | Brightness | int8u |
> 53 | Saturation | int8u |
> 54 | HueAdjustment | int8u |
> 55 | FilterEffect | int8u |
> 0x80 = Off 0x81 = Yellow 0x82 = Orange |  | 0x83 = Red 0x84 = Green 0xff = n/a
> 56 | ToningEffect | int8u |
> 0x80 = B&W 0x81 = Sepia 0x82 = Cyanotype 0x83 = Red 0x84 = Yellow 0x85 = Green |  | 0x86 = Blue-green 0x87 = Blue 0x88 = Purple-blue 0x89 = Red-purple 0xff = n/a
> 57 | ToningSaturation | int8u |

## Nikon PictureControl2 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | PictureControlVersion | no |
> 4 | PictureControlName | string[20] |
> 24 | PictureControlBase | string[20] |
> 48 | PictureControlAdjust | int8u | 0 = Default Settings 1 = Quick Adjust 2 = Full Control
> 49 | PictureControlQuickAdjust | int8u |
> 51 | Sharpness | int8u |
> 53 | Clarity | int8u |
> 55 | Contrast | int8u |
> 57 | Brightness | int8u |
> 59 | Saturation | int8u |
> 61 | Hue | int8u |
> 63 | FilterEffect | int8u |
> 0x80 = Off 0x81 = Yellow 0x82 = Orange |  | 0x83 = Red 0x84 = Green 0xff = n/a
> 64 | ToningEffect | int8u |
> 0x80 = B&W 0x81 = Sepia 0x82 = Cyanotype 0x83 = Red 0x84 = Yellow 0x85 = Green |  | 0x86 = Blue-green 0x87 = Blue 0x88 = Purple-blue 0x89 = Red-purple 0xff = n/a
> 65 | ToningSaturation | int8u |

## Nikon PictureControl3 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | PictureControlVersion | no |
> 8 | PictureControlName | string[20] |
> 28 | PictureControlBase | string[20] |
> 54 | PictureControlAdjust | int8u | 0 = Default Settings 1 = Quick Adjust 2 = Full Control
> 55 | PictureControlQuickAdjust | int8u |
> 57 | Sharpness | int8u |
> 59 | MidRangeSharpness | int8u |
> 61 | Clarity | int8u |
> 63 | Contrast | int8u |
> 65 | Brightness | int8u |
> 67 | Saturation | int8u |
> 69 | Hue | int8u |
> 71 | FilterEffect | int8u |
> 0x80 = Off 0x81 = Yellow 0x82 = Orange |  | 0x83 = Red 0x84 = Green 0xff = n/a
> 72 | ToningEffect | int8u |
> 0x80 = B&W 0x81 = Sepia 0x82 = Cyanotype 0x83 = Red 0x84 = Yellow 0x85 = Green |  | 0x86 = Blue-green 0x87 = Blue 0x88 = Purple-blue 0x89 = Red-purple 0xff = n/a
> 73 | ToningSaturation | int8u |

## Nikon PictureControlUnknown Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | PictureControlVersion | no |

## Nikon WorldTime Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | TimeZone | int16s |
> 2 | DaylightSavings | int8u | 0 = No 1 = Yes
> 3 | DateDisplayFormat | int8u | 0 = Y/M/D 1 = M/D/Y 2 = D/M/Y

## Nikon ISOInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ISO | int8u | (val = 100 * 2**(raw/12-5))
> 4 | ISOExpansion | int16u |
> 0x0 = Off 0x101 = Hi 0.3 0x102 = Hi 0.5 0x103 = Hi 0.7 0x104 = Hi 1.0 0x105 = Hi 1.3 0x106 = Hi 1.5 0x107 = Hi 1.7 0x108 = Hi 2.0 0x109 = Hi 2.3 0x10a = Hi 2.5 0x10b = Hi 2.7 0x10c = Hi 3.0 |  | 0x10d = Hi 3.3 0x10e = Hi 3.5 0x10f = Hi 3.7 0x110 = Hi 4.0 0x111 = Hi 4.3 0x112 = Hi 4.5 0x113 = Hi 4.7 0x114 = Hi 5.0 0x201 = Lo 0.3 0x202 = Lo 0.5 0x203 = Lo 0.7 0x204 = Lo 1.0
> 6 | ISO2 | int8u | (val = 100 * 2**(raw/12-5))
> 10 | ISOExpansion2 | int16u |
> 0x0 = Off 0x101 = Hi 0.3 0x102 = Hi 0.5 0x103 = Hi 0.7 0x104 = Hi 1.0 0x105 = Hi 1.3 0x106 = Hi 1.5 |  | 0x107 = Hi 1.7 0x108 = Hi 2.0 0x201 = Lo 0.3 0x202 = Lo 0.5 0x203 = Lo 0.7 0x204 = Lo 1.0

## Nikon DistortInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | DistortionVersion? | no |
> 4 | AutoDistortionControl | int8u | 0 = Off 1 = On 2 = On (underwater)

## Nikon UnknownInfo Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | UnknownInfoVersion? | no |

## Nikon UnknownInfo2 Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | UnknownInfo2Version? | no |

## Nikon HDRInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | HDRInfoVersion | no |
> 4 | HDR | int8u | 0 = Off 1 = On (normal) 48 = Auto
> 5 | HDRLevel | int8u | 0 = Auto 1 = 1 EV 2 = 2 EV 3 = 3 EV 255 = n/a
> 6 | HDRSmoothing | int8u |
> 0 = Off 1 = Normal 2 = Low |  | 3 = High 48 = Auto 255 = n/a
> 7 | HDRLevel2 | int8u | 0 = Auto 1 = 1 EV 2 = 2 EV 3 = 3 EV 255 = n/a

## Nikon HDRInfo2 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | HDRInfoVersion | no |
> 4 | HDR | int8u | 0 = Off 1 = On (normal)
> 5 | HDRLevel | int8u |
> 0 = n/a 1 = Normal 2 = Low |  | 3 = High 4 = High+ 5 = Auto

## Nikon LocationInfo Tags

Tags written by some Nikon GPS-equipped cameras like the AW100.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LocationInfoVersion | undef[4] |
> 4 | TextEncoding | int8u | 0 = n/a 1 = UTF8 2 = UTF16
> 5 | CountryCode | undef[3] |
> 8 | POILevel | int8u |
> 9 | Location | undef[70] |

## Nikon MakerNotes0x51 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FirmwareVersion51 | no |
> 10 | NEFCompression | int16u[0.5] | --> Nikon NEFCompression Values

## Nikon MakerNotes0x56 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FirmwareVersion | no |
> 4 | BurstGroupID | int16u |

## Nikon AFInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | AFAreaMode | int8u |
> 0 = Single Area 1 = Dynamic Area 2 = Dynamic Area (closest subject) 3 = Group Dynamic 4 = Single Area (wide) 5 = Dynamic Area (wide)
> 1 | AFPoint | int8u | (in some focus modes this value is not meaningful)
> 0 = Center 1 = Top 2 = Bottom 3 = Mid-left 4 = Mid-right 5 = Upper-left |  | 6 = Upper-right 7 = Lower-left 8 = Lower-right 9 = Far Left 10 = Far Right
> 2 | AFPointsInFocus | int16u |
> 0x0 = (none) 0x7ff = All 11 Points Bit 0 = Center Bit 1 = Top Bit 2 = Bottom Bit 3 = Mid-left Bit 4 = Mid-right |  | Bit 5 = Upper-left Bit 6 = Upper-right Bit 7 = Lower-left Bit 8 = Lower-right Bit 9 = Far Left Bit 10 = Far Right

## Nikon ShotInfoD40 Tags

These tags are extracted from encrypted data in D40 and D40X images.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 582 | ShutterCount | int32u |
> 586.1 | VibrationReduction | int8u | [val >> 3 & 0x1] 0 = Off 1 = On
> 729 | CustomSettingsD40 | - | --> NikonCustom SettingsD40 Tags

## Nikon ShotInfoD80 Tags

These tags are extracted from encrypted data in D80 images.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 586 | ShutterCount | int32u |
> 590.1 | Rotation | int8u | [val & 0x7] 0 = Horizontal 1 = Rotate 270 CW 2 = Rotate 90 CW 3 = Rotate 180
> 590.2 | VibrationReduction | int8u | [val >> 3 & 0x3] 0 = Off 3 = On
> 590.3 | FlashFired | int8u | [val >> 5 & 0x7] Bit 1 = Internal Bit 2 = External
> 708 | NikonImageSize | int8u | [val >> 4 & 0xf] 0 = Large (10.0 M) 1 = Medium (5.6 M) 2 = Small (2.5 M)
> 708.1 | ImageQuality | int8u | [val & 0xf]
> 0 = NEF (RAW) 1 = JPEG Fine 2 = JPEG Normal 3 = JPEG Basic 4 = NEF (RAW) + JPEG Fine 5 = NEF (RAW) + JPEG Normal 6 = NEF (RAW) + JPEG Basic
> 748 | CustomSettingsD80 | - | --> NikonCustom SettingsD80 Tags

## Nikon ShotInfoD90 Tags

These tags are extracted from encrypted data in images from the D90 with firmware 1.00.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 693 | ISO2 | int8u |
> 725 | ShutterCount | int32u |
> 884 | CustomSettingsD90 | - | --> NikonCustom SettingsD90 Tags

## Nikon ShotInfoD3a Tags

These tags are extracted from encrypted data in images from the D3 with firmware 1.00 and earlier.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 598 | ISO2 | int8u |
> 630 | ShutterCount | int32u |
> 723.1 | NikonImageSize | int8u | [val >> 3 & 0x3] 0 = Large 1 = Medium 2 = Small
> 723.2 | ImageQuality | int8u | [val & 0x7]
> 0 = NEF (RAW) + JPEG Fine 1 = NEF (RAW) + JPEG Norm 2 = NEF (RAW) + JPEG Basic 3 = NEF (RAW) 4 = TIF (RGB) 5 = JPEG Fine 6 = JPEG Normal 7 = JPEG Basic
> 769 | CustomSettingsD3 | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD3b Tags

These tags are extracted from encrypted data in images from the D3 with firmware 1.10, 2.00, 2.01 and 2.02.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 16 | ImageArea | int8u | 0 = FX (36x24) 1 = DX (24x16) 2 = 5:4 (30x24)
> 605 | ISO2 | int8u |
> 637 | ShutterCount | int32u | (firmware 1.10)
> 639 | ShutterCount | int32u | (firmware 2.00, 2.01 and 2.02)
> 650 | PreFlashReturnStrength | int8u | (valid in TTL and TTL-BL flash control modes)
> 732.1 | NikonImageSize | int8u | [val >> 3 & 0x3] 0 = Large 1 = Medium 2 = Small
> 732.2 | ImageQuality | int8u | [val & 0x7]
> 0 = NEF (RAW) + JPEG Fine 1 = NEF (RAW) + JPEG Norm 2 = NEF (RAW) + JPEG Basic 3 = NEF (RAW) 4 = TIF (RGB) 5 = JPEG Fine 6 = JPEG Normal 7 = JPEG Basic
> 778 | CustomSettingsD3 | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD3X Tags

These tags are extracted from encrypted data in images from the D3X with firmware 1.00.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 605 | ISO2 | int8u |
> 640 | ShutterCount | int32u |
> 779 | CustomSettingsD3X | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD3S Tags

These tags are extracted from encrypted data in images from the D3S with firmware 1.00 and earlier.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 16 | ImageArea | int8u | 0 = FX (36x24) 1 = DX (24x16) 2 = 5:4 (30x24) 3 = 1.2x (30x20)
> 545 | ISO2 | int8u |
> 578 | ShutterCount | int32u |
> 671.1 | JPGCompression | int8u | [val >> 6 & 0x1] 0 = Size Priority 1 = Optimal Quality
> 718 | CustomSettingsD3S | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD300a Tags

These tags are extracted from encrypted data in images from the D300 with firmware 1.00 and earlier.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 604 | ISO2 | int8u |
> 633 | ShutterCount | int32u |
> 721 | AFFineTuneAdj | int16u |
> 0x0 = 0 0x3a = +1 0x3b = +2 0x3c = +4 0x3d = +8 0x3e = +16 0xc2 = -16 0xc3 = -8 0xc4 = -4 0xc5 = -2 0xc6 = -1 0x103e = +17 0x10c2 = -17 0x203d = +9 |  | 0x203e = +18 0x20c2 = -18 0x20c3 = -9 0x303e = +19 0x30c2 = -19 0x403c = +5 0x403d = +10 0x403e = +20 0x40c2 = -20 0x40c3 = -10 0x40c4 = -5 0x603d = +11 0x60c3 = -11 0x803b = +3 |  | 0x803c = +6 0x803d = +12 0x80c3 = -12 0x80c4 = -6 0x80c5 = -3 0xa03d = +13 0xa0c3 = -13 0xc03c = +7 0xc03d = +14 0xc0c3 = -14 0xc0c4 = -7 0xe03d = +15 0xe0c3 = -15
> 790 | CustomSettingsD300 | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD300b Tags

These tags are extracted from encrypted data in images from the D300 with firmware 1.10.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 613 | ISO2 | int8u |
> 644 | ShutterCount | int32u |
> 732 | AFFineTuneAdj | int16u | (firmware version 1.10B)
> 0x0 = 0 0x83e = +11 0x8c2 = -11 0x203c = +3 0x203d = +6 0x203e = +12 0x20c2 = -12 0x20c3 = -6 0x20c4 = -3 0x383e = +13 0x38c2 = -13 0x503d = +7 0x503e = +14 0x50c2 = -14 |  | 0x50c3 = -7 0x683e = +15 0x68c2 = -15 0x803a = +1 0x803b = +2 0x803c = +4 0x803d = +8 0x803e = +16 0x80c2 = -16 0x80c3 = -8 0x80c4 = -4 0x80c5 = -2 0x80c6 = -1 0x983e = +17 |  | 0x98c2 = -17 0xb03d = +9 0xb03e = +18 0xb0c2 = -18 0xb0c3 = -9 0xc83e = +19 0xc8c2 = -19 0xe03c = +5 0xe03d = +10 0xe03e = +20 0xe0c2 = -20 0xe0c3 = -10 0xe0c4 = -5
> (other versions)
> 0x0 = 0 0x43e = +13 0x4c2 = -13 0x183d = +7 0x183e = +14 0x18c2 = -14 0x18c3 = -7 0x2c3e = +15 0x2cc2 = -15 0x403a = +1 0x403b = +2 0x403c = +4 0x403d = +8 0x403e = +16 |  | 0x40c2 = -16 0x40c3 = -8 0x40c4 = -4 0x40c5 = -2 0x40c6 = -1 0x543e = +17 0x54c2 = -17 0x683d = +9 0x683e = +18 0x68c2 = -18 0x68c3 = -9 0x7c3e = +19 0x7cc2 = -19 0x903c = +5 |  | 0x903d = +10 0x903e = +20 0x90c2 = -20 0x90c3 = -10 0x90c4 = -5 0xb83d = +11 0xb8c3 = -11 0xe03b = +3 0xe03c = +6 0xe03d = +12 0xe0c3 = -12 0xe0c4 = -6 0xe0c5 = -3
> 802 | CustomSettingsD300 | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD300S Tags

These tags are extracted from encrypted data in images from the D300S with firmware 1.00.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 613 | ISO2 | int8u |
> 646 | ShutterCount | int32u |
> 804 | CustomSettingsD300S | - | --> NikonCustom SettingsD3 Tags

## Nikon ShotInfoD700 Tags

These tags are extracted from encrypted data in images from the D700 with firmware 1.02f.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 613 | ISO2 | int8u |
> 647 | ShutterCount | int32u |
> 804 | CustomSettingsD700 | - | --> NikonCustom SettingsD700 Tags

## Nikon ShotInfoD780 Tags

These tags are extracted from encrypted data in images from the D780.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 156 | OrientOffset | - | --> Nikon OrientationInfo Tags

## Nikon OrientationInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | RollAngle | fixed32u | (converted to degrees of clockwise camera roll)
> 4 | PitchAngle | fixed32u | (converted to degrees of upward camera tilt)
> 8 | YawAngle | fixed32u | (the camera yaw angle when shooting in portrait orientation)

## Nikon ShotInfoD7500 Tags

These tags are extracted from encrypted data in images from the D7500.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 160 | OrientOffset | - | --> Nikon OrientationInfo Tags

## Nikon ShotInfoD800 Tags

These tags are extracted from encrypted data in images from the D800.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 1216 | RepeatingFlashOutputExternal | int8u |
> 1218 | RepeatingFlashRateExternal | int8u |
> 1219 | RepeatingFlashCountExternal | int8u |
> 1234 | FlashExposureComp2 | int8s | (includes the effect of flash bracketing)
> 1242 | RepeatingFlashRateBuilt-in | int8u |
> 1243 | RepeatingFlashCountBuilt-in | int8u |
> 1308 | SequenceNumber | int8u |
> 1531 | ShutterCount | int32u |
> 1772 | CustomSettingsD800 | - | --> NikonCustom SettingsD800 Tags

## Nikon ShotInfoD810 Tags

These tags are extracted from encrypted data in images from the D810.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 16 | SettingsOffset | - | --> Nikon SettingsInfoD810 Tags
> 36 | BracketingOffset | - | --> Nikon BracketingInfoD810 Tags
> 56 | ISOAutoOffset | - | --> Nikon ISOAutoInfoD810 Tags
> 64 | CustomSettingsOffset | - | --> NikonCustom SettingsD810 Tags
> 132 | OrientationOffset | - | --> Nikon OrientationInfo Tags

## Nikon SettingsInfoD810 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 316 | SecondarySlotFunction | int8u | [val & 0x3] 0 = Overflow 2 = Backup 3 = NEF Primary + JPG Secondary

## Nikon BracketingInfoD810 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 15 | AEBracketingSteps | int8u | [val & 0xff]
> 0x0 = AE Bracketing Disabled 0x20 = AE Bracketing Disabled 0x30 = AE Bracketing Disabled 0x40 = AE Bracketing Disabled 0x50 = AE Bracketing Disabled 0x81 = +3F0.3 0x82 = -3F0.3 0x83 = +2F0.3 0x84 = -2F0.3 0x85 = 3F0.3 0x86 = 5F0.3 0x87 = 7F0.3 0x88 = 9F0.3 0x91 = +3F0.5 0x92 = -3F0.5 0x93 = +2F0.5 0x94 = -2F0.5 0x95 = 3F0.5 0x96 = 5F0.5 0x97 = 7F0.5 0x98 = 9F0.5 0xa1 = +3F0.7 0xa2 = -3F0.7 0xa3 = +2F0.7 0xa4 = -2F0.7 |  | 0xa5 = 3F0.7 0xa6 = 5F0.7 0xa7 = 7F0.7 0xa8 = 9F0.7 0xb1 = +3F1 0xb2 = -3F1 0xb3 = +2F1 0xb4 = -2F1 0xb5 = 3F1 0xb6 = 5F1 0xb7 = 7F1 0xb8 = 9F1 0xc1 = +3F2 0xc2 = -3F2 0xc3 = +2F2 0xc4 = -2F2 0xc5 = 3F2 0xc6 = 5F2 0xd1 = +3F3 0xd2 = -3F3 0xd3 = +2F3 0xd4 = -2F3 0xd5 = 3F3 0xd6 = 5F3
> 16 | WBBracketingSteps | int8u | [val & 0xff]
> 0x0 = WB Bracketing Disabled 0x1 = b3F 1 0x2 = A3F 1 0x3 = b2F 1 0x4 = A2F 1 0x5 = 3F 1 0x6 = 5F 1 0x7 = 7F 1 0x8 = 9F 1 0x10 = 0F 2 0x11 = b3F 2 0x12 = A3F 2 0x13 = b2F 2 0x14 = A2F 2 |  | 0x15 = 3F 2 0x16 = 5F 2 0x17 = 7F 2 0x18 = 9F 2 0x20 = 0F 3 0x21 = b3F 3 0x22 = A3F 3 0x23 = b2F 3 0x24 = A2F 3 0x25 = 3F 3 0x26 = 5F 3 0x27 = 7F 3 0x28 = 9F 3
> 23 | NikonMeteringMode | int8u | [val & 0x3] 0 = Matrix 1 = Center 2 = Spot 3 = Highlight

## Nikon ISOAutoInfoD810 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 4 | ISOAutoShutterTime | int8u | [val & 0x3f]
> 0 = 1/4000 s 1 = 1/3200 s 2 = 1/2500 s 3 = 1/2000 s 4 = 1/1600 s 5 = 1/1250 s 6 = 1/1000 s 7 = 1/800 s 8 = 1/640 s 9 = 1/500 s 10 = 1/400 s 11 = 1/320 s 12 = 1/250 s 13 = 1/200 s 14 = 1/160 s 15 = 1/125 s 16 = 1/100 s 17 = 1/80 s 18 = 1/60 s |  | 19 = 1/50 s 20 = 1/40 s 21 = 1/30 s 22 = 1/15 s 23 = 1/8 s 24 = 1/4 s 25 = 1/2 s 26 = 1 s 27 = 2 s 28 = 4 s 29 = 8 s 30 = 15 s 31 = 30 s 32 = Auto (Slowest) 33 = Auto (Slower) 34 = Auto 35 = Auto (Faster) 36 = Auto (Fastest)
> 5 | ISOAutoHiLimit | int8u | [val & 0xff]
> 0x24 = ISO 200 0x26 = ISO 250 0x27 = ISO 280 0x28 = ISO 320 0x2a = ISO 400 0x2c = ISO 500 0x2d = ISO 560 0x2e = ISO 640 0x30 = ISO 800 0x32 = ISO 1000 0x33 = ISO 1100 0x34 = ISO 1250 0x36 = ISO 1600 0x38 = ISO 2000 0x39 = ISO 2200 0x3a = ISO 2500 0x3c = ISO 3200 0x3e = ISO 4000 0x3f = ISO 4500 0x40 = ISO 5000 0x42 = ISO 6400 |  | 0x44 = ISO 8000 0x45 = ISO 9000 0x46 = ISO 10000 0x48 = ISO 12800 0x4a = ISO 16000 0x4b = ISO 18000 0x4c = ISO 20000 0x4e = ISO 25600 0x50 = ISO 32000 0x51 = ISO 36000 0x52 = ISO 40000 0x54 = ISO 51200 0x56 = ISO Hi 0.3 0x57 = ISO Hi 0.5 0x58 = ISO Hi 0.7 0x5a = ISO Hi 1.0 0x60 = ISO Hi 2.0 0x66 = ISO Hi 3.0 0x6c = ISO Hi 4.0 0x72 = ISO Hi 5.0

## Nikon ShotInfoD850 Tags

These tags are extracted from encrypted data in images from the D850.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 16 | MenuSettingsOffset | - | --> Nikon MenuSettingsD850 Tags
> 76 | MoreSettingsOffset | - | --> Nikon MoreSettingsD850 Tags
> 88 | CustomSettingsOffset | - | --> NikonCustom SettingsD850 Tags
> 160 | OrientationOffset | - | --> Nikon OrientationInfo Tags

## Nikon MenuSettingsD850 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 1757 | PhotoShootingMenuBankImageArea | int8u | [val & 0x7] 0 = FX (36x24) 1 = DX (24x16) 2 = 5:4 (30x24) 3 = 1.2x (30x20) 4 = 1:1 (24x24)

## Nikon MoreSettingsD850 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 36 | PhotoShootingMenuBank | int8u | (valid for JPEG images only) [val & 0x3] 0 = A 1 = B 2 = C 3 = D
> 37 | PrimarySlot | int8u | [val >> 7 & 0x1] 0 = XQD Card 1 = SD Card

## Nikon ShotInfoD5000 Tags

These tags are extracted from encrypted data in images from the D5000 with firmware 1.00.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 693 | ISO2 | int8u |
> 726 | ShutterCount | int32u |
> 888 | CustomSettingsD5000 | - | --> NikonCustom SettingsD5000 Tags

## Nikon ShotInfoD5100 Tags

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 801 | ShutterCount | int32u |
> 1031 | CustomSettingsD5100 | - | --> NikonCustom SettingsD5100 Tags

## Nikon ShotInfoD5200 Tags

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 3032 | ShutterCount | int32u |
> 3285 | CustomSettingsD5200 | - | --> NikonCustom SettingsD5200 Tags

## Nikon ShotInfoD7000 Tags

These tags are extracted from encrypted data in images from the D7000 with firmware 1.01b.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 800 | ShutterCount | int32u |
> 1028 | CustomSettingsD7000 | - | --> NikonCustom SettingsD7000 Tags

## Nikon ShotInfoD4 Tags

These tags are extracted from encrypted data in images from the D4.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 1873 | CustomSettingsD4 | - | --> NikonCustom SettingsD4 Tags

## Nikon ShotInfoD4S Tags

These tags are extracted from encrypted data in images from the D4S.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 464 | SecondarySlotFunction | int8u | [val & 0x3] 0 = Overflow 2 = Backup 3 = NEF Primary + JPG Secondary
> 5964 | AEBracketingSteps | int8u | [val & 0xff]
> 0x0 = AE Bracketing Disabled 0x20 = AE Bracketing Disabled 0x30 = AE Bracketing Disabled 0x40 = AE Bracketing Disabled 0x50 = AE Bracketing Disabled 0x81 = +3F0.3 0x82 = -3F0.3 0x83 = +2F0.3 0x84 = -2F0.3 0x85 = 3F0.3 0x86 = 5F0.3 0x87 = 7F0.3 0x88 = 9F0.3 0x91 = +3F0.5 0x92 = -3F0.5 0x93 = +2F0.5 0x94 = -2F0.5 0x95 = 3F0.5 0x96 = 5F0.5 0x97 = 7F0.5 0x98 = 9F0.5 0xa1 = +3F0.7 0xa2 = -3F0.7 0xa3 = +2F0.7 0xa4 = -2F0.7 |  | 0xa5 = 3F0.7 0xa6 = 5F0.7 0xa7 = 7F0.7 0xa8 = 9F0.7 0xb1 = +3F1 0xb2 = -3F1 0xb3 = +2F1 0xb4 = -2F1 0xb5 = 3F1 0xb6 = 5F1 0xb7 = 7F1 0xb8 = 9F1 0xc1 = +3F2 0xc2 = -3F2 0xc3 = +2F2 0xc4 = -2F2 0xc5 = 3F2 0xc6 = 5F2 0xd1 = +3F3 0xd2 = -3F3 0xd3 = +2F3 0xd4 = -2F3 0xd5 = 3F3 0xd6 = 5F3
> 5965 | WBBracketingSteps | int8u | [val & 0xff]
> 0x0 = WB Bracketing Disabled 0x1 = b3F 1 0x2 = A3F 1 0x3 = b2F 1 0x4 = A2F 1 0x5 = 3F 1 0x6 = 5F 1 0x7 = 7F 1 0x8 = 9F 1 0x10 = 0F 2 0x11 = b3F 2 0x12 = A3F 2 0x13 = b2F 2 0x14 = A2F 2 |  | 0x15 = 3F 2 0x16 = 5F 2 0x17 = 7F 2 0x18 = 9F 2 0x20 = 0F 3 0x21 = b3F 3 0x22 = A3F 3 0x23 = b2F 3 0x24 = A2F 3 0x25 = 3F 3 0x26 = 5F 3 0x27 = 7F 3 0x28 = 9F 3
> 6221 | ReleaseMode | int8u | [val & 0xff]
> 0 = Single Frame 1 = Continuous High Speed 3 = Continuous Low Speed 4 = Timer 32 = Mirror-Up 64 = Quiet
> 6301 | CustomSettingsD4S | - | --> NikonCustom SettingsD4 Tags (firmware version 1.00)
> 6338 | MultiSelectorLiveViewMode | int8u | [val >> 6 & 0x3] 0 = Reset 1 = Zoom 3 = None
> 6378 | ISOAutoShutterTime | int8u | [val & 0x3f]
> 0 = 1/4000 s 1 = 1/3200 s 2 = 1/2500 s 3 = 1/2000 s 4 = 1/1600 s 5 = 1/1250 s 6 = 1/1000 s 7 = 1/800 s 8 = 1/640 s 9 = 1/500 s 10 = 1/400 s 11 = 1/320 s 12 = 1/250 s 13 = 1/200 s 14 = 1/160 s 15 = 1/125 s 16 = 1/100 s 17 = 1/80 s 18 = 1/60 s |  | 19 = 1/50 s 20 = 1/40 s 21 = 1/30 s 22 = 1/15 s 23 = 1/8 s 24 = 1/4 s 25 = 1/2 s 26 = 1 s 27 = 2 s 28 = 4 s 29 = 8 s 30 = 15 s 31 = 30 s 32 = Auto (Slowest) 33 = Auto (Slower) 34 = Auto 35 = Auto (Faster) 36 = Auto (Fastest)
> 6379 | ISOAutoHiLimit | int8u | [val & 0xff]
> 0x24 = ISO 200 0x26 = ISO 250 0x27 = ISO 280 0x28 = ISO 320 0x2a = ISO 400 0x2c = ISO 500 0x2d = ISO 560 0x2e = ISO 640 0x30 = ISO 800 0x32 = ISO 1000 0x33 = ISO 1100 0x34 = ISO 1250 0x36 = ISO 1600 0x38 = ISO 2000 0x39 = ISO 2200 0x3a = ISO 2500 0x3c = ISO 3200 0x3e = ISO 4000 0x3f = ISO 4500 0x40 = ISO 5000 0x42 = ISO 6400 |  | 0x44 = ISO 8000 0x45 = ISO 9000 0x46 = ISO 10000 0x48 = ISO 12800 0x4a = ISO 16000 0x4b = ISO 18000 0x4c = ISO 20000 0x4e = ISO 25600 0x50 = ISO 32000 0x51 = ISO 36000 0x52 = ISO 40000 0x54 = ISO 51200 0x56 = ISO Hi 0.3 0x57 = ISO Hi 0.5 0x58 = ISO Hi 0.7 0x5a = ISO Hi 1.0 0x60 = ISO Hi 2.0 0x66 = ISO Hi 3.0 0x6c = ISO Hi 4.0 0x72 = ISO Hi 5.0
> 6461 | CustomSettingsD4S | - | --> NikonCustom SettingsD4 Tags (firmware version 1.01)
> 13579 | OrientationInfo | - | --> Nikon OrientationInfo Tags
> 13971 | Rotation | int8u | [val >> 4 & 0x3] 0 = Horizontal 1 = Rotate 270 CW 2 = Rotate 90 CW 3 = Rotate 180

## Nikon ShotInfoD500 Tags

These tags are extracted from encrypted data in images from the D5 and D500.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 16 | RotationInfoOffset | - | --> Nikon RotationInfoD500 Tags
> 20 | JPGInfoOffset | - | --> Nikon JPGInfoD500 Tags
> 44 | BracketingOffset | - | --> Nikon BracketingInfoD500 Tags
> 80 | ShootingMenuOffset | - | --> Nikon ShootingMenuD500 Tags
> 88 | CustomSettingsOffset | - | --> Nikon CustomSettingsD500 Tags
> 160 | OrientationOffset | - | --> Nikon OrientationInfo Tags
> 168 | OtherOffset | - | --> Nikon OtherInfoD500 Tags

## Nikon RotationInfoD500 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 26 | Rotation | int8u | [val & 0x3] 0 = Horizontal 1 = Rotate 270 CW 2 = Rotate 90 CW 3 = Rotate 180
> 32 | Interval | int8u~ |
> 36 | IntervalFrame | int8u~ |
> 1330 | FlickerReductionIndicator | int8u | [val & 0x1] 0 = On 1 = Off

## Nikon JPGInfoD500 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 36 | JPGCompression | int8u | [val & 0x1] 0 = Size Priority 1 = Optimal Quality

## Nikon BracketingInfoD500 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 15 | AEBracketingSteps | int8u | [val & 0xff]
> 0x0 = AE Bracketing Disabled 0x20 = AE Bracketing Disabled 0x30 = AE Bracketing Disabled 0x40 = AE Bracketing Disabled 0x50 = AE Bracketing Disabled 0x81 = +3F0.3 0x82 = -3F0.3 0x83 = +2F0.3 0x84 = -2F0.3 0x85 = 3F0.3 0x86 = 5F0.3 0x87 = 7F0.3 0x88 = 9F0.3 0x91 = +3F0.5 0x92 = -3F0.5 0x93 = +2F0.5 0x94 = -2F0.5 0x95 = 3F0.5 0x96 = 5F0.5 0x97 = 7F0.5 0x98 = 9F0.5 0xa1 = +3F0.7 0xa2 = -3F0.7 0xa3 = +2F0.7 0xa4 = -2F0.7 |  | 0xa5 = 3F0.7 0xa6 = 5F0.7 0xa7 = 7F0.7 0xa8 = 9F0.7 0xb1 = +3F1 0xb2 = -3F1 0xb3 = +2F1 0xb4 = -2F1 0xb5 = 3F1 0xb6 = 5F1 0xb7 = 7F1 0xb8 = 9F1 0xc1 = +3F2 0xc2 = -3F2 0xc3 = +2F2 0xc4 = -2F2 0xc5 = 3F2 0xc6 = 5F2 0xd1 = +3F3 0xd2 = -3F3 0xd3 = +2F3 0xd4 = -2F3 0xd5 = 3F3 0xd6 = 5F3
> 16 | WBBracketingSteps | int8u | [val & 0xff]
> 0x0 = WB Bracketing Disabled 0x1 = b3F 1 0x2 = A3F 1 0x3 = b2F 1 0x4 = A2F 1 0x5 = 3F 1 0x6 = 5F 1 0x7 = 7F 1 0x8 = 9F 1 0x10 = 0F 2 0x11 = b3F 2 0x12 = A3F 2 0x13 = b2F 2 0x14 = A2F 2 |  | 0x15 = 3F 2 0x16 = 5F 2 0x17 = 7F 2 0x18 = 9F 2 0x20 = 0F 3 0x21 = b3F 3 0x22 = A3F 3 0x23 = b2F 3 0x24 = A2F 3 0x25 = 3F 3 0x26 = 5F 3 0x27 = 7F 3 0x28 = 9F 3
> 23 | ADLBracketingStep | int8u | [val >> 4 & 0xf]
> 0 = Off 1 = Low 2 = Normal |  | 3 = High 4 = Extra High 8 = Auto
> 24 | ADLBracketingType | int8u | [val & 0xf] 0 = Off 1 = 2 Shots 2 = 3 Shots 3 = 4 Shots 4 = 5 Shots

## Nikon ShootingMenuD500 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | PhotoShootingMenuBank | int8u | [val & 0x3] 0 = A 1 = B 2 = C 3 = D
> 2 | PrimarySlot | int8u | (D500 only) [val >> 7 & 0x1] 0 = XQD Card 1 = SD Card
> 4 | ISOAutoShutterTime | int8u | [val & 0x3f]
> 0 = 1/4000 s 1 = 1/3200 s 2 = 1/2500 s 3 = 1/2000 s 4 = 1/1600 s 5 = 1/1250 s 6 = 1/1000 s 7 = 1/800 s 8 = 1/640 s 9 = 1/500 s 10 = 1/400 s 11 = 1/320 s 12 = 1/250 s 13 = 1/200 s 14 = 1/160 s 15 = 1/125 s 16 = 1/100 s 17 = 1/80 s 18 = 1/60 s |  | 19 = 1/50 s 20 = 1/40 s 21 = 1/30 s 22 = 1/15 s 23 = 1/8 s 24 = 1/4 s 25 = 1/2 s 26 = 1 s 27 = 2 s 28 = 4 s 29 = 8 s 30 = 15 s 31 = 30 s 32 = Auto (Slowest) 33 = Auto (Slower) 34 = Auto 35 = Auto (Faster) 36 = Auto (Fastest)
> 5 | ISOAutoHiLimit | int8u | [val & 0xff]
> 0x24 = ISO 200 0x26 = ISO 250 0x27 = ISO 280 0x28 = ISO 320 0x2a = ISO 400 0x2c = ISO 500 0x2d = ISO 560 0x2e = ISO 640 0x30 = ISO 800 0x32 = ISO 1000 0x33 = ISO 1100 0x34 = ISO 1250 0x36 = ISO 1600 0x38 = ISO 2000 0x39 = ISO 2200 0x3a = ISO 2500 0x3c = ISO 3200 0x3e = ISO 4000 0x3f = ISO 4500 0x40 = ISO 5000 0x42 = ISO 6400 |  | 0x44 = ISO 8000 0x45 = ISO 9000 0x46 = ISO 10000 0x48 = ISO 12800 0x4a = ISO 16000 0x4b = ISO 18000 0x4c = ISO 20000 0x4e = ISO 25600 0x50 = ISO 32000 0x51 = ISO 36000 0x52 = ISO 40000 0x54 = ISO 51200 0x56 = ISO Hi 0.3 0x57 = ISO Hi 0.5 0x58 = ISO Hi 0.7 0x5a = ISO Hi 1.0 0x60 = ISO Hi 2.0 0x66 = ISO Hi 3.0 0x6c = ISO Hi 4.0 0x72 = ISO Hi 5.0
> 7 | FlickerReduction | int8u | [val >> 5 & 0x1] 0 = Enable 1 = Disable
> 7.1 | PhotoShootingMenuBankImageArea | int8u | [val & 0x7] 0 = FX (36x24) 1 = DX (24x16) 2 = 5:4 (30x24) 3 = 1.2x (30x20) 4 = 1.3x (18x12)

## Nikon CustomSettingsD500 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | CustomSettingsD5 CustomSettingsD500 | - - | --> NikonCustom SettingsD5 Tags --> NikonCustom SettingsD500 Tags

## Nikon OtherInfoD500 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 532 | NikonMeteringMode | int8u | (D500 only) [val & 0x3] 0 = Matrix 1 = Center 2 = Spot 3 = Highlight

## Nikon ShotInfoD6 Tags

These tags are extracted from encrypted data in images from the D6.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 48 | SequenceOffset | - | --> Nikon SeqInfoD6 Tags
> 156 | OrientationOffset | - | --> Nikon OrientationInfo Tags
> 164 | IntervalOffset | - | --> Nikon IntervalInfoD6 Tags

## Nikon SeqInfoD6 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 36 | IntervalShooting | int16u~ |
> 43 | ImageArea | int8u |
> 0 = FX (36x24) 1 = DX (24x16) 2 = 5:4 (30x24) |  | 3 = 1.2x (30x20) 4 = 1:1 (24x24) 6 = 16:9

## Nikon IntervalInfoD6 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 380 | Intervals | int32u |
> 384 | ShotsPerInterval | int32u |
> 388 | IntervalExposureSmoothing | int8u | 0 = Off 1 = On
> 390 | IntervalPriority | int8u | 0 = Off 1 = On
> 424 | FocusShiftNumberShots | int8u |
> 428 | FocusShiftStepWidth | int8u |
> 432 | FocusShiftInterval | int8u~ |
> 436 | FocusShiftExposureLock | int8u | 0 = Off 1 = On
> 526 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 532 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 538 | FlashGNDistance? | no |
> 0 = 0 1 = 0.1 m 2 = 0.2 m 3 = 0.3 m 4 = 0.4 m 5 = 0.5 m 6 = 0.6 m 7 = 0.7 m 8 = 0.8 m 9 = 0.9 m 10 = 1.0 m 11 = 1.1 m 12 = 1.3 m |  | 13 = 1.4 m 14 = 1.6 m 15 = 1.8 m 16 = 2.0 m 17 = 2.2 m 18 = 2.5 m 19 = 2.8 m 20 = 3.2 m 21 = 3.6 m 22 = 4.0 m 23 = 4.5 m 24 = 5.0 m 25 = 5.6 m |  | 26 = 6.3 m 27 = 7.1 m 28 = 8.0 m 29 = 9.0 m 30 = 10.0 m 31 = 11.0 m 32 = 13.0 m 33 = 14.0 m 34 = 16.0 m 35 = 18.0 m 36 = 20.0 m 255 = n/a
> 542 | FlashOutput? | int8u |
> 552 | FlashRemoteControl? | int8u | 0 = Group 1 = Quick Wireless 2 = Remote Repeating
> 556 | FlashMasterControlMode | int8u | 0 = TTL 1 = Manual 2 = Auto 3 = Off
> 558 | FlashMasterCompensation? | int8s |
> 562 | FlashMasterOutput? | int8u |
> 564 | FlashWirelessOption? | int8u | 0 = Optical AWL 1 = Off
> 714 | MovieType? | int8u | 0 = MOV 1 = MP4

## Nikon ShotInfoD610 Tags

These tags are extracted from encrypted data in images from the D610.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 1999 | CustomSettingsD610 | - | --> NikonCustom SettingsD610 Tags

## Nikon ShotInfoZ7II Tags

These tags are extracted from encrypted data in images from the Z7II.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 48 | IntervalOffset | - | --> Nikon IntervalInfoZ7II Tags
> 56 | PortraitOffset | - | --> Nikon PortraitInfoZ7II Tags
> 136 | OrientationOffset | - | --> Nikon OrientationInfo Tags
> 152 | OrientationOffset | - | --> Nikon OrientationInfo Tags
> 160 | MenuOffset | - | --> Nikon MenuInfoZ7II Tags

## Nikon IntervalInfoZ7II Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 36 | IntervalShooting | int16u~ |
> 43 | ImageArea | int8u |
> 0 = FX (36x24) 1 = DX (24x16) 2 = 5:4 (30x24) |  | 3 = 1.2x (30x20) 4 = 1:1 (24x24) 6 = 16:9

## Nikon PortraitInfoZ7II Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 160 | PortraitImpressionBalance | int8u[2]~ |

## Nikon MenuInfoZ7II Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 16 | MenuSettingsOffsetZ7II | - | --> Nikon MenuSettingsZ7II Tags

## Nikon MenuSettingsZ7II Tags

These tags are used by the Z5, Z6, Z7, Z6II, Z7II, Z50, Zfc and Zf.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 92 | ReleaseMode | no | 0 = Continuous Low 1 = Continuous High 2 = Continuous High (Extended) 4 = Timer 5 = Single Frame
> 160 | IntervalDurationHours | int32u |
> 164 | IntervalDurationMinutes | int32u |
> 168 | IntervalDurationSeconds | int32u |
> 176 | Intervals | int32u |
> 180 | ShotsPerInterval | int32u |
> 184 | IntervalExposureSmoothing | int8u | 0 = Off 1 = On
> 186 | IntervalPriority | int8u | 0 = Off 1 = On
> 220 | FocusShiftNumberShots | int8u |
> 224 | FocusShiftStepWidth | int8u |
> 228 | FocusShiftInterval | int8u~ |
> 232 | FocusShiftExposureLock | int8u | 0 = Off 1 = On
> 322 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 323 | AutoDistortionControl | int8u | 0 = Off 1 = On
> 326 | NikonMeteringMode | int8u | 0 = Matrix 1 = Center 2 = Spot 3 = Highlight
> 328 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 334 | FlashGNDistance? | no |
> 0 = 0 1 = 0.1 m 2 = 0.2 m 3 = 0.3 m 4 = 0.4 m 5 = 0.5 m 6 = 0.6 m 7 = 0.7 m 8 = 0.8 m 9 = 0.9 m 10 = 1.0 m 11 = 1.1 m 12 = 1.3 m |  | 13 = 1.4 m 14 = 1.6 m 15 = 1.8 m 16 = 2.0 m 17 = 2.2 m 18 = 2.5 m 19 = 2.8 m 20 = 3.2 m 21 = 3.6 m 22 = 4.0 m 23 = 4.5 m 24 = 5.0 m 25 = 5.6 m |  | 26 = 6.3 m 27 = 7.1 m 28 = 8.0 m 29 = 9.0 m 30 = 10.0 m 31 = 11.0 m 32 = 13.0 m 33 = 14.0 m 34 = 16.0 m 35 = 18.0 m 36 = 20.0 m 255 = n/a
> 338 | FlashOutput? | int8u |
> 346 | FlashWirelessOption? | int8u | 0 = Off 1 = Optical AWL 2 = Optical/Radio AWL 3 = Radio AWL
> 348 | FlashRemoteControl? | int8u | 0 = Group 1 = Quick Wireless 2 = Remote Repeating
> 352 | FlashMasterControlMode | int8u | 0 = TTL 1 = Manual 2 = Auto 3 = Off
> 354 | FlashMasterCompensation? | int8s |
> 358 | FlashMasterOutput? | int8u |
> 502 | MovieFrameSize? | int8u | 1 = 1920x1080 2 = 3840x2160 3 = 7680x4320
> 504 | MovieFrameRate? | int8u |
> 0 = 120p 1 = 100p 2 = 60p 3 = 50p |  | 4 = 30p 5 = 25p 6 = 24p
> 506 | MovieSlowMotion? | int8u | 0 = Off 1 = On (4x) 2 = On (5x)
> 510 | MovieType? | int8u | 0 = MOV 1 = MP4
> 516 | MovieISOAutoManualMode? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 568 | MovieActiveD-Lighting? | int8u | 0 = Off 2 = Low 3 = Normal 4 = High 5 = Extra High
> 572 | MovieHighISONoiseReduction? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 574 | MovieVignetteControl? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 576 | MovieVignetteControlSameAsPhoto? | int8u | 0 = No 1 = Yes
> 577 | MovieDiffractionCompensation? | int8u | 0 = Off 1 = On
> 578 | MovieAutoDistortionControl? | int8u | 0 = Off 1 = On
> 584 | MovieFocusMode? | int8u | 0 = Manual 1 = AF-S 2 = AF-C 4 = AF-F
> 590 | MovieVibrationReduction? | int8u | 0 = Off 1 = On (Normal) 2 = On (Sport)
> 591 | MovieVibrationReductionSameAsPhoto? | int8u | 0 = No 1 = Yes
> 858 | HDMIOutputN-Log? | int8u | 0 = Off 1 = On

## Nikon ShotInfoZ8 Tags

These tags are extracted from encrypted data in images from the Z8.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 48 | SequenceOffset | - | --> Nikon SeqInfoZ9 Tags
> 128 | AutoCaptureOffset | - | --> Nikon AutoCaptureInfo Tags
> 132 | OrientOffset | - | --> Nikon OrientationInfo Tags
> 140 | MenuOffset | - | --> Nikon MenuInfoZ8 Tags

## Nikon SeqInfoZ9 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 32 | FocusShiftShooting | int8u~ |
> 40 | IntervalShooting | int16u~ |

## Nikon AutoCaptureInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | AutoCapturedFrame | int8u | 0 = No 5 = Yes
> 1 | AutoCaptureCriteria | int8u~ | Bit 0 = Distance Bit 1 = Motion Bit 2 = Subject Detection
> 55 | AutoCaptureRecordingTime | int8u |
> 0 = 1 Sec 1 = 3 Sec 2 = 5 Sec 4 = 30 Sec 5 = No Limit |  | 6 = 2 Sec 7 = 10 Sec 8 = 20 Sec 9 = 1 Min 10 = 3 Min |  | 11 = 5 Min 12 = 10 Min 13 = 30 Min
> 56 | AutoCaptureWaitTime | int8u |
> 0 = No Wait 1 = 10 Sec 2 = 30 Sec 3 = 1 Min 4 = 5 Min |  | 5 = 10 Min 6 = 30 Min 7 = 1 Sec 8 = 2 Sec 9 = 3 Sec |  | 10 = 5 Sec 11 = 20 Sec 12 = 3 Min
> 74 | AutoCaptureDistanceFar | int8u~ |
> 78 | AutoCaptureDistanceNear | int8u~ |
> 95 | AutoCaptureCriteriaMotionDirection | int8u~ | Bit 0 = Top Left Bit 1 = Top Right Bit 2 = Bottom Left Bit 3 = Bottom Right Bit 4 = Left Bit 5 = Right Bit 6 = Top Center Bit 7 = Bottom Center
> 99 | AutoCaptureCriteriaMotionSpeed | int8u |
> 100 | AutoCaptureCriteriaMotionSize | int8u |
> 105 | AutoCaptureCriteriaSubjectSize | int8u |
> 106 | AutoCaptureCriteriaSubjectType | int8u | 0 = Auto (all) 1 = People 2 = Animals 3 = Vehicle

## Nikon MenuInfoZ8 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 16 | MenuSettingsOffsetZ8 MenuSettingsOffsetZ8v2 | - - | (Firmware versions 1.0.0 and 1.1.0) --> Nikon MenuSettingsZ8 Tags (Firmware version 2.0) --> Nikon MenuSettingsZ8v2 Tags

## Nikon MenuSettingsZ8 Tags

These tags are used by the Z8 firmware 1.00.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 72 | HighFrameRate | int8u |
> 0 = Off 1 = CH 3 = C30 |  | 4 = C120 5 = C60 6 = C15
> 152 | MultipleExposureMode | int8u | 0 = Off 1 = On 2 = On (Series)
> 154 | MultiExposureShots | int8u |
> 184 | IntervalDurationHours | int32u |
> 188 | IntervalDurationMinutes | int32u |
> 192 | IntervalDurationSeconds | int32u |
> 200 | Intervals | int32u |
> 204 | ShotsPerInterval | int32u |
> 208 | IntervalExposureSmoothing | int8u | 0 = Off 1 = On
> 210 | IntervalPriority | int8u | 0 = Off 1 = On
> 244 | FocusShiftNumberShots | int8u |
> 248 | FocusShiftStepWidth | int8u |
> 252 | FocusShiftInterval | int8u~ |
> 256 | FocusShiftExposureLock? | int8u | 0 = Off 1 = On
> 286 | PhotoShootingMenuBank | int8u | 0 = A 1 = B 2 = C 3 = D
> 288 | ExtendedMenuBanks | int8u | 0 = Off 1 = On
> 324 | PhotoShootingMenuBankImageArea | int8u | 0 = FX 1 = DX 4 = 16:9 8 = 1:1
> 338 | AutoISO | int8u | 0 = Off 1 = On
> 340 | ISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 342 | ISOAutoFlashLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 350 | ISOAutoShutterTime | no |
> -15 = Auto -12 = 15 s -9 = 8 s -6 = 4 s -3 = 2 s 0 = 1 s 1 = 1/1.3 s 2 = 1/1.6 s 3 = 1/2 s 4 = 1/2.5 s 5 = 1/3 s 6 = 1/4 s 7 = 1/5 s 8 = 1/6 s 9 = 1/8 s 10 = 1/10 s 11 = 1/13 s 12 = 1/15 s 13 = 1/20 s 14 = 1/25 s 15 = 1/30 s 16 = 1/40 s 17 = 1/50 s 18 = 1/60 s 19 = 1/80 s |  | 20 = 1/100 s 21 = 1/120 s 22 = 1/160 s 23 = 1/200 s 24 = 1/250 s 25 = 1/320 s 26 = 1/400 s 27 = 1/500 s 28 = 1/640 s 29 = 1/800 s 30 = 1/1000 s 31 = 1/1250 s 32 = 1/1600 s 33 = 1/2000 s 34 = 1/2500 s 35 = 1/3200 s 36 = 1/4000 s 37 = 1/5000 s 37.5 = 1/6000 s 38 = 1/6400 s 39 = 1/8000 s 40 = 1/10000 s 40.5 = 1/12000 s 41 = 1/13000 s 42 = 1/16000 s
> 432 | MovieVignetteControl? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 434 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 436 | FlickerReductionShooting | int8u | 0 = Off 1 = On
> 440 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 548 | AFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 550 | VRMode | int8u | 0 = Off 1 = Normal 2 = Sport
> 554 | BracketSet | int8u | 0 = AE/Flash 1 = AE 2 = Flash 3 = White Balance 4 = Active-D Lighting
> 556 | BracketProgram | int8u | (AE and/or Flash Bracketing)
> 0 = Disabled 2 = 2F 3 = 3F 4 = 4F |  | 5 = 5F 7 = 7F 9 = 9F
> 558 | BracketIncrement | int8u | (AE and/or Flash Bracketing)
> 0 = 0.3 1 = 0.5 2 = 0.7 |  | 3 = 1.0 4 = 2.0 5 = 3.0 |  | 6 = 1.3 7 = 1.5 8 = 1.7 |  | 9 = 2.3 10 = 2.5 11 = 2.7
> 570 | HDR | int8u | 0 = Off 1 = On 2 = On (Series)
> 576 | SecondarySlotFunction | int8u | 0 = Overflow 1 = Backup 2 = NEF Primary + JPG Secondary 3 = JPG Primary + JPG Secondary
> 582 | HDRLevel | int8u | 0 = Auto 1 = Extra High 2 = High 3 = Normal 4 = Low
> 586 | Slot2JpgSize? | int8u | 0 = Large (8256x5504) 1 = Medium (6192x4128) 2 = Small (4128x2752)
> 592 | DXCropAlert | int8u | 0 = Off 1 = On
> 594 | SubjectDetection | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 596 | DynamicAFAreaSize | int8u | 0 = Small 1 = Medium 2 = Large
> 618 | ToneMap? | int8u | 0 = SDR 1 = HLG
> 622 | PortraitImpressionBalance | int8u | 0 = Off 1 = Mode 1 2 = Mode 2 3 = Mode 3
> 636 | HighFrequencyFlickerReduction? | int8u | 0 = Off 1 = On
> 730 | MovieImageArea? | int8u | [val & 0x1] 0 = FX 1 = DX
> 740 | MovieType? | int8u |
> 1 = H.264 8-bit (MP4) 2 = H.265 8-bit (MOV) 3 = H.265 10-bit (MOV) 4 = ProRes 422 HQ 10-bit (MOV) 5 = ProRes RAW HQ 12-bit (MOV) 6 = NRAW 12-bit (NEV)
> 742 | MovieISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 744 | MovieISOAutoControlManualMode? | int8u | 0 = Off 1 = On
> 746 | MovieISOAutoManualMode? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 820 | MovieActiveD-Lighting? | int8u | 0 = Off 2 = Low 3 = Normal 4 = High 5 = Extra High
> 822 | MovieHighISONoiseReduction? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 828 | MovieFlickerReduction | int8u | 0 = Auto 1 = 50Hz 2 = 60Hz
> 830 | MovieMeteringMode? | int8u | 0 = Matrix 1 = Center 2 = Spot 3 = Highlight
> 832 | MovieFocusMode? | int8u | 0 = Manual 1 = AF-S 2 = AF-C 4 = AF-F
> 834 | MovieAFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 836 | MovieVRMode? | int8u | 0 = Off 1 = Normal 2 = Sport
> 840 | MovieElectronicVR? | int8u | 0 = Off 1 = On
> 842 | MovieSoundRecording? | int8u | 0 = Off 1 = Auto 2 = Manual
> 844 | MicrophoneSensitivity? | int8u |
> 846 | MicrophoneAttenuator? | int8u | 0 = Off 1 = On
> 848 | MicrophoneFrequencyResponse? | int8u | 0 = Wide Range 1 = Vocal Range
> 850 | WindNoiseReduction? | int8u | 0 = Off 1 = On
> 882 | MovieFrameSize? | int8u | 1 = 1920x1080 2 = 3840x2160 3 = 7680x4320
> 884 | MovieFrameRate? | int8u |
> 0 = 120p 1 = 100p 2 = 60p 3 = 50p |  | 4 = 30p 5 = 25p 6 = 24p
> 886 | MicrophoneJackPower? | int8u | 0 = Off 1 = On
> 887 | MovieDXCropAlert? | int8u | 0 = Off 1 = On
> 888 | MovieSubjectDetection? | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 896 | MovieHighResZoom? | int8u | 0 = Off 1 = On
> 943 | CustomSettingsZ8 | - | --> NikonCustom SettingsZ8 Tags
> 1684 | TimeZone | int8u |
> 3 = +10:00 (Sydney) 5 = +09:00 (Tokyo) 6 = +08:00 (Beijing, Honk Kong, Sinapore) 10 = +05:45 (Kathmandu) 11 = +05:30 (New Dehli) 12 = +05:00 (Islamabad) 13 = +04:30 (Kabul) 14 = +04:00 (Abu Dhabi) 15 = +03:30 (Tehran) 16 = +03:00 (Moscow, Nairobi) 17 = +02:00 (Athens, Helsinki) 18 = +01:00 (Madrid, Paris, Berlin) 19 = +00:00 (London) 20 = -01:00 (Azores) 21 = -02:00 (Fernando de Noronha) 22 = -03:00 (Buenos Aires, Sao Paulo) 23 = -03:30 (Newfoundland) 24 = -04:00 (Manaus, Caracas) 25 = -05:00 (New York, Toronto, Lima) 26 = -06:00 (Chicago, Mexico City) 27 = -07:00 (Denver) 28 = -08:00 (Los Angeles, Vancouver) 29 = -09:00 (Anchorage) 30 = -10:00 (Hawaii)
> 1690 | MonitorBrightness? | int8u |
> 0 = -5 1 = -4 2 = -3 |  | 3 = -2 4 = -1 5 = 0 |  | 6 = 1 7 = 2 8 = 3 |  | 9 = 4 10 = 5 14 = Hi1 |  | 15 = Hi2 16 = Lo2 17 = Lo1
> 1698 | Language? | int8u | 4 = English 5 = Spanish 7 = French 15 = Portuguese
> 1712 | AFFineTune? | int8u | 0 = Off 1 = On
> 1716 | NonCPULens1FocalLength? | int16u~ |
> 1718 | NonCPULens2FocalLength? | int16u~ |
> 1720 | NonCPULens3FocalLength? | int16u~ |
> 1722 | NonCPULens4FocalLength? | int16u~ |
> 1724 | NonCPULens5FocalLength? | int16u~ |
> 1726 | NonCPULens6FocalLength? | int16u~ |
> 1728 | NonCPULens7FocalLength? | int16u~ |
> 1730 | NonCPULens8FocalLength? | int16u~ |
> 1732 | NonCPULens9FocalLength? | int16u~ |
> 1734 | NonCPULens10FocalLength? | int16u~ |
> 1736 | NonCPULens11FocalLength? | int16u~ |
> 1738 | NonCPULens12FocalLength? | int16u~ |
> 1740 | NonCPULens13FocalLength? | int16u~ |
> 1742 | NonCPULens14FocalLength? | int16u~ |
> 1744 | NonCPULens15FocalLength? | int16u~ |
> 1746 | NonCPULens16FocalLength? | int16u~ |
> 1748 | NonCPULens17FocalLength? | int16u~ |
> 1750 | NonCPULens18FocalLength? | int16u~ |
> 1752 | NonCPULens19FocalLength? | int16u~ |
> 1754 | NonCPULens20FocalLength? | int16u~ |
> 1756 | NonCPULens1MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1758 | NonCPULens2MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1760 | NonCPULens3MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1762 | NonCPULens4MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1764 | NonCPULens5MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1766 | NonCPULens6MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1768 | NonCPULens7MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1770 | NonCPULens8MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1772 | NonCPULens9MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1774 | NonCPULens10MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1776 | NonCPULens11MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1778 | NonCPULens12MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1780 | NonCPULens13MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1782 | NonCPULens14MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1784 | NonCPULens15MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1786 | NonCPULens16MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1788 | NonCPULens17MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1790 | NonCPULens18MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1792 | NonCPULens19MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1794 | NonCPULens20MaxAperture? | int16u |
> 12 = f/1.2 24 = f/1.4 40 = f/1.8 48 = f/2.0 64 = f/2.5 72 = f/2.8 84 = f/3.3 88 = f/3.5 |  | 96 = f/4.0 104 = f/4.5 112 = f/5.0 120 = f/5.6 128 = f/6.3 136 = f/7.1 144 = f/8 156 = f/9.5 |  | 168 = f/11 180 = f/13 188 = f/15 192 = f/16 204 = f/19 216 = f/22 313 = N/A
> 1808 | HDMIOutputResolution | int8u | 0 = Auto 1 = 4320p 2 = 2160p 3 = 1080p 5 = 720p
> 1826 | AirplaneMode? | int8u | 0 = Off 1 = On
> 1827 | EmptySlotRelease? | int8u | 0 = Disable Release 1 = Enable Release
> 1862 | EnergySavingMode? | int8u | 0 = Off 1 = On
> 1890 | USBPowerDelivery? | int8u | 0 = Off 1 = On
> 1899 | SensorShield? | int8u | 0 = Stays Open 1 = Closes

## Nikon MenuSettingsZ8v2 Tags

These tags are used by the Z8 firmware 1.00.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 72 | HighFrameRate | int8u |
> 0 = Off 1 = CH 3 = C30 |  | 4 = C120 5 = C60 6 = C15
> 152 | MultipleExposureMode | int8u | 0 = Off 1 = On 2 = On (Series)
> 154 | MultiExposureShots | int8u |
> 184 | IntervalDurationHours | int32u |
> 188 | IntervalDurationMinutes | int32u |
> 192 | IntervalDurationSeconds | int32u |
> 200 | Intervals | int32u |
> 204 | ShotsPerInterval | int32u |
> 208 | IntervalExposureSmoothing | int8u | 0 = Off 1 = On
> 210 | IntervalPriority | int8u | 0 = Off 1 = On
> 244 | FocusShiftNumberShots | int8u |
> 248 | FocusShiftStepWidth | int8u |
> 252 | FocusShiftInterval | int8u~ |
> 256 | FocusShiftExposureLock? | int8u | 0 = Off 1 = On
> 286 | PhotoShootingMenuBank | int8u | 0 = A 1 = B 2 = C 3 = D
> 288 | ExtendedMenuBanks | int8u | 0 = Off 1 = On
> 324 | PhotoShootingMenuBankImageArea | int8u | 0 = FX 1 = DX 4 = 16:9 8 = 1:1
> 338 | AutoISO | int8u | 0 = Off 1 = On
> 340 | ISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 342 | ISOAutoFlashLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 350 | ISOAutoShutterTime | no |
> -15 = Auto -12 = 15 s -9 = 8 s -6 = 4 s -3 = 2 s 0 = 1 s 1 = 1/1.3 s 2 = 1/1.6 s 3 = 1/2 s 4 = 1/2.5 s 5 = 1/3 s 6 = 1/4 s 7 = 1/5 s 8 = 1/6 s 9 = 1/8 s 10 = 1/10 s 11 = 1/13 s 12 = 1/15 s 13 = 1/20 s 14 = 1/25 s 15 = 1/30 s 16 = 1/40 s 17 = 1/50 s 18 = 1/60 s 19 = 1/80 s |  | 20 = 1/100 s 21 = 1/120 s 22 = 1/160 s 23 = 1/200 s 24 = 1/250 s 25 = 1/320 s 26 = 1/400 s 27 = 1/500 s 28 = 1/640 s 29 = 1/800 s 30 = 1/1000 s 31 = 1/1250 s 32 = 1/1600 s 33 = 1/2000 s 34 = 1/2500 s 35 = 1/3200 s 36 = 1/4000 s 37 = 1/5000 s 37.5 = 1/6000 s 38 = 1/6400 s 39 = 1/8000 s 40 = 1/10000 s 40.5 = 1/12000 s 41 = 1/13000 s 42 = 1/16000 s
> 432 | MovieVignetteControl? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 434 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 436 | FlickerReductionShooting | int8u | 0 = Off 1 = On
> 440 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 548 | AFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 550 | VRMode | int8u | 0 = Off 1 = Normal 2 = Sport
> 554 | BracketSet | int8u | 0 = AE/Flash 1 = AE 2 = Flash 3 = White Balance 4 = Active-D Lighting
> 556 | BracketProgram | int8u | (AE and/or Flash Bracketing)
> 0 = Disabled 2 = 2F 3 = 3F 4 = 4F |  | 5 = 5F 7 = 7F 9 = 9F
> 558 | BracketIncrement | int8u | (AE and/or Flash Bracketing)
> 0 = 0.3 1 = 0.5 2 = 0.7 |  | 3 = 1.0 4 = 2.0 5 = 3.0 |  | 6 = 1.3 7 = 1.5 8 = 1.7 |  | 9 = 2.3 10 = 2.5 11 = 2.7
> 570 | HDR | int8u | 0 = Off 1 = On 2 = On (Series)
> 576 | SecondarySlotFunction | int8u | 0 = Overflow 1 = Backup 2 = NEF Primary + JPG Secondary 3 = JPG Primary + JPG Secondary
> 582 | HDRLevel | int8u | 0 = Auto 1 = Extra High 2 = High 3 = Normal 4 = Low
> 586 | Slot2JpgSize? | int8u | 0 = Large (8256x5504) 1 = Medium (6192x4128) 2 = Small (4128x2752)
> 592 | DXCropAlert | int8u | 0 = Off 1 = On
> 594 | SubjectDetection | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 596 | DynamicAFAreaSize | int8u | 0 = Small 1 = Medium 2 = Large
> 618 | ToneMap? | int8u | 0 = SDR 1 = HLG
> 622 | PortraitImpressionBalance | int8u | 0 = Off 1 = Mode 1 2 = Mode 2 3 = Mode 3
> 636 | HighFrequencyFlickerReduction? | int8u | 0 = Off 1 = On
> 730 | MovieImageArea? | int8u | [val & 0x1] 0 = FX 1 = DX
> 740 | MovieType? | int8u |
> 1 = H.264 8-bit (MP4) 2 = H.265 8-bit (MOV) 3 = H.265 10-bit (MOV) 4 = ProRes 422 HQ 10-bit (MOV) 5 = ProRes RAW HQ 12-bit (MOV) 6 = NRAW 12-bit (NEV)
> 742 | MovieISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 744 | MovieISOAutoControlManualMode? | int8u | 0 = Off 1 = On
> 746 | MovieISOAutoManualMode? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 820 | MovieActiveD-Lighting? | int8u | 0 = Off 2 = Low 3 = Normal 4 = High 5 = Extra High
> 822 | MovieHighISONoiseReduction? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 828 | MovieFlickerReduction | int8u | 0 = Auto 1 = 50Hz 2 = 60Hz
> 830 | MovieMeteringMode? | int8u | 0 = Matrix 1 = Center 2 = Spot 3 = Highlight
> 832 | MovieFocusMode? | int8u | 0 = Manual 1 = AF-S 2 = AF-C 4 = AF-F
> 834 | MovieAFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 836 | MovieVRMode? | int8u | 0 = Off 1 = Normal 2 = Sport
> 840 | MovieElectronicVR? | int8u | 0 = Off 1 = On
> 842 | MovieSoundRecording? | int8u | 0 = Off 1 = Auto 2 = Manual
> 844 | MicrophoneSensitivity? | int8u |
> 846 | MicrophoneAttenuator? | int8u | 0 = Off 1 = On
> 848 | MicrophoneFrequencyResponse? | int8u | 0 = Wide Range 1 = Vocal Range
> 850 | WindNoiseReduction? | int8u | 0 = Off 1 = On
> 878 | MovieFrameSize? | int8u | 1 = 1920x1080 2 = 3840x2160 3 = 7680x4320
> 880 | MovieFrameRate? | int8u |
> 0 = 120p 1 = 100p 2 = 60p 3 = 50p |  | 4 = 30p 5 = 25p 6 = 24p
> 886 | MicrophoneJackPower? | int8u | 0 = Off 1 = On
> 887 | MovieDXCropAlert? | int8u | 0 = Off 1 = On
> 888 | MovieSubjectDetection? | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 896 | MovieHighResZoom? | int8u | 0 = Off 1 = On
> 943 | CustomSettingsZ8 | - | --> NikonCustom SettingsZ8 Tags
> 1698 | Language? | int8u | 4 = English 5 = Spanish 7 = French 15 = Portuguese
> 1700 | TimeZone | int8u |
> 3 = +10:00 (Sydney) 5 = +09:00 (Tokyo) 6 = +08:00 (Beijing, Honk Kong, Sinapore) 10 = +05:45 (Kathmandu) 11 = +05:30 (New Dehli) 12 = +05:00 (Islamabad) 13 = +04:30 (Kabul) 14 = +04:00 (Abu Dhabi) 15 = +03:30 (Tehran) 16 = +03:00 (Moscow, Nairobi) 17 = +02:00 (Athens, Helsinki) 18 = +01:00 (Madrid, Paris, Berlin) 19 = +00:00 (London) 20 = -01:00 (Azores) 21 = -02:00 (Fernando de Noronha) 22 = -03:00 (Buenos Aires, Sao Paulo) 23 = -03:30 (Newfoundland) 24 = -04:00 (Manaus, Caracas) 25 = -05:00 (New York, Toronto, Lima) 26 = -06:00 (Chicago, Mexico City) 27 = -07:00 (Denver) 28 = -08:00 (Los Angeles, Vancouver) 29 = -09:00 (Anchorage) 30 = -10:00 (Hawaii)
> 1706 | MonitorBrightness? | int8u |
> 0 = -5 1 = -4 2 = -3 |  | 3 = -2 4 = -1 5 = 0 |  | 6 = 1 7 = 2 8 = 3 |  | 9 = 4 10 = 5 14 = Hi1 |  | 15 = Hi2 16 = Lo2 17 = Lo1
> 1728 | AFFineTune? | int8u | 0 = Off 1 = On
> 1732 | NonCPULens1FocalLength? | int16u~ |
> 1734 | NonCPULens2FocalLength? | int16u~ |
> 1736 | NonCPULens3FocalLength? | int16u~ |
> 1738 | NonCPULens4FocalLength? | int16u~ |
> 1740 | NonCPULens5FocalLength? | int16u~ |
> 1742 | NonCPULens6FocalLength? | int16u~ |
> 1744 | NonCPULens7FocalLength? | int16u~ |
> 1746 | NonCPULens8FocalLength? | int16u~ |
> 1748 | NonCPULens9FocalLength? | int16u~ |
> 1750 | NonCPULens10FocalLength? | int16u~ |
> 1752 | NonCPULens11FocalLength? | int16u~ |
> 1754 | NonCPULens12FocalLength? | int16u~ |
> 1756 | NonCPULens13FocalLength? | int16u~ |
> 1758 | NonCPULens14FocalLength? | int16u~ |
> 1760 | NonCPULens15FocalLength? | int16u~ |
> 1762 | NonCPULens16FocalLength? | int16u~ |
> 1764 | NonCPULens17FocalLength? | int16u~ |
> 1766 | NonCPULens18FocalLength? | int16u~ |
> 1768 | NonCPULens19FocalLength? | int16u~ |
> 1770 | NonCPULens20FocalLength? | int16u~ |
> 1812 | NonCPULens1MaxAperture? | int32u~ |
> 1816 | NonCPULens2MaxAperture? | int32u~ |
> 1820 | NonCPULens3MaxAperture? | int32u~ |
> 1824 | HDMIOutputResolution | int8u | 0 = Auto 1 = 4320p 2 = 2160p 3 = 1080p 5 = 720p
> 1828 | NonCPULens5MaxAperture? | int32u~ |
> 1832 | NonCPULens6MaxAperture? | int32u~ |
> 1836 | NonCPULens7MaxAperture? | int32u~ |
> 1840 | NonCPULens8MaxAperture? | int32u~ |
> 1842 | AirplaneMode? | int8u | 0 = Off 1 = On
> 1843 | EmptySlotRelease? | int8u | 0 = Disable Release 1 = Enable Release
> 1844 | NonCPULens9MaxAperture? | int32u~ |
> 1848 | NonCPULens10MaxAperture? | int32u~ |
> 1852 | NonCPULens11MaxAperture? | int32u~ |
> 1856 | NonCPULens12MaxAperture? | int32u~ |
> 1860 | NonCPULens13MaxAperture? | int32u~ |
> 1864 | NonCPULens14MaxAperture? | int32u~ |
> 1868 | NonCPULens15MaxAperture? | int32u~ |
> 1872 | NonCPULens16MaxAperture? | int32u~ |
> 1876 | NonCPULens17MaxAperture? | int32u~ |
> 1878 | EnergySavingMode? | int8u | 0 = Off 1 = On
> 1880 | NonCPULens18MaxAperture? | int32u~ |
> 1884 | NonCPULens19MaxAperture? | int32u~ |
> 1888 | NonCPULens20MaxAperture? | int32u~ |
> 1906 | USBPowerDelivery? | int8u | 0 = Off 1 = On
> 1915 | SensorShield? | int8u | 0 = Stays Open 1 = Closes
> 2046 | PixelShiftShooting | int8u | 0 = Off 1 = On 2 = On (Series)
> 2048 | PixelShiftNumberShots | int8u | 0 = 4 1 = 8 2 = 16 3 = 32
> 2050 | PixelShiftDelay | int8u |
> 0 = Off 1 = 1 s 2 = 2 s |  | 3 = 3 s 4 = 5 s 5 = 10 s
> 2052 | PlaybackButton | int8u | --> Nikon ButtonsZ9 Values
> 2054 | WBButton | int8u | --> Nikon ButtonsZ9 Values
> 2056 | BracketButton | int8u | --> Nikon ButtonsZ9 Values
> 2058 | LensFunc1ButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2060 | LensFunc2ButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2062 | PlaybackButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2064 | BracketButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values

## Nikon ButtonsZ9 Values

> Value | ButtonsZ9 | Value | ButtonsZ9
> --- | --- | --- | ---
> 0 | = None | 70 | = Photo Shooting Bank
> 1 | = Preview | 71 | = ISO
> 3 | = FV Lock | 72 | = Shooting Mode
> 4 | = AE/AF Lock | 73 | = Exposure Compensation
> 5 | = AE Lock Only | 76 | = Silent Mode
> 6 | = AE Lock (reset on release) | 78 | = LiveView Information
> 7 | = AE Lock (hold) | 79 | = AWB Lock (hold)
> 8 | = AF Lock Only | 80 | = Grid Display
> 9 | = AF-On | 81 | = Starlight View
> 10 | = Flash Disable/Enable | 82 | = Select To Send (PC)
> 11 | = Bracketing Burst | 83 | = Select To Send (FTP)
> 12 | = +NEF(RAW) | 84 | = Pattern Tone Range
> 18 | = Virtual Horizon | 85 | = Control Lock
> 19 | = Synchronized Release | 86 | = Save Focus Position
> 20 | = My Menu | 87 | = Recall Focus Position
> 21 | = My Menu Top Item | 88 | = Recall Shooting Functions (Hold)
> 22 | = Playback | 89 | = Set Picture Control (HLG)
> 23 | = Rating | 90 | = Skin Softening
> 24 | = Protect | 91 | = Portrait Impression Balance
> 25 | = Zoom | 97 | = High Frequency Flicker Reduction
> 26 | = Focus Peaking | 98 | = Switch FX/DX
> 27 | = Flash Mode/Compensation | 99 | = View Mode (Photo LV)
> 28 | = Image Area | 100 | = Photo Flicker Reduction
> 30 | = Non-CPU Lens | 101 | = Filtered Playback (Select Criteria)
> 31 | = Active-D Lighting | 103 | = Start Series Playback
> 32 | = Exposure Delay Mode | 104 | = View Assist
> 33 | = 1 Stop Speed/Aperture | 105 | = Hi-Res Zoom+
> 34 | = White Balance | 106 | = Hi-Res Zoom-
> 35 | = Metering | 108 | = Override Other Cameras
> 36 | = Auto Bracketing | 109 | = DISP - Cycle Information Display (shooting)
> 37 | = Multiple Exposure | 110 | = DISP - Cycle Information Display (playback)
> 38 | = HDR Overlay | 111 | = Resume Shooting
> 39 | = Picture Control | 112 | = Switch Eyes
> 40 | = Quality | 113 | = Power Zoom +
> 41 | = Focus Mode/AF AreaMode | 114 | = Power Zoom -
> 42 | = Select Center Focus Point | 115 | = Delete
> 44 | = Record Movie | 116 | = Pixel Shift Shooting
> 45 | = Thumbnail On/Off | 117 | = Cycle AF-area Mode
> 46 | = View Histograms | 118 | = Raw Processing (Current)
> 47 | = Choose Folder | 119 | = Raw Processing (Multiple)
> 48 | = Power Aperture (Open) | 120 | = Trim
> 49 | = Power Aperture (Close) | 121 | = Resize (Current)
> 52 | = Microphone Sensitivity | 122 | = Resize (Multiple)
> 53 | = Release Mode | 123 | = D-Lighting
> 57 | = Preset Focus Point | 124 | = Straighten
> 58 | = AE/AWB Lock (hold) | 125 | = Distortion Control
> 59 | = AF-AreaMode | 126 | = Perspective Control
> 60 | = AF-AreaMode + AF-On | 127 | = Monochrome
> 61 | = Recall Shooting Functions | 128 | = Overlay (Add)
> 64 | = Filtered Playback | 129 | = Lighten
> 65 | = Same as AF-On | 130 | = Darken
> 66 | = Voice Memo | 131 | = Motion Blend

## Nikon ShotInfoZ9 Tags

These tags are extracted from encrypted data in images from the Z9.

> Index | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 48 | SequenceOffset | - | --> Nikon SeqInfoZ9 Tags
> 88 | Offset13 | - | --> Nikon Offset13InfoZ9 Tags
> 128 | AutoCaptureOffset | - | --> Nikon AutoCaptureInfo Tags
> 132 | OrientOffset | - | --> Nikon OrientationInfo Tags
> 140 | MenuOffset | - | --> Nikon MenuInfoZ9 Tags

## Nikon Offset13InfoZ9 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 3048 | AFAreaInitialXPosition | int8s~ |
> 3049 | AFAreaInitialYPosition | int8s~ |
> 3050 | AFAreaInitialWidth | int8u |
> 3051 | AFAreaInitialHeight | int8u |

## Nikon MenuInfoZ9 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 16 | MenuSettingsOffsetZ9 MenuSettingsOffsetZ9v3 MenuSettingsOffsetZ9v4 | - - - | (Firmware versions 2.11 and earlier) --> Nikon MenuSettingsZ9 Tags (Firmware versions 3.0 and v3.10) --> Nikon MenuSettingsZ9v3 Tags (Firmware versions 4.0 and later) --> Nikon MenuSettingsZ9v4 Tags

## Nikon MenuSettingsZ9 Tags

These tags are used by the Z9.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 140 | MultipleExposureMode | int8u | 0 = Off 1 = On 2 = On (Series)
> 142 | MultiExposureShots | int8u |
> 188 | Intervals | int32u |
> 192 | ShotsPerInterval | int32u |
> 232 | FocusShiftNumberShots | int8u |
> 236 | FocusShiftStepWidth | int8u |
> 240 | FocusShiftInterval | int8u~ |
> 244 | FocusShiftExposureLock? | int8u | 0 = Off 1 = On
> 274 | PhotoShootingMenuBank | int8u | 0 = A 1 = B 2 = C 3 = D
> 276 | ExtendedMenuBanks | int8u | 0 = Off 1 = On
> 308 | PhotoShootingMenuBankImageArea | int8u | 0 = FX 1 = DX 4 = 16:9 8 = 1:1
> 322 | AutoISO | int8u | 0 = Off 1 = On
> 324 | ISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 326 | ISOAutoFlashLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 334 | ISOAutoShutterTime | no |
> -15 = Auto -12 = 15 s -9 = 8 s -6 = 4 s -3 = 2 s 0 = 1 s 1 = 1/1.3 s 2 = 1/1.6 s 3 = 1/2 s 4 = 1/2.5 s 5 = 1/3 s 6 = 1/4 s 7 = 1/5 s 8 = 1/6 s 9 = 1/8 s 10 = 1/10 s 11 = 1/13 s 12 = 1/15 s 13 = 1/20 s 14 = 1/25 s 15 = 1/30 s 16 = 1/40 s 17 = 1/50 s 18 = 1/60 s 19 = 1/80 s |  | 20 = 1/100 s 21 = 1/120 s 22 = 1/160 s 23 = 1/200 s 24 = 1/250 s 25 = 1/320 s 26 = 1/400 s 27 = 1/500 s 28 = 1/640 s 29 = 1/800 s 30 = 1/1000 s 31 = 1/1250 s 32 = 1/1600 s 33 = 1/2000 s 34 = 1/2500 s 35 = 1/3200 s 36 = 1/4000 s 37 = 1/5000 s 37.5 = 1/6000 s 38 = 1/6400 s 39 = 1/8000 s 40 = 1/10000 s 40.5 = 1/12000 s 41 = 1/13000 s 42 = 1/16000 s
> 416 | MovieVignetteControl? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 418 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 420 | FlickerReductionShooting | int8u | 0 = Off 1 = On
> 424 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 426 | FlashMasterCompensation? | int8s |
> 430 | FlashGNDistance? | no |
> 0 = 0 1 = 0.1 m 2 = 0.2 m 3 = 0.3 m 4 = 0.4 m 5 = 0.5 m 6 = 0.6 m 7 = 0.7 m 8 = 0.8 m 9 = 0.9 m 10 = 1.0 m 11 = 1.1 m 12 = 1.3 m |  | 13 = 1.4 m 14 = 1.6 m 15 = 1.8 m 16 = 2.0 m 17 = 2.2 m 18 = 2.5 m 19 = 2.8 m 20 = 3.2 m 21 = 3.6 m 22 = 4.0 m 23 = 4.5 m 24 = 5.0 m 25 = 5.6 m |  | 26 = 6.3 m 27 = 7.1 m 28 = 8.0 m 29 = 9.0 m 30 = 10.0 m 31 = 11.0 m 32 = 13.0 m 33 = 14.0 m 34 = 16.0 m 35 = 18.0 m 36 = 20.0 m 255 = n/a
> 434 | FlashOutput? | int8u |
> 444 | FlashRemoteControl? | int8u | 0 = Group 1 = Quick Wireless 2 = Remote Repeating
> 456 | FlashWirelessOption? | int8u | 0 = Off 1 = Optical AWL 2 = Optical/Radio AWL 3 = Radio AWL
> 528 | AFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 530 | VRMode | int8u | 0 = Off 1 = Normal 2 = Sport
> 534 | BracketSet | int8u | 0 = AE/Flash 1 = AE 2 = Flash 3 = White Balance 4 = Active-D Lighting
> 536 | BracketProgram | int8u | (AE and/or Flash Bracketing)
> 0 = Disabled 2 = 2F 3 = 3F 4 = 4F |  | 5 = 5F 7 = 7F 9 = 9F
> 538 | BracketIncrement | int8u | (AE and/or Flash Bracketing)
> 0 = 0.3 1 = 0.5 2 = 0.7 |  | 3 = 1.0 4 = 2.0 5 = 3.0 |  | 6 = 1.3 7 = 1.5 8 = 1.7 |  | 9 = 2.3 10 = 2.5 11 = 2.7
> 556 | SecondarySlotFunction | int8u | 0 = Overflow 1 = Backup 2 = NEF Primary + JPG Secondary 3 = JPG Primary + JPG Secondary
> 572 | DXCropAlert | int8u | 0 = Off 1 = On
> 574 | SubjectDetection | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 576 | DynamicAFAreaSize | int8u | 0 = Small 1 = Medium 2 = Large
> 604 | MovieImageArea? | int8u | [val & 0x1] 0 = FX 1 = DX
> 614 | MovieType? | int8u |
> 1 = H.264 8-bit (MP4) 2 = H.265 8-bit (MOV) 3 = H.265 10-bit (MOV) 4 = ProRes 422 HQ 10-bit (MOV) 5 = ProRes RAW HQ 12-bit (MOV) 6 = NRAW 12-bit (NEV)
> 616 | MovieISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 618 | MovieISOAutoControlManualMode? | int8u | 0 = Off 1 = On
> 620 | MovieISOAutoManualMode? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 696 | MovieActiveD-Lighting? | int8u | 0 = Off 2 = Low 3 = Normal 4 = High 5 = Extra High
> 698 | MovieHighISONoiseReduction? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 704 | MovieFlickerReduction | int8u | 0 = Auto 1 = 50Hz 2 = 60Hz
> 706 | MovieMeteringMode? | int8u | 0 = Matrix 1 = Center 2 = Spot 3 = Highlight
> 708 | MovieFocusMode? | int8u | 0 = Manual 1 = AF-S 2 = AF-C 4 = AF-F
> 710 | MovieAFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 712 | MovieVRMode? | int8u | 0 = Off 1 = Normal 2 = Sport
> 716 | MovieElectronicVR? | int8u | 0 = Off 1 = On
> 718 | MovieSoundRecording? | int8u | 0 = Off 1 = Auto 2 = Manual
> 720 | MicrophoneSensitivity? | int8u |
> 722 | MicrophoneAttenuator? | int8u | 0 = Off 1 = On
> 724 | MicrophoneFrequencyResponse? | int8u | 0 = Wide Range 1 = Vocal Range
> 726 | WindNoiseReduction? | int8u | 0 = Off 1 = On
> 748 | MovieToneMap? | int8u | 0 = SDR 1 = HLG 2 = N-Log
> 754 | MovieFrameSize? | int8u | 1 = 1920x1080 2 = 3840x2160 3 = 7680x4320
> 756 | MovieFrameRate? | int8u |
> 0 = 120p 1 = 100p 2 = 60p 3 = 50p |  | 4 = 30p 5 = 25p 6 = 24p
> 762 | MicrophoneJackPower? | int8u | 0 = Off 1 = On
> 763 | MovieDXCropAlert? | int8u | 0 = Off 1 = On
> 764 | MovieSubjectDetection? | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 799 | CustomSettingsZ9 | - | --> NikonCustom SettingsZ9 Tags
> 1426 | Language? | int8u | 4 = English 5 = Spanish 7 = French 15 = Portuguese
> 1428 | TimeZone | int8u |
> 3 = +10:00 (Sydney) 5 = +09:00 (Tokyo) 6 = +08:00 (Beijing, Honk Kong, Sinapore) 10 = +05:45 (Kathmandu) 11 = +05:30 (New Dehli) 12 = +05:00 (Islamabad) 13 = +04:30 (Kabul) 14 = +04:00 (Abu Dhabi) 15 = +03:30 (Tehran) 16 = +03:00 (Moscow, Nairobi) 17 = +02:00 (Athens, Helsinki) 18 = +01:00 (Madrid, Paris, Berlin) 19 = +00:00 (London) 20 = -01:00 (Azores) 21 = -02:00 (Fernando de Noronha) 22 = -03:00 (Buenos Aires, Sao Paulo) 23 = -03:30 (Newfoundland) 24 = -04:00 (Manaus, Caracas) 25 = -05:00 (New York, Toronto, Lima) 26 = -06:00 (Chicago, Mexico City) 27 = -07:00 (Denver) 28 = -08:00 (Los Angeles, Vancouver) 29 = -09:00 (Anchorage) 30 = -10:00 (Hawaii)
> 1434 | MonitorBrightness? | no |
> 1456 | AFFineTune? | int8u | 0 = Off 1 = On
> 1552 | HDMIOutputResolution | int8u | 0 = Auto 1 = 4320p 2 = 2160p 3 = 1080p 5 = 720p
> 1565 | SetClockFromLocationData? | int8u | 0 = Off 1 = On
> 1572 | AirplaneMode? | int8u | 0 = Off 1 = On
> 1573 | EmptySlotRelease? | int8u | 0 = Disable Release 1 = Enable Release
> 1608 | EnergySavingMode? | int8u | 0 = Off 1 = On
> 1632 | RecordLocationData? | int8u | 0 = Off 1 = On
> 1636 | USBPowerDelivery? | int8u | 0 = Off 1 = On
> 1645 | SensorShield? | int8u | 0 = Stays Open 1 = Closes

## Nikon MenuSettingsZ9v3 Tags

These tags are used by the Z9 firmware 3.00.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 72 | HighFrameRate | int8u |
> 0 = Off 1 = CH 3 = C30 |  | 4 = C120 5 = C60 6 = C15
> 154 | MultipleExposureMode | int8u | 0 = Off 1 = On 2 = On (Series)
> 156 | MultiExposureShots | int8u |
> 204 | Intervals | int32u |
> 208 | ShotsPerInterval | int32u |
> 248 | FocusShiftNumberShots | int8u |
> 252 | FocusShiftStepWidth | int8u |
> 256 | FocusShiftInterval | int8u~ |
> 260 | FocusShiftExposureLock? | int8u | 0 = Off 1 = On
> 290 | PhotoShootingMenuBank | int8u | 0 = A 1 = B 2 = C 3 = D
> 292 | ExtendedMenuBanks | int8u | 0 = Off 1 = On
> 328 | PhotoShootingMenuBankImageArea | int8u | 0 = FX 1 = DX 4 = 16:9 8 = 1:1
> 342 | AutoISO | int8u | 0 = Off 1 = On
> 344 | ISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 346 | ISOAutoFlashLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 354 | ISOAutoShutterTime | no |
> -15 = Auto -12 = 15 s -9 = 8 s -6 = 4 s -3 = 2 s 0 = 1 s 1 = 1/1.3 s 2 = 1/1.6 s 3 = 1/2 s 4 = 1/2.5 s 5 = 1/3 s 6 = 1/4 s 7 = 1/5 s 8 = 1/6 s 9 = 1/8 s 10 = 1/10 s 11 = 1/13 s 12 = 1/15 s 13 = 1/20 s 14 = 1/25 s 15 = 1/30 s 16 = 1/40 s 17 = 1/50 s 18 = 1/60 s 19 = 1/80 s |  | 20 = 1/100 s 21 = 1/120 s 22 = 1/160 s 23 = 1/200 s 24 = 1/250 s 25 = 1/320 s 26 = 1/400 s 27 = 1/500 s 28 = 1/640 s 29 = 1/800 s 30 = 1/1000 s 31 = 1/1250 s 32 = 1/1600 s 33 = 1/2000 s 34 = 1/2500 s 35 = 1/3200 s 36 = 1/4000 s 37 = 1/5000 s 37.5 = 1/6000 s 38 = 1/6400 s 39 = 1/8000 s 40 = 1/10000 s 40.5 = 1/12000 s 41 = 1/13000 s 42 = 1/16000 s
> 436 | MovieVignetteControl? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 438 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 440 | FlickerReductionShooting | int8u | 0 = Off 1 = On
> 444 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 446 | FlashMasterCompensation? | int8s |
> 450 | FlashGNDistance? | no |
> 0 = 0 1 = 0.1 m 2 = 0.2 m 3 = 0.3 m 4 = 0.4 m 5 = 0.5 m 6 = 0.6 m 7 = 0.7 m 8 = 0.8 m 9 = 0.9 m 10 = 1.0 m 11 = 1.1 m 12 = 1.3 m |  | 13 = 1.4 m 14 = 1.6 m 15 = 1.8 m 16 = 2.0 m 17 = 2.2 m 18 = 2.5 m 19 = 2.8 m 20 = 3.2 m 21 = 3.6 m 22 = 4.0 m 23 = 4.5 m 24 = 5.0 m 25 = 5.6 m |  | 26 = 6.3 m 27 = 7.1 m 28 = 8.0 m 29 = 9.0 m 30 = 10.0 m 31 = 11.0 m 32 = 13.0 m 33 = 14.0 m 34 = 16.0 m 35 = 18.0 m 36 = 20.0 m 255 = n/a
> 454 | FlashOutput? | int8u |
> 548 | AFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 550 | VRMode | int8u | 0 = Off 1 = Normal 2 = Sport
> 554 | BracketSet | int8u | 0 = AE/Flash 1 = AE 2 = Flash 3 = White Balance 4 = Active-D Lighting
> 556 | BracketProgram | int8u | (AE and/or Flash Bracketing)
> 0 = Disabled 2 = 2F 3 = 3F 4 = 4F |  | 5 = 5F 7 = 7F 9 = 9F
> 558 | BracketIncrement | int8u | (AE and/or Flash Bracketing)
> 0 = 0.3 1 = 0.5 2 = 0.7 |  | 3 = 1.0 4 = 2.0 5 = 3.0 |  | 6 = 1.3 7 = 1.5 8 = 1.7 |  | 9 = 2.3 10 = 2.5 11 = 2.7
> 576 | SecondarySlotFunction | int8u | 0 = Overflow 1 = Backup 2 = NEF Primary + JPG Secondary 3 = JPG Primary + JPG Secondary
> 592 | DXCropAlert | int8u | 0 = Off 1 = On
> 594 | SubjectDetection | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 596 | DynamicAFAreaSize | int8u | 0 = Small 1 = Medium 2 = Large
> 636 | HighFrequencyFlickerReduction? | int8u | 0 = Off 1 = On
> 646 | MovieImageArea? | int8u | [val & 0x1] 0 = FX 1 = DX
> 656 | MovieType? | int8u |
> 1 = H.264 8-bit (MP4) 2 = H.265 8-bit (MOV) 3 = H.265 10-bit (MOV) 4 = ProRes 422 HQ 10-bit (MOV) 5 = ProRes RAW HQ 12-bit (MOV) 6 = NRAW 12-bit (NEV)
> 658 | MovieISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 660 | MovieISOAutoControlManualMode? | int8u | 0 = Off 1 = On
> 662 | MovieISOAutoManualMode? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 736 | MovieActiveD-Lighting? | int8u | 0 = Off 2 = Low 3 = Normal 4 = High 5 = Extra High
> 738 | MovieHighISONoiseReduction? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 744 | MovieFlickerReduction | int8u | 0 = Auto 1 = 50Hz 2 = 60Hz
> 746 | MovieMeteringMode? | int8u | 0 = Matrix 1 = Center 2 = Spot 3 = Highlight
> 748 | MovieFocusMode? | int8u | 0 = Manual 1 = AF-S 2 = AF-C 4 = AF-F
> 750 | MovieAFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 752 | MovieVRMode? | int8u | 0 = Off 1 = Normal 2 = Sport
> 756 | MovieElectronicVR? | int8u | 0 = Off 1 = On
> 758 | MovieSoundRecording? | int8u | 0 = Off 1 = Auto 2 = Manual
> 760 | MicrophoneSensitivity? | int8u |
> 762 | MicrophoneAttenuator? | int8u | 0 = Off 1 = On
> 764 | MicrophoneFrequencyResponse? | int8u | 0 = Wide Range 1 = Vocal Range
> 766 | WindNoiseReduction? | int8u | 0 = Off 1 = On
> 788 | MovieToneMap? | int8u | 0 = SDR 1 = HLG 2 = N-Log
> 794 | MovieFrameSize? | int8u | 1 = 1920x1080 2 = 3840x2160 3 = 7680x4320
> 796 | MovieFrameRate? | int8u |
> 0 = 120p 1 = 100p 2 = 60p 3 = 50p |  | 4 = 30p 5 = 25p 6 = 24p
> 802 | MicrophoneJackPower? | int8u | 0 = Off 1 = On
> 803 | MovieDXCropAlert? | int8u | 0 = Off 1 = On
> 804 | MovieSubjectDetection? | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 812 | MovieHighResZoom? | int8u | 0 = Off 1 = On
> 847 | CustomSettingsZ9 | - | --> NikonCustom SettingsZ9 Tags
> 1474 | Language? | int8u | 4 = English 5 = Spanish 7 = French 15 = Portuguese
> 1476 | TimeZone | int8u |
> 3 = +10:00 (Sydney) 5 = +09:00 (Tokyo) 6 = +08:00 (Beijing, Honk Kong, Sinapore) 10 = +05:45 (Kathmandu) 11 = +05:30 (New Dehli) 12 = +05:00 (Islamabad) 13 = +04:30 (Kabul) 14 = +04:00 (Abu Dhabi) 15 = +03:30 (Tehran) 16 = +03:00 (Moscow, Nairobi) 17 = +02:00 (Athens, Helsinki) 18 = +01:00 (Madrid, Paris, Berlin) 19 = +00:00 (London) 20 = -01:00 (Azores) 21 = -02:00 (Fernando de Noronha) 22 = -03:00 (Buenos Aires, Sao Paulo) 23 = -03:30 (Newfoundland) 24 = -04:00 (Manaus, Caracas) 25 = -05:00 (New York, Toronto, Lima) 26 = -06:00 (Chicago, Mexico City) 27 = -07:00 (Denver) 28 = -08:00 (Los Angeles, Vancouver) 29 = -09:00 (Anchorage) 30 = -10:00 (Hawaii)
> 1482 | MonitorBrightness? | int8u |
> 0 = -5 1 = -4 2 = -3 |  | 3 = -2 4 = -1 5 = 0 |  | 6 = 1 7 = 2 8 = 3 |  | 9 = 4 10 = 5 14 = Hi1 |  | 15 = Hi2 16 = Lo2 17 = Lo1
> 1504 | AFFineTune? | int8u | 0 = Off 1 = On
> 1600 | HDMIOutputResolution | int8u | 0 = Auto 1 = 4320p 2 = 2160p 3 = 1080p 5 = 720p
> 1613 | SetClockFromLocationData? | int8u | 0 = Off 1 = On
> 1620 | AirplaneMode? | int8u | 0 = Off 1 = On
> 1621 | EmptySlotRelease? | int8u | 0 = Disable Release 1 = Enable Release
> 1656 | EnergySavingMode? | int8u | 0 = Off 1 = On
> 1680 | RecordLocationData? | int8u | 0 = Off 1 = On
> 1684 | USBPowerDelivery? | int8u | 0 = Off 1 = On
> 1693 | SensorShield? | int8u | 0 = Stays Open 1 = Closes
> 1754 | FocusShiftAutoReset? | int8u | 0 = Off 1 = On
> 1810 | PreReleaseBurstLength | int8u | 0 = None 1 = 0.3 Sec 2 = 0.5 Sec 3 = 1 Sec
> 1812 | PostReleaseBurstLength | int8u | 0 = 1 Sec 1 = 2 Sec 2 = 3 Sec 3 = Max

## Nikon MenuSettingsZ9v4 Tags

These tags are used by the Z9 firmware 4.0.0 and 4.1.0

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 72 | HighFrameRate | int8u |
> 0 = Off 1 = CH 3 = C30 |  | 4 = C120 5 = C60 6 = C15
> 154 | MultipleExposureMode | int8u | 0 = Off 1 = On 2 = On (Series)
> 156 | MultiExposureShots | int8u |
> 204 | Intervals | int32u |
> 208 | ShotsPerInterval | int32u |
> 248 | FocusShiftNumberShots | int8u |
> 252 | FocusShiftStepWidth | int8u |
> 256 | FocusShiftInterval | int8u~ |
> 260 | FocusShiftExposureLock? | int8u | 0 = Off 1 = On
> 290 | PhotoShootingMenuBank | int8u | 0 = A 1 = B 2 = C 3 = D
> 292 | ExtendedMenuBanks | int8u | 0 = Off 1 = On
> 328 | PhotoShootingMenuBankImageArea | int8u | 0 = FX 1 = DX 4 = 16:9 8 = 1:1
> 342 | AutoISO | int8u | 0 = Off 1 = On
> 344 | ISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 346 | ISOAutoFlashLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 354 | ISOAutoShutterTime | no |
> -15 = Auto -12 = 15 s -9 = 8 s -6 = 4 s -3 = 2 s 0 = 1 s 1 = 1/1.3 s 2 = 1/1.6 s 3 = 1/2 s 4 = 1/2.5 s 5 = 1/3 s 6 = 1/4 s 7 = 1/5 s 8 = 1/6 s 9 = 1/8 s 10 = 1/10 s 11 = 1/13 s 12 = 1/15 s 13 = 1/20 s 14 = 1/25 s 15 = 1/30 s 16 = 1/40 s 17 = 1/50 s 18 = 1/60 s 19 = 1/80 s |  | 20 = 1/100 s 21 = 1/120 s 22 = 1/160 s 23 = 1/200 s 24 = 1/250 s 25 = 1/320 s 26 = 1/400 s 27 = 1/500 s 28 = 1/640 s 29 = 1/800 s 30 = 1/1000 s 31 = 1/1250 s 32 = 1/1600 s 33 = 1/2000 s 34 = 1/2500 s 35 = 1/3200 s 36 = 1/4000 s 37 = 1/5000 s 37.5 = 1/6000 s 38 = 1/6400 s 39 = 1/8000 s 40 = 1/10000 s 40.5 = 1/12000 s 41 = 1/13000 s 42 = 1/16000 s
> 436 | MovieVignetteControl? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 438 | DiffractionCompensation | int8u | 0 = Off 1 = On
> 440 | FlickerReductionShooting | int8u | 0 = Off 1 = On
> 444 | FlashControlMode | int8u | 0 = TTL 1 = Auto External Flash 2 = GN (distance priority) 3 = Manual 4 = Repeating Flash
> 446 | FlashMasterCompensation? | int8s |
> 450 | FlashGNDistance? | no |
> 0 = 0 1 = 0.1 m 2 = 0.2 m 3 = 0.3 m 4 = 0.4 m 5 = 0.5 m 6 = 0.6 m 7 = 0.7 m 8 = 0.8 m 9 = 0.9 m 10 = 1.0 m 11 = 1.1 m 12 = 1.3 m |  | 13 = 1.4 m 14 = 1.6 m 15 = 1.8 m 16 = 2.0 m 17 = 2.2 m 18 = 2.5 m 19 = 2.8 m 20 = 3.2 m 21 = 3.6 m 22 = 4.0 m 23 = 4.5 m 24 = 5.0 m 25 = 5.6 m |  | 26 = 6.3 m 27 = 7.1 m 28 = 8.0 m 29 = 9.0 m 30 = 10.0 m 31 = 11.0 m 32 = 13.0 m 33 = 14.0 m 34 = 16.0 m 35 = 18.0 m 36 = 20.0 m 255 = n/a
> 454 | FlashOutput? | int8u |
> 548 | AFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 550 | VRMode | int8u | 0 = Off 1 = Normal 2 = Sport
> 554 | BracketSet | int8u | 0 = AE/Flash 1 = AE 2 = Flash 3 = White Balance 4 = Active-D Lighting
> 556 | BracketProgram | int8u | (AE and/or Flash Bracketing)
> 0 = Disabled 2 = 2F 3 = 3F 4 = 4F |  | 5 = 5F 7 = 7F 9 = 9F
> 558 | BracketIncrement | int8u | (AE and/or Flash Bracketing)
> 0 = 0.3 1 = 0.5 2 = 0.7 |  | 3 = 1.0 4 = 2.0 5 = 3.0 |  | 6 = 1.3 7 = 1.5 8 = 1.7 |  | 9 = 2.3 10 = 2.5 11 = 2.7
> 570 | HDR | int8u | 0 = Off 1 = On 2 = On (Series)
> 576 | SecondarySlotFunction | int8u | 0 = Overflow 1 = Backup 2 = NEF Primary + JPG Secondary 3 = JPG Primary + JPG Secondary
> 582 | HDRLevel | int8u | 0 = Auto 1 = Extra High 2 = High 3 = Normal 4 = Low
> 586 | Slot2JpgSize? | int8u | 0 = Large (8256x5504) 1 = Medium (6192x4128) 2 = Small (4128x2752)
> 592 | DXCropAlert | int8u | 0 = Off 1 = On
> 594 | SubjectDetection | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 596 | DynamicAFAreaSize | int8u | 0 = Small 1 = Medium 2 = Large
> 636 | HighFrequencyFlickerReduction? | int8u | 0 = Off 1 = On
> 646 | MovieImageArea? | int8u | [val & 0x1] 0 = FX 1 = DX
> 656 | MovieType? | int8u |
> 1 = H.264 8-bit (MP4) 2 = H.265 8-bit (MOV) 3 = H.265 10-bit (MOV) 4 = ProRes 422 HQ 10-bit (MOV) 5 = ProRes RAW HQ 12-bit (MOV) 6 = NRAW 12-bit (NEV)
> 658 | MovieISOAutoHiLimit? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 660 | MovieISOAutoControlManualMode? | int8u | 0 = Off 1 = On
> 662 | MovieISOAutoManualMode? | int16u |
> 0 = ISO 64 1 = ISO 80 2 = ISO 100 3 = ISO 125 4 = ISO 160 5 = ISO 200 6 = ISO 250 7 = ISO 320 8 = ISO 400 9 = ISO 500 10 = ISO 640 11 = ISO 800 12 = ISO 1000 13 = ISO 1250 14 = ISO 1600 15 = ISO 2000 |  | 16 = ISO 2500 17 = ISO 3200 18 = ISO 4000 19 = ISO 5000 20 = ISO 6400 21 = ISO 8000 22 = ISO 10000 23 = ISO 12800 24 = ISO 16000 25 = ISO 20000 26 = ISO 25600 27 = ISO Hi 0.3 28 = ISO Hi 0.7 29 = ISO Hi 1.0 32 = ISO Hi 2.0
> 736 | MovieActiveD-Lighting? | int8u | 0 = Off 2 = Low 3 = Normal 4 = High 5 = Extra High
> 738 | MovieHighISONoiseReduction? | int8u | 0 = Off 1 = Low 2 = Normal 3 = High
> 744 | MovieFlickerReduction | int8u | 0 = Auto 1 = 50Hz 2 = 60Hz
> 746 | MovieMeteringMode? | int8u | 0 = Matrix 1 = Center 2 = Spot 3 = Highlight
> 748 | MovieFocusMode? | int8u | 0 = Manual 1 = AF-S 2 = AF-C 4 = AF-F
> 750 | MovieAFAreaMode | int8u |
> 0 = Pinpoint 1 = Single 2 = Dynamic 3 = Wide (S) 4 = Wide (L) |  | 5 = 3D 6 = Auto 11 = Subject Tracking 12 = Wide (C1) 13 = Wide (C2)
> 752 | MovieVRMode? | int8u | 0 = Off 1 = Normal 2 = Sport
> 756 | MovieElectronicVR? | int8u | 0 = Off 1 = On
> 758 | MovieSoundRecording? | int8u | 0 = Off 1 = Auto 2 = Manual
> 760 | MicrophoneSensitivity? | int8u |
> 762 | MicrophoneAttenuator? | int8u | 0 = Off 1 = On
> 764 | MicrophoneFrequencyResponse? | int8u | 0 = Wide Range 1 = Vocal Range
> 766 | WindNoiseReduction? | int8u | 0 = Off 1 = On
> 788 | MovieToneMap? | int8u | 0 = SDR 1 = HLG 2 = N-Log
> 794 | MovieFrameSize? | int8u | 1 = 1920x1080 2 = 3840x2160 3 = 7680x4320
> 796 | MovieFrameRate? | int8u |
> 0 = 120p 1 = 100p 2 = 60p 3 = 50p |  | 4 = 30p 5 = 25p 6 = 24p
> 802 | MicrophoneJackPower? | int8u | 0 = Off 1 = On
> 803 | MovieDXCropAlert? | int8u | 0 = Off 1 = On
> 804 | MovieSubjectDetection? | int8u |
> 0 = Off 1 = Auto 2 = People 3 = Animals |  | 4 = Vehicles 5 = Birds 6 = Airplanes
> 812 | MovieHighResZoom? | int8u | 0 = Off 1 = On
> 847 | CustomSettingsZ9v4 | - | --> NikonCustom SettingsZ9v4 Tags
> 1498 | Language? | int8u | 4 = English 5 = Spanish 7 = French 15 = Portuguese
> 1500 | TimeZone | int8u |
> 3 = +10:00 (Sydney) 5 = +09:00 (Tokyo) 6 = +08:00 (Beijing, Honk Kong, Sinapore) 10 = +05:45 (Kathmandu) 11 = +05:30 (New Dehli) 12 = +05:00 (Islamabad) 13 = +04:30 (Kabul) 14 = +04:00 (Abu Dhabi) 15 = +03:30 (Tehran) 16 = +03:00 (Moscow, Nairobi) 17 = +02:00 (Athens, Helsinki) 18 = +01:00 (Madrid, Paris, Berlin) 19 = +00:00 (London) 20 = -01:00 (Azores) 21 = -02:00 (Fernando de Noronha) 22 = -03:00 (Buenos Aires, Sao Paulo) 23 = -03:30 (Newfoundland) 24 = -04:00 (Manaus, Caracas) 25 = -05:00 (New York, Toronto, Lima) 26 = -06:00 (Chicago, Mexico City) 27 = -07:00 (Denver) 28 = -08:00 (Los Angeles, Vancouver) 29 = -09:00 (Anchorage) 30 = -10:00 (Hawaii)
> 1506 | MonitorBrightness? | int8u |
> 0 = -5 1 = -4 2 = -3 |  | 3 = -2 4 = -1 5 = 0 |  | 6 = 1 7 = 2 8 = 3 |  | 9 = 4 10 = 5 14 = Hi1 |  | 15 = Hi2 16 = Lo2 17 = Lo1
> 1528 | AFFineTune? | int8u | 0 = Off 1 = On
> 1532 | NonCPULens1FocalLength? | int16s~ |
> 1536 | NonCPULens2FocalLength? | int16s~ |
> 1540 | NonCPULens3FocalLength? | int16s~ |
> 1544 | NonCPULens4FocalLength? | int16s~ |
> 1548 | NonCPULens5FocalLength? | int16s~ |
> 1552 | NonCPULens6FocalLength? | int16s~ |
> 1556 | NonCPULens7FocalLength? | int16s~ |
> 1560 | NonCPULens8FocalLength? | int16s~ |
> 1564 | NonCPULens9FocalLength? | int16s~ |
> 1568 | NonCPULens10FocalLength? | int16s~ |
> 1572 | NonCPULens11FocalLength? | int16s~ |
> 1576 | NonCPULens12FocalLength? | int16s~ |
> 1580 | NonCPULens13FocalLength? | int16s~ |
> 1584 | NonCPULens14FocalLength? | int16s~ |
> 1588 | NonCPULens15FocalLength? | int16s~ |
> 1592 | NonCPULens16FocalLength? | int16s~ |
> 1596 | NonCPULens17FocalLength? | int16s~ |
> 1600 | NonCPULens18FocalLength? | int16s~ |
> 1604 | NonCPULens19FocalLength? | int16s~ |
> 1608 | NonCPULens20FocalLength? | int16s~ |
> 1612 | NonCPULens1MaxAperture? | int16s~ |
> 1616 | NonCPULens2MaxAperture? | int16s~ |
> 1620 | NonCPULens3MaxAperture? | int16s~ |
> 1624 | NonCPULens4MaxAperture? | int16s~ |
> 1628 | NonCPULens5MaxAperture? | int16s~ |
> 1632 | NonCPULens6MaxAperture? | int16s~ |
> 1636 | NonCPULens7MaxAperture? | int16s~ |
> 1640 | NonCPULens8MaxAperture? | int16s~ |
> 1644 | NonCPULens9MaxAperture? | int16s~ |
> 1648 | NonCPULens10MaxAperture? | int16s~ |
> 1652 | NonCPULens11MaxAperture? | int16s~ |
> 1656 | NonCPULens12MaxAperture? | int16s~ |
> 1660 | NonCPULens13MaxAperture? | int16s~ |
> 1664 | NonCPULens14MaxAperture? | int16s~ |
> 1668 | NonCPULens15MaxAperture? | int16s~ |
> 1672 | NonCPULens16MaxAperture? | int16s~ |
> 1676 | NonCPULens17MaxAperture? | int16s~ |
> 1680 | NonCPULens18MaxAperture? | int16s~ |
> 1684 | NonCPULens19MaxAperture? | int16s~ |
> 1688 | NonCPULens20MaxAperture? | int16s~ |
> 1704 | HDMIOutputResolution | int8u | 0 = Auto 1 = 4320p 2 = 2160p 3 = 1080p 5 = 720p
> 1717 | SetClockFromLocationData? | int8u | 0 = Off 1 = On
> 1724 | AirplaneMode? | int8u | 0 = Off 1 = On
> 1725 | EmptySlotRelease? | int8u | 0 = Disable Release 1 = Enable Release
> 1760 | EnergySavingMode? | int8u | 0 = Off 1 = On
> 1784 | RecordLocationData? | int8u | 0 = Off 1 = On
> 1788 | USBPowerDelivery? | int8u | 0 = Off 1 = On
> 1797 | SensorShield? | int8u | 0 = Stays Open 1 = Closes
> 1862 | AutoCapturePreset | int8u | 0 = 1 1 = 2 2 = 3 3 = 4 4 = 5
> 1864 | FocusShiftAutoReset? | int8u | 0 = Off 1 = On
> 1922 | PreReleaseBurstLength | int8u | 0 = None 1 = 0.3 Sec 2 = 0.5 Sec 3 = 1 Sec
> 1924 | PostReleaseBurstLength | int8u | 0 = 1 Sec 1 = 2 Sec 2 = 3 Sec 3 = Max
> 1938 | VerticalISOButton | int8u | --> Nikon ButtonsZ9 Values
> 1940 | ExposureCompensationButton | int8u | --> Nikon ButtonsZ9 Values
> 1942 | ISOButton | int8u | --> Nikon ButtonsZ9 Values
> 2002 | ViewModeShowEffectsOfSettings? | int8u | 0 = Always 1 = Only When Flash Not Used
> 2004 | DispButton | int8u | --> Nikon ButtonsZ9 Values
> 2048 | ExposureDelay | fixed32u~ |
> 2052 | CommandDialFrameAdvanceZoom? | int8u | 0 = Hold 1 = Focus Point 2 = Face Priority
> 2054 | SubCommandDialFrameAdvanceZoom? | int8u | 0 = Hold 1 = Focus Point 2 = Face Priority
> 2056 | PlaybackButton | int8u | --> Nikon ButtonsZ9 Values
> 2058 | WBButton | int8u | --> Nikon ButtonsZ9 Values
> 2060 | BracketButton | int8u | --> Nikon ButtonsZ9 Values
> 2062 | FlashModeButton | int8u | --> Nikon ButtonsZ9 Values
> 2064 | LensFunc1ButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2066 | LensFunc2ButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2068 | PlaybackButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2070 | BracketButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values
> 2072 | FlashModeButtonPlaybackMode | int8u | --> Nikon ButtonsZ9 Values

## Nikon ShotInfo Tags

This information is encrypted for ShotInfoVersion 02xx, and some tags are only valid for specific models.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ShotInfoVersion | no |
> 4 | FirmwareVersion | no |
> 16 | DistortionControl | int8u | (P6000) 0 = Off 1 = On
> 102 | VR_0x66? | int8u | (D2X, D2Xs (unverified)) 0 = Off 1 = On (normal) 2 = On (active)
> 106 | ShutterCount | int32u | (D2X, D2Xs)
> 110 | DeletedImageCount | int32u | (D2X, D2Xs)
> 117 | VibrationReduction | int8u | (D200) 0 = Off 1 = On (1) 2 = On (2) 3 = On (3)
> 130 | VibrationReduction | int8u | (D2X, D2Xs) 0 = Off 1 = On
> 343 | ShutterCount | undef[2] | (D50)
> 430 | VibrationReduction | int8u | (D50) 0x0 = n/a 0xc = Off 0xf = On
> 589 | ShutterCount | int32u | (D60)

## Nikon ColorBalance1 Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | WB_RBGGLevels | int16u[4]! |

## Nikon ColorBalance2 Tags

This information is encrypted for most camera models.

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | WB_RGGBLevels | int16u[4]! |

## Nikon ColorBalance3 Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | WB_RGBGLevels | int16u[4]! |

## Nikon ColorBalance4 Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | WB_GRBGLevels | int16u[4]! |

## Nikon ColorBalanceUnknown Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ColorBalanceVersion | undef[4] |

## Nikon ColorBalanceUnknown2 Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ColorBalanceVersion | undef[4] |

## Nikon LensData00 Tags

This structure is used by the D100, and D1X with firmware version 1.1.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 6 | LensIDNumber | int8u | (see LensID values below)
> 7 | LensFStops | int8u |
> 8 | MinFocalLength | int8u |
> 9 | MaxFocalLength | int8u |
> 10 | MaxApertureAtMinFocal | int8u |
> 11 | MaxApertureAtMaxFocal | int8u |
> 12 | MCUVersion | int8u |

## Nikon LensData01 Tags

Nikon encrypts the LensData information below if LensDataVersion is 0201 or higher, but the decryption algorithm is known so the information can be extracted.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 4 | ExitPupilPosition | int8u |
> 5 | AFAperture | int8u |
> 8 | FocusPosition | int8u |
> 9 | FocusDistance | int8u | (this focus distance is approximate, and not very accurate for some lenses)
> 10 | FocalLength | int8u |
> 11 | LensIDNumber | int8u | (see LensID values below)
> 12 | LensFStops | int8u |
> 13 | MinFocalLength | int8u |
> 14 | MaxFocalLength | int8u |
> 15 | MaxApertureAtMinFocal | int8u |
> 16 | MaxApertureAtMaxFocal | int8u |
> 17 | MCUVersion | int8u |
> 18 | EffectiveMaxAperture | int8u |

## Nikon LensData0204 Tags

Nikon encrypts the LensData information below if LensDataVersion is 0201 or higher, but the decryption algorithm is known so the information can be extracted.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 4 | ExitPupilPosition | int8u |
> 5 | AFAperture | int8u |
> 8 | FocusPosition | int8u |
> 10 | FocusDistance | int8u | (this focus distance is approximate, and not very accurate for some lenses)
> 11 | FocalLength | int8u |
> 12 | LensIDNumber | int8u | (see LensID values below)
> 13 | LensFStops | int8u |
> 14 | MinFocalLength | int8u |
> 15 | MaxFocalLength | int8u |
> 16 | MaxApertureAtMinFocal | int8u |
> 17 | MaxApertureAtMaxFocal | int8u |
> 18 | MCUVersion | int8u |
> 19 | EffectiveMaxAperture | int8u |

## Nikon LensData0400 Tags

Tags extracted from the encrypted lens data of the Nikon 1J1/1V1/1J2.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 394 | LensModel | string[64] |

## Nikon LensData0402 Tags

Tags extracted from the encrypted lens data of the Nikon 1J3/1S1/1V2.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 395 | LensModel | string[64] |

## Nikon LensData0403 Tags

Tags extracted from the encrypted lens data of the Nikon 1J4/1J5.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 684 | LensModel | string[64] |

## Nikon LensData0800 Tags

Tags found in the encrypted LensData from cameras such as the Z6 and Z7.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |
> 4 | ExitPupilPosition | int8u |
> 5 | AFAperture | int8u |
> 11 | FocusDistance | int8u | (this focus distance is approximate, and not very accurate for some lenses)
> 12 | FocalLength | int8u |
> 13 | LensIDNumber | int8u | (see LensID values below)
> 14 | LensFStops | int8u |
> 15 | MinFocalLength | int8u |
> 16 | MaxFocalLength | int8u |
> 17 | MaxApertureAtMinFocal | int8u |
> 18 | MaxApertureAtMaxFocal | int8u |
> 19 | MCUVersion | int8u |
> 20 | EffectiveMaxAperture | int8u |
> 47 | NewLensData | undef[17] |
> 48 | LensID | int16u | (tags from here onward used for Nikkor Z lenses only)
> 1 = Nikkor Z 24-70mm f/4 S 2 = Nikkor Z 14-30mm f/4 S 4 = Nikkor Z 35mm f/1.8 S 8 = Nikkor Z 58mm f/0.95 S Noct 9 = Nikkor Z 50mm f/1.8 S 11 = Nikkor Z DX 16-50mm f/3.5-6.3 VR 12 = Nikkor Z DX 50-250mm f/4.5-6.3 VR 13 = Nikkor Z 24-70mm f/2.8 S 14 = Nikkor Z 85mm f/1.8 S 15 = Nikkor Z 24mm f/1.8 S 16 = Nikkor Z 70-200mm f/2.8 VR S 17 = Nikkor Z 20mm f/1.8 S 18 = Nikkor Z 24-200mm f/4-6.3 VR 21 = Nikkor Z 50mm f/1.2 S 22 = Nikkor Z 24-50mm f/4-6.3 23 = Nikkor Z 14-24mm f/2.8 S 24 = Nikkor Z MC 105mm f/2.8 VR S 25 = Nikkor Z 40mm f/2 26 = Nikkor Z DX 18-140mm f/3.5-6.3 VR 27 = Nikkor Z MC 50mm f/2.8 28 = Nikkor Z 100-400mm f/4.5-5.6 VR S 29 = Nikkor Z 28mm f/2.8 30 = Nikkor Z 400mm f/2.8 TC VR S 31 = Nikkor Z 24-120mm f/4 S 32 = Nikkor Z 800mm f/6.3 VR S 35 = Nikkor Z 28-75mm f/2.8 36 = Nikkor Z 400mm f/4.5 VR S 37 = Nikkor Z 600mm f/4 TC VR S 38 = Nikkor Z 85mm f/1.2 S 39 = Nikkor Z 17-28mm f/2.8 40 = Nikkor Z 26mm f/2.8 41 = Nikkor Z DX 12-28mm f/3.5-5.6 PZ VR 42 = Nikkor Z 180-600mm f/5.6-6.3 VR 43 = Nikkor Z DX 24mm f/1.7 44 = Nikkor Z 70-180mm f/2.8 45 = Nikkor Z 600mm f/6.3 VR S 46 = Nikkor Z 135mm f/1.8 S Plena 48 = Nikkor Z 28-400mm f/4-8 VR 32768 = Nikkor Z 400mm f/2.8 TC VR S TC-1.4x 32769 = Nikkor Z 600mm f/4 TC VR S TC-1.4x
> 53 | LensMountType | int8u | 0 = F-mount Lens 1 = Z-mount Lens
> 54 | MaxAperture | int16u |
> 56 | FNumber | int16u |
> 60 | FocalLength | int16u |
> 76 | FocusDistanceRangeWidth? | int8u |
> 78 | FocusDistance | int16u~ |
> 86 | LensDriveEnd? | int8u |
> 88 | FocusStepsFromInfinity? | int8u |
> 90 | LensPositionAbsolute | int32s |

## Nikon LensDataUnknown Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | LensDataVersion | no |

## Nikon FlashInfo0100 Tags

These tags are used by the D2H, D2Hs, D2X, D2Xs, D50, D70, D70s, D80 and D200.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |
> 4 | FlashSource | int8u | 0 = None 1 = External 2 = Internal
> 6 | ExternalFlashFirmware | int8u[2] | --> Nikon FlashFirmware Values
> 8 | ExternalFlashFlags | int8u | 0x0 = (none) Bit 0 = Fired Bit 2 = Bounce Flash Bit 4 = Wide Flash Adapter Bit 5 = Dome Diffuser
> 9.1 | FlashCommanderMode | int8u | [val >> 7 & 0x1] 0 = Off 1 = On
> 9.2 | FlashControlMode | int8u | [val & 0x7f] --> Nikon FlashControlMode Values
> 10 | FlashOutput FlashCompensation | int8u int8s |
> 11 | FlashFocalLength | int8u |
> 12 | RepeatingFlashRate | int8u |
> 13 | RepeatingFlashCount | int8u |
> 14 | FlashGNDistance | int8u | --> Nikon FlashGNDistance Values
> 15 | FlashGroupAControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values
> 16 | FlashGroupBControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values
> 17 | FlashGroupAOutput FlashGroupACompensation | int8u int8s |
> 18 | FlashGroupBOutput FlashGroupBCompensation | int8u int8s |

## Nikon FlashFirmware Values

> Value | FlashFirmware | Value | FlashFirmware
> --- | --- | --- | ---
> '0 0' | = n/a | '4 2' | = 4.02 (SB-400)
> '1 1' | = 1.01 (SB-800 or Metz 58 AF-1) | '4 4' | = 4.04 (SB-400)
> '1 3' | = 1.03 (SB-800) | '5 1' | = 5.01 (SB-900)
> '2 1' | = 2.01 (SB-800) | '5 2' | = 5.02 (SB-900)
> '2 4' | = 2.04 (SB-600) | '6 1' | = 6.01 (SB-700)
> '2 5' | = 2.05 (SB-600) | '7 1' | = 7.01 (SB-910)
> '3 1' | = 3.01 (SU-800 Remote Commander) | '14 3' | = 14.03 (SB-5000)
> '4 1' | = 4.01 (SB-400) |  |

## Nikon FlashControlMode Values

> Value | FlashControlMode | Value | FlashControlMode | Value | FlashControlMode
> --- | --- | --- | --- | --- | ---
> 0 | = Off | 3 | = Auto Aperture | 6 | = Manual
> 1 | = iTTL-BL | 4 | = Automatic | 7 | = Repeating Flash
> 2 | = iTTL | 5 | = GN (distance priority) |  |

## Nikon FlashGNDistance Values

> Value | FlashGNDistance | Value | FlashGNDistance | Value | FlashGNDistance
> --- | --- | --- | --- | --- | ---
> 0 | = 0 | 13 | = 1.4 m | 26 | = 6.3 m
> 1 | = 0.1 m | 14 | = 1.6 m | 27 | = 7.1 m
> 2 | = 0.2 m | 15 | = 1.8 m | 28 | = 8.0 m
> 3 | = 0.3 m | 16 | = 2.0 m | 29 | = 9.0 m
> 4 | = 0.4 m | 17 | = 2.2 m | 30 | = 10.0 m
> 5 | = 0.5 m | 18 | = 2.5 m | 31 | = 11.0 m
> 6 | = 0.6 m | 19 | = 2.8 m | 32 | = 13.0 m
> 7 | = 0.7 m | 20 | = 3.2 m | 33 | = 14.0 m
> 8 | = 0.8 m | 21 | = 3.6 m | 34 | = 16.0 m
> 9 | = 0.9 m | 22 | = 4.0 m | 35 | = 18.0 m
> 10 | = 1.0 m | 23 | = 4.5 m | 36 | = 20.0 m
> 11 | = 1.1 m | 24 | = 5.0 m | 255 | = n/a
> 12 | = 1.3 m | 25 | = 5.6 m |  |

## Nikon FlashInfo0102 Tags

These tags are used by the D3 (firmware 1.x), D40, D40X, D60 and D300 (firmware 1.00).

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |
> 4 | FlashSource | int8u | 0 = None 1 = External 2 = Internal
> 6 | ExternalFlashFirmware | int8u[2] | --> Nikon FlashFirmware Values
> 8 | ExternalFlashFlags | int8u | Bit 0 = Fired Bit 2 = Bounce Flash Bit 4 = Wide Flash Adapter Bit 5 = Dome Diffuser
> 9.1 | FlashCommanderMode | int8u | [val >> 7 & 0x1] 0 = Off 1 = On
> 9.2 | FlashControlMode | int8u | [val & 0x7f] --> Nikon FlashControlMode Values
> 10 | FlashOutput FlashCompensation | int8u int8s |
> 12 | FlashFocalLength | int8u |
> 13 | RepeatingFlashRate | int8u |
> 14 | RepeatingFlashCount | int8u |
> 15 | FlashGNDistance | int8u | --> Nikon FlashGNDistance Values
> 16.1 | FlashGroupAControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group A tags may apply to the built-in flash settings for some models)
> 17.1 | FlashGroupBControlMode | int8u | [val >> 4 & 0xf] --> Nikon FlashControlMode Values (note: group B tags may apply to group A settings for some models)
> 17.2 | FlashGroupCControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group C tags may apply to group B settings for some models)
> 18 | FlashGroupAOutput FlashGroupACompensation | int8u int8s |
> 19 | FlashGroupBOutput FlashGroupBCompensation | int8u int8s |
> 20 | FlashGroupCOutput FlashGroupCCompensation | int8u int8s |

## Nikon FlashInfo0103 Tags

These tags are used by the D3 (firmware 2.x), D3X, D3S, D4, D90, D300 (firmware 1.10), D300S, D600, D700, D800, D3000, D3100, D3200, D5000, D5100, D5200, D7000.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |
> 4 | FlashSource | int8u | 0 = None 1 = External 2 = Internal
> 6 | ExternalFlashFirmware | int8u[2] | --> Nikon FlashFirmware Values
> 8 | ExternalFlashFlags | int8u | Bit 0 = Fired Bit 2 = Bounce Flash Bit 4 = Wide Flash Adapter Bit 5 = Dome Diffuser
> 9.1 | FlashCommanderMode | int8u | [val >> 7 & 0x1] 0 = Off 1 = On
> 9.2 | FlashControlMode | int8u | [val & 0x7f] --> Nikon FlashControlMode Values
> 10 | FlashOutput FlashCompensation | int8u int8s |
> 12 | FlashFocalLength | int8u |
> 13 | RepeatingFlashRate | int8u |
> 14 | RepeatingFlashCount | int8u |
> 15 | FlashGNDistance | int8u | --> Nikon FlashGNDistance Values
> 16 | FlashColorFilter | int8u | --> Nikon FlashColorFilter Values
> 17.1 | FlashGroupAControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group A tags may apply to the built-in flash settings for some models)
> 18.1 | FlashGroupBControlMode | int8u | [val >> 4 & 0xf] --> Nikon FlashControlMode Values (note: group B tags may apply to group A settings for some models)
> 18.2 | FlashGroupCControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group C tags may apply to group B settings for some models)
> 19 | FlashGroupAOutput FlashGroupACompensation | int8u int8s |
> 20 | FlashGroupBOutput FlashGroupBCompensation | int8u int8s |
> 21 | FlashGroupCOutput FlashGroupCCompensation | int8u int8s |
> 27 | ExternalFlashCompensation | int8s |
> 29 | FlashExposureComp3 | int8s | (does not include the effect of flash bracketing)
> 39 | FlashExposureComp4 | int8s | (includes the effect of flash bracketing. Valid for repeating flash)

## Nikon FlashColorFilter Values

> Value | FlashColorFilter | Value | FlashColorFilter | Value | FlashColorFilter
> --- | --- | --- | --- | --- | ---
> 0 | = None | 10 | = TN-A2 | 68 | = Amber
> 1 | = FL-GL1 or SZ-2FL Fluorescent | 65 | = Red | 128 | = Incandescent
> 2 | = FL-GL2 | 66 | = Blue |  |
> 9 | = TN-A1 or SZ-2TN Incandescent | 67 | = Yellow |  |

## Nikon FlashInfo0106 Tags

These tags are used by the Df, D610, D3300, D5300, D7100 and Coolpix A.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |
> 4 | FlashSource | int8u | 0 = None 1 = External 2 = Internal
> 6 | ExternalFlashFirmware | int8u[2] | --> Nikon FlashFirmware Values
> 8 | ExternalFlashFlags | int8u | Bit 0 = Fired Bit 2 = Bounce Flash Bit 4 = Wide Flash Adapter Bit 5 = Dome Diffuser
> 9.1 | FlashCommanderMode | int8u | [val >> 7 & 0x1] 0 = Off 1 = On
> 9.2 | FlashControlMode | int8u | [val & 0x7f] --> Nikon FlashControlMode Values
> 12 | FlashFocalLength | int8u | (only valid if flash pattern is "Standard Illumination")
> 13 | RepeatingFlashRate | int8u |
> 14 | RepeatingFlashCount | int8u |
> 15 | FlashGNDistance | int8u | --> Nikon FlashGNDistance Values
> 16 | FlashColorFilter | int8u | --> Nikon FlashColorFilter Values
> 17.1 | FlashGroupAControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values
> 18.1 | FlashGroupBControlMode | int8u | [val >> 4 & 0xf] --> Nikon FlashControlMode Values
> 18.2 | FlashGroupCControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values
> 39 | FlashOutput FlashCompensation | int8u int8s |
> 40 | FlashGroupAOutput FlashGroupACompensation | int8u int8s |
> 41 | FlashGroupBOutput FlashGroupBCompensation | int8u int8s |
> 42 | FlashGroupCOutput FlashGroupCCompensation | int8u int8s |

## Nikon FlashInfo0107 Tags

These tags are used by the D4S, D750, D810, D5500, D7200 (FlashInfoVersion 0107) and the D5, D500, D850 and D3400 (FlashInfoVersion 0108).

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |
> 4 | FlashSource | int8u | 0 = None 1 = External 2 = Internal
> 6 | ExternalFlashFirmware | int8u[2] | --> Nikon FlashFirmware Values
> 8.1 | ExternalFlashZoomOverride | int8u | (indicates that the user has overridden the flash zoom distance) [val >> 7 & 0x1] 0 = No 1 = Yes
> 8.2 | ExternalFlashStatus | int8u | [val & 0x1] 0 = Flash Not Attached 1 = Flash Attached
> 9.1 | ExternalFlashReadyState | int8u | [val & 0x7] 0 = n/a 1 = Ready 6 = Not Ready
> 10 | FlashCompensation | int8s |
> 12 | FlashFocalLength | int8u | (only valid if flash pattern is "Standard Illumination")
> 13 | RepeatingFlashRate | int8u |
> 14 | RepeatingFlashCount | int8u |
> 15 | FlashGNDistance | int8u | --> Nikon FlashGNDistance Values
> 17.1 | FlashGroupAControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group A tags may apply to the built-in flash settings for some models)
> 18.1 | FlashGroupBControlMode | int8u | [val >> 4 & 0xf] --> Nikon FlashControlMode Values (note: group B tags may apply to group A settings for some models)
> 18.2 | FlashGroupCControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group C tags may apply to group B settings for some models)
> 40 | FlashGroupAOutput FlashGroupACompensation | int8u int8s |
> 41 | FlashGroupBOutput FlashGroupBCompensation | int8u int8s |
> 42 | FlashGroupCOutput FlashGroupCCompensation | int8u int8s |

## Nikon FlashInfo0300 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |
> 4 | FlashSource | int8u | 0 = None 1 = External 2 = Internal
> 6 | ExternalFlashFirmware | int8u[2] | --> Nikon FlashFirmware Values
> 8 | ExternalFlashFlags | int8u | Bit 0 = Flash Ready Bit 2 = Bounce Flash Bit 4 = Wide Flash Adapter Bit 7 = Zoom Override
> 9.1 | FlashCommanderMode | int8u | [val >> 7 & 0x1] 0 = Off 1 = On
> 9.2 | FlashControlMode | int8u | [val & 0x7f] --> Nikon FlashControlMode Values
> 10 | FlashCompensation | int8s |
> 13 | RepeatingFlashRate | int8u |
> 14 | RepeatingFlashCount | int8u |
> 15 | FlashGNDistance | int8u | --> Nikon FlashGNDistance Values
> 16 | FlashColorFilter | int8u | --> Nikon FlashColorFilter Values
> 17.1 | FlashGroupAControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group A tags may apply to the built-in flash settings for some models)
> 18.1 | FlashGroupBControlMode | int8u | [val >> 4 & 0xf] --> Nikon FlashControlMode Values (note: group B tags may apply to group A settings for some models)
> 18.2 | FlashGroupCControlMode | int8u | [val & 0xf] --> Nikon FlashControlMode Values (note: group C tags may apply to group B settings for some models)
> 33 | FlashOutput | int8u |
> 37 | FlashIlluminationPattern | int8u | 0 = Standard 1 = Center-weighted 2 = Even
> 38 | FlashFocalLength | int8u | (only valid if flash pattern is "Standard Illumination")
> 40 | FlashGroupAOutput FlashGroupACompensation | int8u int8s |
> 41 | FlashGroupBOutput FlashGroupBCompensation | int8u int8s |
> 42 | FlashGroupCOutput FlashGroupCCompensation | int8u int8s |

## Nikon FlashInfoUnknown Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FlashInfoVersion | no |

## Nikon MultiExposure Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | MultiExposureVersion | no |
> 1 | MultiExposureMode | int32u | 0 = Off 1 = Multiple Exposure 2 = Image Overlay 3 = HDR
> 2 | MultiExposureShots | int32u |
> 3 | MultiExposureAutoGain | int32u | 0 = Off 1 = On

## Nikon MultiExposure2 Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | MultiExposureVersion | no |
> 1 | MultiExposureMode | int32u | 0 = Off 1 = Multiple Exposure 3 = HDR
> 2 | MultiExposureShots | int32u |
> 3 | MultiExposureOverlayMode | int32u | 0 = Add 1 = Average 2 = Light 3 = Dark

## Nikon AFInfo2V0400 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | AFInfo2Version | no |
> 5 | AFAreaMode | int8u |
> 192 = Pinpoint 193 = Single 195 = Wide (S) 196 = Wide (L) 197 = Auto |  | 204 = Dynamic Area (S) 205 = Dynamic Area (M) 206 = Dynamic Area (L) 207 = 3D-tracking 208 = Wide (C1/C2)
> 10 | AFPointsUsed | undef[51] |
> 62 | AFImageWidth | int16u |
> 64 | AFImageHeight | int16u |
> 66 | AFAreaXPosition | int16u |
> 67 | FocusPositionHorizontal | int8u~ | (the focus points form a 29x17 grid, but the X,Y coordinate values run from 1,1 to 30,19. The horizontal coordinate 11R (5) and the vertical coordinates 6U (4) and 2D (12) are not used for some reason)
> 68 | AFAreaYPosition | int16u |
> 69 | FocusPositionVertical | int8u~ |
> 70 | AFAreaWidth | int16u | (size of AF area in AFImage pixels)
> 72 | AFAreaHeight | int16u |
> 74 | FocusResult | int8u | 0 = Out of Focus 1 = Focus

## Nikon AFInfo2 Tags

These tags are written by Nikon DSLR's which have the live view feature.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | AFInfo2Version | no |
> 4 | ContrastDetectAF | int8u | (this is Off for the hybrid AF used in Nikon 1 models) 0 = Off 1 = On 2 = On (2)
> 5 | AFAreaMode | int8u | (ContrastDetectAF Off)
> 0 = Single Area 1 = Dynamic Area 2 = Dynamic Area (closest subject) 3 = Group Dynamic 4 = Dynamic Area (9 points) 5 = Dynamic Area (21 points) 6 = Dynamic Area (51 points) 7 = Dynamic Area (51 points, 3D-tracking) 8 = Auto-area 9 = Dynamic Area (3D-tracking) 10 = Single Area (wide) 11 = Dynamic Area (wide) 12 = Dynamic Area (wide, 3D-tracking) 13 = Group Area 14 = Dynamic Area (25 points) 15 = Dynamic Area (72 points) 16 = Group Area (HL) 17 = Group Area (VL) 18 = Dynamic Area (49 points) 128 = Single 129 = Auto (41 points) 130 = Subject Tracking (41 points) 131 = Face Priority (41 points) 192 = Pinpoint 193 = Single 195 = Wide (S) 196 = Wide (L) 197 = Auto
> (ContrastDetectAF On)
> 0 = Contrast-detect 1 = Contrast-detect (normal area) 2 = Contrast-detect (wide area) 3 = Contrast-detect (face priority) 4 = Contrast-detect (subject tracking) 128 = Single 129 = Auto (41 points) 130 = Subject Tracking (41 points) 131 = Face Priority (41 points) 192 = Pinpoint 193 = Single 194 = Dynamic 195 = Wide (S) 196 = Wide (L) 197 = Auto 198 = Auto (People) 199 = Auto (Animal) 200 = Normal-area AF 201 = Wide-area AF 202 = Face-priority AF 203 = Subject-tracking AF 204 = Dynamic Area (S) 205 = Dynamic Area (M) 206 = Dynamic Area (L) 207 = 3D-tracking 208 = Wide-Area (C1/C2)
> 6 | PhaseDetectAF | int8u | (PrimaryAFPoint and AFPointsUsed below are only valid when this is On)
> 0 = Off 1 = On (51-point) 2 = On (11-point) 3 = On (39-point) 4 = On (73-point) |  | 5 = On (5) 6 = On (105-point) 7 = On (153-point) 8 = On (81-point) 9 = On (105-point)
> 7 | PrimaryAFPoint | int8u | (models with 51-point AF -- 5 rows (A-E) and 11 columns (1-11): D3, D3S, D3X, D4, D4S, D300, D300S, D700, D800, D800e and D810)
> 0 = (none) 1 = C6 (Center) 2 = B6 3 = A5 4 = D6 5 = E5 6 = C7 7 = B7 8 = A6 9 = D7 10 = E6 |  | 11 = C5 12 = B5 13 = A4 14 = D5 15 = E4 16 = C8 17 = B8 18 = A7 19 = D8 20 = E7 21 = C9 |  | 22 = B9 23 = A8 24 = D9 25 = E8 26 = C10 27 = B10 28 = A9 29 = D10 30 = E9 31 = C11 32 = B11 |  | 33 = D11 34 = C4 35 = B4 36 = A3 37 = D4 38 = E3 39 = C3 40 = B3 41 = A2 42 = D3 43 = E2 |  | 44 = C2 45 = B2 46 = A1 47 = D2 48 = E1 49 = C1 50 = B1 51 = D1
> (models with 11-point AF: D90, D3000, D3100, D5000 and D5100)
> 0 = (none) 1 = Center 2 = Top 3 = Bottom 4 = Mid-left 5 = Upper-left |  | 6 = Lower-left 7 = Far Left 8 = Mid-right 9 = Upper-right 10 = Lower-right 11 = Far Right
> (models with 39-point AF: D600 and D7000)
> 0 = (none) 1 = C6 (Center) 2 = B6 3 = A2 4 = D6 5 = E2 6 = C7 7 = B7 |  | 8 = A3 9 = D7 10 = E3 11 = C5 12 = B5 13 = A1 14 = D5 15 = E1 |  | 16 = C8 17 = B8 18 = D8 19 = C9 20 = B9 21 = D9 22 = C10 23 = B10 |  | 24 = D10 25 = C11 26 = B11 27 = D11 28 = C4 29 = B4 30 = D4 31 = C3 |  | 32 = B3 33 = D3 34 = C2 35 = B2 36 = D2 37 = C1 38 = B1 39 = D1
> (Nikon 1 models with older 135-point AF and 73-point phase-detect AF)
> 0 = (none) 1 = E8 (Center) 2 = D8 3 = C8 4 = B8 5 = A8 6 = F8 7 = G8 8 = H8 9 = I8 10 = E9 11 = D9 12 = C9 13 = B9 14 = A9 15 = F9 16 = G9 17 = H9 18 = I9 19 = E7 20 = D7 21 = C7 22 = B7 23 = A7 24 = F7 25 = G7 26 = H7 27 = I7 |  | 28 = E10 29 = D10 30 = C10 31 = B10 32 = A10 33 = F10 34 = G10 35 = H10 36 = I10 37 = E11 38 = D11 39 = C11 40 = B11 41 = A11 42 = F11 43 = G11 44 = H11 45 = I11 46 = E12 47 = D12 48 = C12 49 = B12 50 = A12 51 = F12 52 = G12 53 = H12 54 = I12 55 = E13 |  | 56 = D13 57 = C13 58 = B13 59 = A13 60 = F13 61 = G13 62 = H13 63 = I13 64 = E14 65 = D14 66 = C14 67 = B14 68 = A14 69 = F14 70 = G14 71 = H14 72 = I14 73 = E15 74 = D15 75 = C15 76 = B15 77 = A15 78 = F15 79 = G15 80 = H15 81 = I15 82 = E6 83 = D6 |  | 84 = C6 85 = B6 86 = A6 87 = F6 88 = G6 89 = H6 90 = I6 91 = E5 92 = D5 93 = C5 94 = B5 95 = A5 96 = F5 97 = G5 98 = H5 99 = I5 100 = E4 101 = D4 102 = C4 103 = B4 104 = A4 105 = F4 106 = G4 107 = H4 108 = I4 109 = E3 110 = D3 111 = C3 |  | 112 = B3 113 = A3 114 = F3 115 = G3 116 = H3 117 = I3 118 = E2 119 = D2 120 = C2 121 = B2 122 = A2 123 = F2 124 = G2 125 = H2 126 = I2 127 = E1 128 = D1 129 = C1 130 = B1 131 = A1 132 = F1 133 = G1 134 = H1 135 = I1
> (Nikon 1 models with newer 135-point AF and 73-point phase-detect AF -- 9 rows (B-J) and 15 columns (1-15), inside a grid of 11 rows by 15 columns. The points are numbered sequentially, with F8 at the center) 0 = (none) 82 = F8 (Center) (Nikon 1 models with 171-point AF and 105-point phase-detect AF -- 9 rows (B-J) and 19 columns (2-20), inside a grid of 11 rows by 21 columns. The points are numbered sequentially, with F11 at the center) 0 = (none) 115 = F11 (Center) (Nikon models with 153-point AF -- 9 rows (A-I) and 17 columns (1-17): D5, D500 and D850)
> 0 = (none) 1 = E9 (Center) 2 = D9 3 = C9 4 = B9 5 = A9 6 = F9 7 = G9 8 = H9 9 = I9 10 = E10 11 = D10 12 = C10 13 = B10 14 = A10 15 = F10 16 = G10 17 = H10 18 = I10 19 = E11 20 = D11 21 = C11 22 = B11 23 = A11 24 = F11 25 = G11 26 = H11 27 = I11 28 = E8 29 = D8 30 = C8 |  | 31 = B8 32 = A8 33 = F8 34 = G8 35 = H8 36 = I8 37 = E7 38 = D7 39 = C7 40 = B7 41 = A7 42 = F7 43 = G7 44 = H7 45 = I7 46 = E12 47 = D12 48 = C12 49 = B12 50 = A12 51 = F12 52 = G12 53 = H12 54 = I12 55 = E13 56 = D13 57 = C13 58 = B13 59 = A13 60 = F13 61 = G13 |  | 62 = H13 63 = I13 64 = E14 65 = D14 66 = C14 67 = B14 68 = A14 69 = F14 70 = G14 71 = H14 72 = I14 73 = E15 74 = D15 75 = C15 76 = B15 77 = A15 78 = F15 79 = G15 80 = H15 81 = I15 82 = E16 83 = D16 84 = C16 85 = B16 86 = A16 87 = F16 88 = G16 89 = H16 90 = I16 91 = E17 92 = D17 |  | 93 = C17 94 = B17 95 = A17 96 = F17 97 = G17 98 = H17 99 = I17 100 = E6 101 = D6 102 = C6 103 = B6 104 = A6 105 = F6 106 = G6 107 = H6 108 = I6 109 = E5 110 = D5 111 = C5 112 = B5 113 = A5 114 = F5 115 = G5 116 = H5 117 = I5 118 = E4 119 = D4 120 = C4 121 = B4 122 = A4 123 = F4 |  | 124 = G4 125 = H4 126 = I4 127 = E3 128 = D3 129 = C3 130 = B3 131 = A3 132 = F3 133 = G3 134 = H3 135 = I3 136 = E2 137 = D2 138 = C2 139 = B2 140 = A2 141 = F2 142 = G2 143 = H2 144 = I2 145 = E1 146 = D1 147 = C1 148 = B1 149 = A1 150 = F1 151 = G1 152 = H1 153 = I1
> (future models?...) 0 = (none) 1 = Center
> 8 | AFPointsUsed AFPointsUsed AFPointsUsed AFPointsUsed AFPointsUsed AFPointsUsed AFPointsUsed AFPointsUsed PrimaryAFPoint | undef[7] undef[2] undef[5] undef[17] undef[21] undef[29] undef[20] undef[7] int8u | (models with 51-point AF -- 5 rows: A1-9, B1-11, C1-11, D1-11, E1-9. Center point is C6) (models with 11-point AF)
> 0x0 = (none) 0x7ff = All 11 Points Bit 0 = Center Bit 1 = Top Bit 2 = Bottom Bit 3 = Mid-left Bit 4 = Upper-left |  | Bit 5 = Lower-left Bit 6 = Far Left Bit 7 = Mid-right Bit 8 = Upper-right Bit 9 = Lower-right Bit 10 = Far Right
> (models with 39-point AF -- 5 rows: A1-3, B1-11, C1-11, D1-11, E1-3. Center point is C6) (older models with 135-point AF -- 9 rows (A-I) and 15 columns (1-15). Center point is E8. The odd-numbered columns, columns 2 and 14, and the remaining corner points are not used for 41-point AF mode) (newer models with 135-point AF -- 9 rows (B-J) and 15 columns (1-15). Center point is F8) (models with 171-point AF -- 9 rows (B-J) and 19 columns (2-20). Center point is F10) (models with 153-point AF -- 9 rows (A-I) and 17 columns (1-17). Center point is E9) (newer models with 51-point AF)
> 0 = (none) 1 = C6 (Center) 2 = B6 3 = A5 4 = D6 5 = E5 6 = C7 7 = B7 8 = A6 9 = D7 10 = E6 |  | 11 = C5 12 = B5 13 = A4 14 = D5 15 = E4 16 = C8 17 = B8 18 = A7 19 = D8 20 = E7 21 = C9 |  | 22 = B9 23 = A8 24 = D9 25 = E8 26 = C10 27 = B10 28 = A9 29 = D10 30 = E9 31 = C11 32 = B11 |  | 33 = D11 34 = C4 35 = B4 36 = A3 37 = D4 38 = E3 39 = C3 40 = B3 41 = A2 42 = D3 43 = E2 |  | 44 = C2 45 = B2 46 = A1 47 = D2 48 = E1 49 = C1 50 = B1 51 = D1
> 0 = (none) 1 = E5 (Center) 2 = D5 3 = C5 4 = B5 5 = A5 6 = F5 7 = G5 8 = H5 9 = I5 10 = E6 11 = D6 12 = C6 13 = B6 14 = A6 15 = F6 16 = G6 17 = H6 18 = I6 19 = E4 20 = D4 21 = C4 22 = B4 23 = A4 24 = F4 25 = G4 26 = H4 27 = I4 28 = E7 29 = D7 30 = C7 31 = B7 32 = A7 33 = F7 34 = G7 35 = H7 36 = I7 37 = E3 38 = D3 39 = C3 40 = B3 |  | 41 = A3 42 = F3 43 = G3 44 = H3 45 = I3 46 = E8 47 = D8 48 = C8 49 = B8 50 = A8 51 = F8 52 = G8 53 = H8 54 = I8 55 = E2 56 = D2 57 = C2 58 = B2 59 = A2 60 = F2 61 = G2 62 = H2 63 = I2 64 = E9 65 = D9 66 = C9 67 = B9 68 = A9 69 = F9 70 = G9 71 = H9 72 = I9 73 = E1 74 = D1 75 = C1 76 = B1 77 = A1 78 = F1 79 = G1 80 = H1 81 = I1
> 10 | AFPointsUsed AFPointsUsed AFPointsUsed | undef[7] undef[11] undef[14] | (newer models with 51-point AF) (models with 81-selectable point AF -- 9 rows (A-I) and 9 columns (1-9) for phase detect AF points. Center point is E5) (models with 105-point AF -- 7 rows (A-G) and 15 columns (1-15). Center point is D8)
> 16 | AFImageWidth | int16u | (this and the following tags are valid only for contrast-detect AF)
> 18 | AFImageHeight | int16u |
> 20 | AFAreaXPosition | int16u | (center of AF area in AFImage coordinates)
> 22 | AFAreaYPosition | int16u |
> 24 | AFAreaWidth | int16u | (size of AF area in AFImage coordinates)
> 26 | AFAreaHeight | int16u |
> 28 | ContrastDetectAFInFocus AFPointsSelected | int8u undef[20] | 0 = No 1 = Yes
> 42 | AFImageWidth | int16u |
> 44 | AFImageHeight | int16u |
> 46 | AFAreaXPosition | int16u |
> 47 | FocusPositionHorizontal | int8u~ |
> 48 | AFAreaYPosition AFPointsInFocus | int16u undef[20] | (AF points in focus at the time time image was captured)
> 49 | FocusPositionVertical | int8u~ |
> 50 | AFAreaWidth | int16u |
> 52 | AFAreaHeight | int16u |
> 56 | PrimaryAFPoint | int8u | (Nikon models with 105-point AF -- 7 rows (A-G) and 15 columns (1-15): D6)
> 0 = (none) 1 = D8 (Center) 2 = C8 3 = B8 4 = A8 5 = E8 6 = F8 7 = G8 8 = D9 9 = C9 10 = B9 11 = A9 12 = E9 13 = F9 14 = G9 15 = D10 16 = C10 17 = B10 18 = A10 19 = E10 20 = F10 21 = G10 |  | 22 = D7 23 = C7 24 = B7 25 = A7 26 = E7 27 = F7 28 = G7 29 = D6 30 = C6 31 = B6 32 = A6 33 = E6 34 = F6 35 = G6 36 = D11 37 = C11 38 = B11 39 = A11 40 = E11 41 = F11 42 = G11 43 = D12 |  | 44 = C12 45 = B12 46 = A12 47 = E12 48 = F12 49 = G12 50 = D13 51 = C13 52 = B13 53 = A13 54 = E13 55 = F13 56 = G13 57 = D14 58 = C14 59 = B14 60 = A14 61 = E14 62 = F14 63 = G14 64 = D15 65 = C15 |  | 66 = B15 67 = A15 68 = E15 69 = F15 70 = G15 71 = D5 72 = C5 73 = B5 74 = A5 75 = E5 76 = F5 77 = G5 78 = D4 79 = C4 80 = B4 81 = A4 82 = E4 83 = F4 84 = G4 85 = D3 86 = C3 87 = B3 |  | 88 = A3 89 = E3 90 = F3 91 = G3 92 = D2 93 = C2 94 = B2 95 = A2 96 = E2 97 = F2 98 = G2 99 = D1 100 = C1 101 = B1 102 = A1 103 = E1 104 = F1 105 = G1
> 68 | PrimaryAFPoint | int8u |
> 0 = (none) 1 = E9 (Center) 2 = D9 3 = C9 4 = B9 5 = A9 6 = F9 7 = G9 8 = H9 9 = I9 10 = E10 11 = D10 12 = C10 13 = B10 14 = A10 15 = F10 16 = G10 17 = H10 18 = I10 19 = E11 20 = D11 21 = C11 22 = B11 23 = A11 24 = F11 25 = G11 26 = H11 27 = I11 28 = E8 29 = D8 30 = C8 |  | 31 = B8 32 = A8 33 = F8 34 = G8 35 = H8 36 = I8 37 = E7 38 = D7 39 = C7 40 = B7 41 = A7 42 = F7 43 = G7 44 = H7 45 = I7 46 = E12 47 = D12 48 = C12 49 = B12 50 = A12 51 = F12 52 = G12 53 = H12 54 = I12 55 = E13 56 = D13 57 = C13 58 = B13 59 = A13 60 = F13 61 = G13 |  | 62 = H13 63 = I13 64 = E14 65 = D14 66 = C14 67 = B14 68 = A14 69 = F14 70 = G14 71 = H14 72 = I14 73 = E15 74 = D15 75 = C15 76 = B15 77 = A15 78 = F15 79 = G15 80 = H15 81 = I15 82 = E16 83 = D16 84 = C16 85 = B16 86 = A16 87 = F16 88 = G16 89 = H16 90 = I16 91 = E17 92 = D17 |  | 93 = C17 94 = B17 95 = A17 96 = F17 97 = G17 98 = H17 99 = I17 100 = E6 101 = D6 102 = C6 103 = B6 104 = A6 105 = F6 106 = G6 107 = H6 108 = I6 109 = E5 110 = D5 111 = C5 112 = B5 113 = A5 114 = F5 115 = G5 116 = H5 117 = I5 118 = E4 119 = D4 120 = C4 121 = B4 122 = A4 123 = F4 |  | 124 = G4 125 = H4 126 = I4 127 = E3 128 = D3 129 = C3 130 = B3 131 = A3 132 = F3 133 = G3 134 = H3 135 = I3 136 = E2 137 = D2 138 = C2 139 = B2 140 = A2 141 = F2 142 = G2 143 = H2 144 = I2 145 = E1 146 = D1 147 = C1 148 = B1 149 = A1 150 = F1 151 = G1 152 = H1 153 = I1
> (D3500)
> 0 = (none) 1 = Center 2 = Top 3 = Bottom 4 = Mid-left 5 = Upper-left |  | 6 = Lower-left 7 = Far Left 8 = Mid-right 9 = Upper-right 10 = Lower-right 11 = Far Right
> (future models?...) 0 = (none) 1 = Center
> 70 | AFImageWidth | int16u | (this and the following tags are valid only for contrast-detect AF)
> 72 | AFImageHeight | int16u |
> 74 | AFAreaXPosition | int16u | (center of AF area in AFImage coordinates)
> 76 | AFAreaYPosition | int16u |
> 78 | AFAreaWidth | int16u | (size of AF area in AFImage coordinates)
> 80 | AFAreaHeight | int16u |
> 82 | ContrastDetectAFInFocus | int8u | 0 = No 1 = Yes

## Nikon FileInfo Tags

> Index2 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | FileInfoVersion | no |
> 2 | MemoryCardNumber | int16u |
> 3 | DirectoryNumber | int16u |
> 4 | FileNumber | int16u |

## Nikon AFTune Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | AFFineTune | int8u | 0 = Off 1 = On (1) 2 = On (2) 3 = On (Zoom)
> 1 | AFFineTuneIndex | int8u | (index of saved lens)
> 2 | AFFineTuneAdj | int8s | (may only be valid for saved lenses)
> 3 | AFFineTuneAdjTele | int8s | (only valid for zoom lenses (ie, AFTune=3))

## Nikon RetouchInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | RetouchInfoVersion | no |
> 5 | RetouchNEFProcessing | int8s | -1 = Off 1 = On

## Nikon BarometerInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | BarometerInfoVersion | no |
> 6 | Altitude | int32s |

## Nikon CaptureOffsets Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0001 | IFD0_Offset | no |
> 0x0002 | PreviewIFD_Offset | no |
> 0x0003 | SubIFD_Offset | no |

## Nikon Scan Tags

This information is written by the Nikon Scan software.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0002 | FilmType | string |
> 0x0040 | MultiSample | string |
> 0x0041 | BitDepth | int16u |
> 0x0050 | MasterGain | rational64s |
> 0x0051 | ColorGain | rational64s[3] |
> 0x0060 | ScanImageEnhancer | int32u | 0 = Off 1 = On
> 0x0100 | DigitalICE | string |
> 0x0110 | ROCInfo | - | --> Nikon ROC Tags
> 0x0120 | GEMInfo | - | --> Nikon GEM Tags
> 0x0200 | DigitalDEEShadowAdj | int32u |
> 0x0201 | DigitalDEEThreshold | int32u |
> 0x0202 | DigitalDEEHighlightAdj | int32u |

## Nikon ROC Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | DigitalROC | int32u |

## Nikon GEM Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | DigitalGEM | int32u |

## Nikon CaptureOutput Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 2 | OutputImageWidth | int32u |
> 3 | OutputImageHeight | int32u |
> 4 | OutputResolution | int32u |

## Nikon Type2 Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0003 | Quality | yes |
> 0x0004 | ColorMode | yes |
> 0x0005 | ImageAdjustment | yes |
> 0x0006 | CCDSensitivity | yes |
> 0x0007 | WhiteBalance | yes |
> 0x0008 | Focus | yes |
> 0x000a | DigitalZoom | yes |
> 0x000b | Converter | yes |

## Nikon NEFInfo Tags

As-yet unknown information found in SubIFD1 tag 0xc7d5 of NEF images from cameras such as the Z6 and Z7, and NRW images from some Coolpix cameras.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0005 | DistortionInfo | - | --> Nikon DistortionInfo Tags
> 0x0006 | VignetteInfo | - | --> Nikon VignetteInfo Tags

## Nikon DistortionInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | DistortionCorrectionVersion | string[4] |
> 4 | DistortionCorrection | int8u | 1 = On (Optional) 2 = Off 3 = On (Required)
> 20 | RadialDistortionCoefficient1 | rational64s~ |
> 28 | RadialDistortionCoefficient2 | rational64s~ |
> 36 | RadialDistortionCoefficient3 | rational64s~ |

## Nikon VignetteInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | VignetteCorrectionVersion | string[4] |
> 36 | VignetteCoefficient1 | rational64s~ |
> 52 | VignetteCoefficient2 | rational64s~ |
> 68 | VignetteCoefficient3 | rational64s~ |

## Nikon AVI Tags

Nikon-specific RIFF tags found in AVI videos.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 'nctg' | NikonTags | - | --> Nikon AVITags Tags
> 'ncth' | ThumbnailImage | no |
> 'ncvr' | NikonVers | - | --> Nikon AVIVers Tags
> 'ncvw' | PreviewImage | no |

## Nikon AVITags Tags

These tags and the AVIVer tags below are found in proprietary-format records of Nikon AVI videos.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0003 | Make | no |
> 0x0004 | Model | no |
> 0x0005 | Software | no |
> 0x0006 | Equipment | no |
> 0x0007 | Orientation | no |
> 1 = Horizontal (normal) 2 = Mirror horizontal 3 = Rotate 180 4 = Mirror vertical 5 = Mirror horizontal and rotate 270 CW 6 = Rotate 90 CW 7 = Mirror horizontal and rotate 90 CW 8 = Rotate 270 CW
> 0x0008 | ExposureTime | no |
> 0x0009 | FNumber | no |
> 0x000a | ExposureCompensation | no |
> 0x000b | MaxApertureValue | no |
> 0x000c | MeteringMode | no |
> 0 = Unknown 1 = Average 2 = Center-weighted average 3 = Spot 4 = Multi-spot 5 = Multi-segment 6 = Partial 255 = Other
> 0x000f | FocalLength | no |
> 0x0010 | XResolution | no |
> 0x0011 | YResolution | no |
> 0x0012 | ResolutionUnit | no | 1 = None 2 = inches 3 = cm
> 0x0013 | DateTimeOriginal | no |
> 0x0014 | CreateDate | no |
> 0x0016 | Duration | no |
> 0x0018 | FocusMode | no |
> 0x001b | DigitalZoom | no |
> 0x001d | ColorMode | no |
> 0x001e | Sharpness | no |
> 0x001f | WhiteBalance | no |
> 0x0020 | NoiseReduction | no |

## Nikon AVIVers Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0001 | MakerNoteType | no |
> 0x0002 | MakerNoteVersion | no |

## Nikon NCDT Tags

Nikon-specific QuickTime tags found in the NCDT atom of MOV videos from various Nikon models.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 'NCDB' | NikonNCDB | - | --> Nikon NCDB Tags
> 'NCHD' | MakerNoteVersion | no |
> 'NCM1' | PreviewImage1 | no |
> 'NCM2' | PreviewImage2 | no |
> 'NCTG' | NikonTags | - | --> Nikon NCTG Tags
> 'NCTH' | ThumbnailImage | no |
> 'NCVW' | PreviewImage | no |

## Nikon NCDB Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> [no tags known]

## Nikon NCTG Tags

These tags are found in proprietary-format records of the NCTG atom in MOV videos from some Nikon cameras.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0001 | Make | no |
> 0x0002 | Model | no |
> 0x0003 | Software | no |
> 0x0011 | CreateDate | no |
> 0x0012 | DateTimeOriginal | no |
> 0x0013 | FrameCount | no |
> 0x0016 | FrameRate | no |
> 0x0019 | TimeZone | no |
> 0x0022 | FrameWidth | no |
> 0x0023 | FrameHeight | no |
> 0x0032 | AudioChannels | no |
> 0x0033 | AudioBitsPerSample | no |
> 0x0034 | AudioSampleRate | no |
> 0x1002 | NikonDateTime | no |
> 0x1013 | ElectronicVR | no | 0 = Off 1 = On
> 0x110829a | ExposureTime | no |
> 0x110829d | FNumber | no |
> 0x1108822 | ExposureProgram | no |
> 0 = Not Defined 1 = Manual 2 = Program AE 3 = Aperture-priority AE 4 = Shutter speed priority AE 5 = Creative (Slow speed) 6 = Action (High speed) 7 = Portrait 8 = Landscape
> 0x1109204 | ExposureCompensation | no |
> 0x1109207 | MeteringMode | no |
> 0 = Unknown 1 = Average 2 = Center-weighted average 3 = Spot 4 = Multi-spot 5 = Multi-segment 6 = Partial 255 = Other
> 0x110920a | FocalLength | no |
> 0x110a431 | SerialNumber | no |
> 0x110a432 | LensInfo | no |
> 0x110a433 | LensMake | no |
> 0x110a434 | LensModel | no |
> 0x110a435 | LensSerialNumber | no |
> 0x1200000 | GPSVersionID | no |
> 0x1200001 | GPSLatitudeRef | no | 'N' = North 'S' = South
> 0x1200002 | GPSLatitude | no |
> 0x1200003 | GPSLongitudeRef | no | 'E' = East 'W' = West
> 0x1200004 | GPSLongitude | no |
> 0x1200005 | GPSAltitudeRef | no | 0 = Above Sea Level 1 = Below Sea Level
> 0x1200006 | GPSAltitude | no |
> 0x1200007 | GPSTimeStamp | no |
> 0x1200008 | GPSSatellites | no |
> 0x1200010 | GPSImgDirectionRef | no | 'M' = Magnetic North 'T' = True North
> 0x1200011 | GPSImgDirection | no |
> 0x1200012 | GPSMapDatum | no |
> 0x120001d | GPSDateStamp | no |
> 0x2000001 | MakerNoteVersion | no |
> 0x2000005 | WhiteBalance | no |
> 0x2000007 | FocusMode | no |
> 0x200000b | WhiteBalanceFineTune | no |
> 0x200001b | CropHiSpeed | no |
> 0 = Off 1 = 1.3x Crop 2 = DX Crop 3 = 5:4 Crop 4 = 3:2 Crop 6 = 16:9 Crop 8 = 2.7x Crop 9 = DX Movie Crop |  | 10 = 1.3x Movie Crop 11 = FX Uncropped 12 = DX Uncropped 13 = 2.8x Movie Crop 14 = 1.4x Movie Crop 15 = 1.5x Movie Crop 17 = 1:1 Crop
> 0x200001e | ColorSpace | no | 1 = sRGB 2 = Adobe RGB
> 0x200001f | VRInfo | - | --> Nikon VRInfo Tags
> 0x2000022 | ActiveD-Lighting | no |
> 0 = Off 1 = Low 3 = Normal 5 = High 7 = Extra High |  | 8 = Extra High 1 9 = Extra High 2 10 = Extra High 3 11 = Extra High 4 65535 = Auto
> 0x2000023 | PictureControlData | - | --> Nikon PictureControl Tags --> Nikon PictureControl2 Tags --> Nikon PictureControl3 Tags --> Nikon PictureControlUnknown Tags
> 0x2000024 | WorldTime | - | --> Nikon WorldTime Tags
> 0x2000025 | ISOInfo | - | --> Nikon ISOInfo Tags
> 0x200002a | VignetteControl | no | 0 = Off 1 = Low 3 = Normal 5 = High
> 0x200002c | UnknownInfo | - | --> Nikon UnknownInfo Tags
> 0x2000032 | UnknownInfo2 | - | --> Nikon UnknownInfo2 Tags
> 0x2000039 | LocationInfo | - | --> Nikon LocationInfo Tags
> 0x200003f | WhiteBalanceFineTune | no |
> 0x200004e | NikonSettings | - | --> NikonSettings Tags
> 0x2000083 | LensType | no | Bit 0 = MF Bit 1 = D Bit 2 = G Bit 3 = VR Bit 4 = 1 Bit 6 = E
> 0x2000084 | Lens | no |
> 0x2000087 | FlashMode | no |
> 0 = Did Not Fire 1 = Fired, Manual 3 = Not Ready 7 = Fired, External 8 = Fired, Commander Mode 9 = Fired, TTL Mode 18 = LED Light
> 0x2000098 | LensData0100 LensData0101 LensData0201 LensData0204 LensData0400 LensData0402 LensData0403 LensData0800 LensDataUnknown | - - - - - - - - - | --> Nikon LensData00 Tags --> Nikon LensData01 Tags --> Nikon LensData01 Tags --> Nikon LensData0204 Tags --> Nikon LensData0400 Tags --> Nikon LensData0402 Tags --> Nikon LensData0403 Tags --> Nikon LensData0800 Tags --> Nikon LensDataUnknown Tags
> 0x20000a7 | ShutterCount | no |
> 0x20000a8 | FlashInfo0100 FlashInfo0102 FlashInfo0103 FlashInfo0106 FlashInfo0107 FlashInfoUnknown | - - - - - - | --> Nikon FlashInfo0100 Tags --> Nikon FlashInfo0102 Tags --> Nikon FlashInfo0103 Tags --> Nikon FlashInfo0106 Tags --> Nikon FlashInfo0107 Tags --> Nikon FlashInfoUnknown Tags
> 0x20000ab | VariProgram | no |
> 0x20000b1 | HighISONoiseReduction | no |
> 0 = Off 1 = Minimal 2 = Low 3 = Medium Low |  | 4 = Normal 5 = Medium High 6 = High
> 0x20000b7 | AFInfo2 | - | --> Nikon AFInfo2 Tags
> 0x20000c3 | BarometerInfo | - | --> Nikon BarometerInfo Tags

## Nikon MOV Tags

This information is found in MOV and QT videos from some Nikon cameras.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | Make | no |
> 24 | Model | no |
> 38 | ExposureTime | no |
> 42 | FNumber | no |
> 50 | ExposureCompensation | no |
> 68 | WhiteBalance | no |
> 0 = Auto 1 = Daylight 2 = Shade |  | 3 = Fluorescent 4 = Tungsten 5 = Manual
> 72 | FocalLength | no |
> 175 | Software | no |
> 223 | ISO | no |

## Nikon LensID Values

The Nikon LensID is constructed as a Composite tag from the raw hex values of 8 other tags: LensIDNumber, LensFStops, MinFocalLength, MaxFocalLength, MaxApertureAtMinFocal, MaxApertureAtMaxFocal, MCUVersion and LensType, in that order. The user-defined "Lenses" list may be used to specify the lens for ExifTool to choose in these cases (see the sample config file for details).

> Value | LensID
> --- | ---
> '00 00 00 00 00 00 00 01' | = Manual Lens No CPU
> '00 00 00 00 00 00 E1 12' | = TC-17E II
> '00 00 00 00 00 00 F1 0C' | = TC-14E [II] or Sigma APO Tele Converter 1.4x EX DG or Kenko Teleplus PRO 300 DG 1.4x
> '00 00 00 00 00 00 F2 18' | = TC-20E [II] or Sigma APO Tele Converter 2x EX DG or Kenko Teleplus PRO 300 DG 2.0x
> '00 00 48 48 53 53 00 01' | = Loreo 40mm F11-22 3D Lens in a Cap 9005
> '00 36 1C 2D 34 3C 00 06' | = Tamron SP AF 11-18mm f/4.5-5.6 Di II LD Aspherical (IF) (A13)
> '00 3C 1F 37 30 30 00 06' | = Tokina AT-X 124 AF PRO DX (AF 12-24mm f/4)
> '00 3C 2B 44 30 30 00 06' | = Tokina AT-X 17-35 F4 PRO FX (AF 17-35mm f/4)
> '00 3C 5C 80 30 30 00 0E' | = Tokina AT-X 70-200 F4 FX VCM-S (AF 70-200mm f/4)
> '00 3E 80 A0 38 3F 00 02' | = Tamron SP AF 200-500mm f/5-6.3 Di LD (IF) (A08)
> '00 3F 2D 80 2B 40 00 06' | = Tamron AF 18-200mm f/3.5-6.3 XR Di II LD Aspherical (IF) (A14)
> '00 3F 2D 80 2C 40 00 06' | = Tamron AF 18-200mm f/3.5-6.3 XR Di II LD Aspherical (IF) Macro (A14)
> '00 3F 80 A0 38 3F 00 02' | = Tamron SP AF 200-500mm f/5-6.3 Di (A08)
> '00 40 11 11 2C 2C 00 00' | = Samyang 8mm f/3.5 Fish-Eye
> '00 40 18 2B 2C 34 00 06' | = Tokina AT-X 107 AF DX Fisheye (AF 10-17mm f/3.5-4.5)
> '00 40 2A 72 2C 3C 00 06' | = Tokina AT-X 16.5-135 DX (AF 16.5-135mm F3.5-5.6)
> '00 40 2B 2B 2C 2C 00 02' | = Tokina AT-X 17 AF PRO (AF 17mm f/3.5)
> '00 40 2D 2D 2C 2C 00 00' | = Carl Zeiss Distagon T* 3.5/18 ZF.2
> '00 40 2D 80 2C 40 00 06' | = Tamron AF 18-200mm f/3.5-6.3 XR Di II LD Aspherical (IF) Macro (A14NII)
> '00 40 2D 88 2C 40 00 06' | = Tamron AF 18-250mm f/3.5-6.3 Di II LD Aspherical (IF) Macro (A18NII)
> '00 40 2D 88 2C 40 62 06' | = Tamron AF 18-250mm f/3.5-6.3 Di II LD Aspherical (IF) Macro (A18)
> '00 40 31 31 2C 2C 00 00' | = Voigtlander Color Skopar 20mm F3.5 SLII Aspherical
> '00 40 37 80 2C 3C 00 02' | = Tokina AT-X 242 AF (AF 24-200mm f/3.5-5.6)
> '00 40 64 64 2C 2C 00 00' | = Voigtlander APO-Lanthar 90mm F3.5 SLII Close Focus
> '00 44 60 98 34 3C 00 02' | = Tokina AT-X 840 D (AF 80-400mm f/4.5-5.6)
> '00 47 10 10 24 24 00 00' | = Fisheye Nikkor 8mm f/2.8 AiS
> '00 47 25 25 24 24 00 02' | = Tamron SP AF 14mm f/2.8 Aspherical (IF) (69E)
> '00 47 3C 3C 24 24 00 00' | = Nikkor 28mm f/2.8 AiS
> '00 47 44 44 24 24 00 06' | = Tokina AT-X M35 PRO DX (AF 35mm f/2.8 Macro)
> '00 47 53 80 30 3C 00 06' | = Tamron AF 55-200mm f/4-5.6 Di II LD (A15)
> '00 48 1C 29 24 24 00 06' | = Tokina AT-X 116 PRO DX (AF 11-16mm f/2.8)
> '00 48 27 27 24 24 00 00' | = Carl Zeiss Distagon T* 2.8/15 ZF.2
> '00 48 29 3C 24 24 00 06' | = Tokina AT-X 16-28 AF PRO FX (AF 16-28mm f/2.8)
> '00 48 29 50 24 24 00 06' | = Tokina AT-X 165 PRO DX (AF 16-50mm f/2.8)
> '00 48 32 32 24 24 00 00' | = Carl Zeiss Distagon T* 2.8/21 ZF.2
> '00 48 37 5C 24 24 00 06' | = Tokina AT-X 24-70 F2.8 PRO FX (AF 24-70mm f/2.8)
> '00 48 3C 3C 24 24 00 00' | = Voigtlander Color Skopar 28mm F2.8 SL II
> '00 48 3C 60 24 24 00 02' | = Tokina AT-X 280 AF PRO (AF 28-80mm f/2.8)
> '00 48 3C 6A 24 24 00 02' | = Tamron SP AF 28-105mm f/2.8 LD Aspherical IF (176D)
> '00 48 50 50 18 18 00 00' | = Nikkor H 50mm f/2
> '00 48 50 72 24 24 00 06' | = Tokina AT-X 535 PRO DX (AF 50-135mm f/2.8)
> '00 48 5C 80 30 30 00 0E' | = Tokina AT-X 70-200 F4 FX VCM-S (AF 70-200mm f/4)
> '00 48 5C 8E 30 3C 00 06' | = Tamron AF 70-300mm f/4-5.6 Di LD Macro 1:2 (A17NII)
> '00 48 68 68 24 24 00 00' | = Series E 100mm f/2.8
> '00 48 80 80 30 30 00 00' | = Nikkor 200mm f/4 AiS
> '00 49 30 48 22 2B 00 02' | = Tamron SP AF 20-40mm f/2.7-3.5 (166D)
> '00 4C 6A 6A 20 20 00 00' | = Nikkor 105mm f/2.5 AiS
> '00 4C 7C 7C 2C 2C 00 02' | = Tamron SP AF 180mm f/3.5 Di Model (B01)
> '00 53 2B 50 24 24 00 06' | = Tamron SP AF 17-50mm f/2.8 XR Di II LD Aspherical (IF) (A16)
> '00 54 2B 50 24 24 00 06' | = Tamron SP AF 17-50mm f/2.8 XR Di II LD Aspherical (IF) (A16NII)
> '00 54 38 38 18 18 00 00' | = Carl Zeiss Distagon T* 2/25 ZF.2
> '00 54 3C 3C 18 18 00 00' | = Carl Zeiss Distagon T* 2/28 ZF.2
> '00 54 44 44 0C 0C 00 00' | = Carl Zeiss Distagon T* 1.4/35 ZF.2
> '00 54 44 44 18 18 00 00' | = Carl Zeiss Distagon T* 2/35 ZF.2
> '00 54 48 48 18 18 00 00' | = Voigtlander Ultron 40mm F2 SLII Aspherical
> '00 54 50 50 0C 0C 00 00' | = Carl Zeiss Planar T* 1.4/50 ZF.2
> '00 54 50 50 18 18 00 00' | = Carl Zeiss Makro-Planar T* 2/50 ZF.2
> '00 54 53 53 0C 0C 00 00' | = Zeiss Otus 1.4/55
> '00 54 55 55 0C 0C 00 00' | = Voigtlander Nokton 58mm F1.4 SLII
> '00 54 56 56 30 30 00 00' | = Coastal Optical Systems 60mm 1:4 UV-VIS-IR Macro Apo
> '00 54 62 62 0C 0C 00 00' | = Carl Zeiss Planar T* 1.4/85 ZF.2
> '00 54 68 68 18 18 00 00' | = Carl Zeiss Makro-Planar T* 2/100 ZF.2
> '00 54 68 68 24 24 00 02' | = Tokina AT-X M100 AF PRO D (AF 100mm f/2.8 Macro)
> '00 54 72 72 18 18 00 00' | = Carl Zeiss Apo Sonnar T* 2/135 ZF.2
> '00 54 8E 8E 24 24 00 02' | = Tokina AT-X 300 AF PRO (AF 300mm f/2.8)
> '00 57 50 50 14 14 00 00' | = Nikkor 50mm f/1.8 AI
> '00 58 64 64 20 20 00 00' | = Soligor C/D Macro MC 90mm f/2.5
> '01 00 00 00 00 00 02 00' | = TC-16A
> '01 00 00 00 00 00 08 00' | = TC-16A
> '01 54 62 62 0C 0C 00 00' | = Zeiss Otus 1.4/85
> '01 58 50 50 14 14 02 00' | = AF Nikkor 50mm f/1.8
> '01 58 50 50 14 14 05 00' | = AF Nikkor 50mm f/1.8
> '02 2F 98 98 3D 3D 02 00' | = Sigma APO 400mm F5.6
> '02 34 A0 A0 44 44 02 00' | = Sigma APO 500mm F7.2
> '02 37 5E 8E 35 3D 02 00' | = Sigma 75-300mm F4.5-5.6 APO
> '02 37 A0 A0 34 34 02 00' | = Sigma APO 500mm F4.5
> '02 3A 37 50 31 3D 02 00' | = Sigma 24-50mm F4-5.6 UC
> '02 3A 5E 8E 32 3D 02 00' | = Sigma 75-300mm F4.0-5.6
> '02 3B 44 61 30 3D 02 00' | = Sigma 35-80mm F4-5.6
> '02 3B 5C 82 30 3C 02 00' | = Sigma Zoom-K 70-210mm F4-5.6
> '02 3C B0 B0 3C 3C 02 00' | = Sigma APO 800mm F5.6
> '02 3F 24 24 2C 2C 02 00' | = Sigma 14mm F3.5
> '02 3F 3C 5C 2D 35 02 00' | = Sigma 28-70mm F3.5-4.5 UC
> '02 40 44 5C 2C 34 02 00' | = Exakta AF 35-70mm 1:3.5-4.5 MC
> '02 40 44 73 2B 36 02 00' | = Sigma 35-135mm F3.5-4.5 a
> '02 40 5C 82 2C 35 02 00' | = Sigma APO 70-210mm F3.5-4.5
> '02 42 44 5C 2A 34 02 00' | = AF Zoom-Nikkor 35-70mm f/3.3-4.5
> '02 42 44 5C 2A 34 08 00' | = AF Zoom-Nikkor 35-70mm f/3.3-4.5
> '02 46 37 37 25 25 02 00' | = Sigma 24mm F2.8 Super Wide II Macro
> '02 46 3C 5C 25 25 02 00' | = Sigma 28-70mm F2.8
> '02 46 5C 82 25 25 02 00' | = Sigma 70-210mm F2.8 APO
> '02 48 50 50 24 24 02 00' | = Sigma Macro 50mm F2.8
> '02 48 65 65 24 24 02 00' | = Sigma Macro 90mm F2.8
> '02 54 3C 3C 0C 0C 00 00' | = Zeiss Otus 1.4/28 ZF.2
> '03 43 5C 81 35 35 02 00' | = Soligor AF C/D Zoom UMCS 70-210mm 1:4.5
> '03 48 5C 81 30 30 02 00' | = AF Zoom-Nikkor 70-210mm f/4
> '03 54 68 68 0C 0C 00 00' | = Zeiss Otus 1.4/100
> '04 48 3C 3C 24 24 03 00' | = AF Nikkor 28mm f/2.8
> '05 54 50 50 0C 0C 04 00' | = AF Nikkor 50mm f/1.4
> '06 3F 68 68 2C 2C 06 00' | = Cosina AF 100mm F3.5 Macro
> '06 54 53 53 24 24 06 00' | = AF Micro-Nikkor 55mm f/2.8
> '07 36 3D 5F 2C 3C 03 00' | = Cosina AF Zoom 28-80mm F3.5-5.6 MC Macro
> '07 3E 30 43 2D 35 03 00' | = Soligor AF Zoom 19-35mm 1:3.5-4.5 MC
> '07 40 2F 44 2C 34 03 02' | = Tamron AF 19-35mm f/3.5-4.5 (A10)
> '07 40 30 45 2D 35 03 02' | = Tamron AF 19-35mm f/3.5-4.5 (A10)
> '07 40 30 45 2D 35 03 02' | = Voigtlander Ultragon 19-35mm F3.5-4.5 VMV
> '07 40 3C 5C 2C 35 03 00' | = Tokina AF 270 II (AF 28-70mm f/3.5-4.5)
> '07 40 3C 62 2C 34 03 00' | = AF Zoom-Nikkor 28-85mm f/3.5-4.5
> '07 46 2B 44 24 30 03 02' | = Tamron SP AF 17-35mm f/2.8-4 Di LD Aspherical (IF) (A05)
> '07 46 3D 6A 25 2F 03 00' | = Cosina AF Zoom 28-105mm F2.8-3.8 MC
> '07 47 3C 5C 25 35 03 00' | = Tokina AF 287 SD (AF 28-70mm f/2.8-4.5)
> '07 48 3C 5C 24 24 03 00' | = Tokina AT-X 287 AF (AF 28-70mm f/2.8)
> '08 40 44 6A 2C 34 04 00' | = AF Zoom-Nikkor 35-105mm f/3.5-4.5
> '09 48 37 37 24 24 04 00' | = AF Nikkor 24mm f/2.8
> '0A 48 8E 8E 24 24 03 00' | = AF Nikkor 300mm f/2.8 IF-ED
> '0A 48 8E 8E 24 24 05 00' | = AF Nikkor 300mm f/2.8 IF-ED N
> '0B 3E 3D 7F 2F 3D 0E 00' | = Tamron AF 28-200mm f/3.8-5.6 (71D)
> '0B 3E 3D 7F 2F 3D 0E 02' | = Tamron AF 28-200mm f/3.8-5.6D (171D)
> '0B 48 7C 7C 24 24 05 00' | = AF Nikkor 180mm f/2.8 IF-ED
> '0D 40 44 72 2C 34 07 00' | = AF Zoom-Nikkor 35-135mm f/3.5-4.5
> '0E 48 5C 81 30 30 05 00' | = AF Zoom-Nikkor 70-210mm f/4
> '0E 4A 31 48 23 2D 0E 02' | = Tamron SP AF 20-40mm f/2.7-3.5 (166D)
> '0F 58 50 50 14 14 05 00' | = AF Nikkor 50mm f/1.8 N
> '10 3D 3C 60 2C 3C D2 02' | = Tamron AF 28-80mm f/3.5-5.6 Aspherical (177D)
> '10 48 8E 8E 30 30 08 00' | = AF Nikkor 300mm f/4 IF-ED
> '11 48 44 5C 24 24 08 00' | = AF Zoom-Nikkor 35-70mm f/2.8
> '11 48 44 5C 24 24 15 00' | = AF Zoom-Nikkor 35-70mm f/2.8
> '12 36 5C 81 35 3D 09 00' | = Cosina AF Zoom 70-210mm F4.5-5.6 MC Macro
> '12 36 69 97 35 42 09 00' | = Soligor AF Zoom 100-400mm 1:4.5-6.7 MC
> '12 38 69 97 35 42 09 02' | = Promaster Spectrum 7 100-400mm F4.5-6.7
> '12 39 5C 8E 34 3D 08 02' | = Cosina AF Zoom 70-300mm F4.5-5.6 MC Macro
> '12 3B 68 8D 3D 43 09 02' | = Cosina AF Zoom 100-300mm F5.6-6.7 MC Macro
> '12 3B 98 98 3D 3D 09 00' | = Tokina AT-X 400 AF SD (AF 400mm f/5.6)
> '12 3D 3C 80 2E 3C DF 02' | = Tamron AF 28-200mm f/3.8-5.6 AF Aspherical LD (IF) (271D)
> '12 44 5E 8E 34 3C 09 00' | = Tokina AF 730 (AF 75-300mm F4.5-5.6)
> '12 48 5C 81 30 3C 09 00' | = AF Nikkor 70-210mm f/4-5.6
> '12 4A 5C 81 31 3D 09 00' | = Soligor AF C/D Auto Zoom+Macro 70-210mm 1:4-5.6 UMCS
> '13 42 37 50 2A 34 0B 00' | = AF Zoom-Nikkor 24-50mm f/3.3-4.5
> '14 48 60 80 24 24 0B 00' | = AF Zoom-Nikkor 80-200mm f/2.8 ED
> '14 48 68 8E 30 30 0B 00' | = Tokina AT-X 340 AF (AF 100-300mm f/4)
> '14 54 60 80 24 24 0B 00' | = Tokina AT-X 828 AF (AF 80-200mm f/2.8)
> '15 4C 62 62 14 14 0C 00' | = AF Nikkor 85mm f/1.8
> '17 3C A0 A0 30 30 0F 00' | = Nikkor 500mm f/4 P ED IF
> '17 3C A0 A0 30 30 11 00' | = Nikkor 500mm f/4 P ED IF
> '18 40 44 72 2C 34 0E 00' | = AF Zoom-Nikkor 35-135mm f/3.5-4.5 N
> '1A 54 44 44 18 18 11 00' | = AF Nikkor 35mm f/2
> '1B 44 5E 8E 34 3C 10 00' | = AF Zoom-Nikkor 75-300mm f/4.5-5.6
> '1C 48 30 30 24 24 12 00' | = AF Nikkor 20mm f/2.8
> '1D 42 44 5C 2A 34 12 00' | = AF Zoom-Nikkor 35-70mm f/3.3-4.5 N
> '1E 54 56 56 24 24 13 00' | = AF Micro-Nikkor 60mm f/2.8
> '1E 5D 64 64 20 20 13 00' | = Tamron SP AF 90mm f/2.5 (52E)
> '1F 54 6A 6A 24 24 14 00' | = AF Micro-Nikkor 105mm f/2.8
> '20 3C 80 98 3D 3D 1E 02' | = Tamron AF 200-400mm f/5.6 LD IF (75D)
> '20 48 60 80 24 24 15 00' | = AF Zoom-Nikkor 80-200mm f/2.8 ED
> '20 5A 64 64 20 20 14 00' | = Tamron SP AF 90mm f/2.5 Macro (152E)
> '21 40 3C 5C 2C 34 16 00' | = AF Zoom-Nikkor 28-70mm f/3.5-4.5
> '21 56 8E 8E 24 24 14 00' | = Tamron SP AF 300mm f/2.8 LD-IF (60E)
> '22 48 72 72 18 18 16 00' | = AF DC-Nikkor 135mm f/2
> '22 53 64 64 24 24 E0 02' | = Tamron SP AF 90mm f/2.8 Macro 1:1 (72E)
> '23 30 BE CA 3C 48 17 00' | = Zoom-Nikkor 1200-1700mm f/5.6-8 P ED IF
> '24 44 60 98 34 3C 1A 02' | = Tokina AT-X 840 AF-II (AF 80-400mm f/4.5-5.6)
> '24 48 60 80 24 24 1A 02' | = AF Zoom-Nikkor 80-200mm f/2.8D ED
> '24 54 60 80 24 24 1A 02' | = Tokina AT-X 828 AF PRO (AF 80-200mm f/2.8)
> '25 44 44 8E 34 42 1B 02' | = Tokina AF 353 (AF 35-300mm f/4.5-6.7)
> '25 48 3C 5C 24 24 1B 02' | = Tokina AT-X 270 AF PRO II (AF 28-70mm f/2.6-2.8)
> '25 48 3C 5C 24 24 1B 02' | = Tokina AT-X 287 AF PRO SV (AF 28-70mm f/2.8)
> '25 48 44 5C 24 24 1B 02' | = AF Zoom-Nikkor 35-70mm f/2.8D
> '25 48 44 5C 24 24 3A 02' | = AF Zoom-Nikkor 35-70mm f/2.8D
> '25 48 44 5C 24 24 52 02' | = AF Zoom-Nikkor 35-70mm f/2.8D
> '26 3C 54 80 30 3C 1C 06' | = Sigma 55-200mm F4-5.6 DC
> '26 3C 5C 82 30 3C 1C 02' | = Sigma 70-210mm F4-5.6 UC-II
> '26 3C 5C 8E 30 3C 1C 02' | = Sigma 70-300mm F4-5.6 DG Macro
> '26 3C 98 98 3C 3C 1C 02' | = Sigma APO Tele Macro 400mm F5.6
> '26 3D 3C 80 2F 3D 1C 02' | = Sigma 28-300mm F3.8-5.6 Aspherical
> '26 3E 3C 6A 2E 3C 1C 02' | = Sigma 28-105mm F3.8-5.6 UC-III Aspherical IF
> '26 40 27 3F 2C 34 1C 02' | = Sigma 15-30mm F3.5-4.5 EX DG Aspherical DF
> '26 40 2D 44 2B 34 1C 02' | = Sigma 18-35mm F3.5-4.5 Aspherical
> '26 40 2D 50 2C 3C 1C 06' | = Sigma 18-50mm F3.5-5.6 DC
> '26 40 2D 70 2B 3C 1C 06' | = Sigma 18-125mm F3.5-5.6 DC
> '26 40 2D 80 2C 40 1C 06' | = Sigma 18-200mm F3.5-6.3 DC
> '26 40 37 5C 2C 3C 1C 02' | = Sigma 24-70mm F3.5-5.6 Aspherical HF
> '26 40 3C 5C 2C 34 1C 02' | = AF Zoom-Nikkor 28-70mm f/3.5-4.5D
> '26 40 3C 60 2C 3C 1C 02' | = Sigma 28-80mm F3.5-5.6 Mini Zoom Macro II Aspherical
> '26 40 3C 65 2C 3C 1C 02' | = Sigma 28-90mm F3.5-5.6 Macro
> '26 40 3C 80 2B 3C 1C 02' | = Sigma 28-200mm F3.5-5.6 Compact Aspherical Hyperzoom Macro
> '26 40 3C 80 2C 3C 1C 02' | = Sigma 28-200mm F3.5-5.6 Compact Aspherical Hyperzoom Macro
> '26 40 3C 8E 2C 40 1C 02' | = Sigma 28-300mm F3.5-6.3 Macro
> '26 40 7B A0 34 40 1C 02' | = Sigma APO 170-500mm F5-6.3 Aspherical RF
> '26 41 3C 8E 2C 40 1C 02' | = Sigma 28-300mm F3.5-6.3 DG Macro
> '26 44 73 98 34 3C 1C 02' | = Sigma 135-400mm F4.5-5.6 APO Aspherical
> '26 45 68 8E 34 42 1C 02' | = Sigma 100-300mm F4.5-6.7 DL
> '26 48 11 11 30 30 1C 02' | = Sigma 8mm F4 EX Circular Fisheye
> '26 48 27 27 24 24 1C 02' | = Sigma 15mm F2.8 EX Diagonal Fisheye
> '26 48 2D 50 24 24 1C 06' | = Sigma 18-50mm F2.8 EX DC
> '26 48 31 49 24 24 1C 02' | = Sigma 20-40mm F2.8
> '26 48 37 56 24 24 1C 02' | = Sigma 24-60mm F2.8 EX DG
> '26 48 3C 5C 24 24 1C 06' | = Sigma 28-70mm F2.8 EX DG
> '26 48 3C 5C 24 30 1C 02' | = Sigma 28-70mm F2.8-4 DG
> '26 48 3C 6A 24 30 1C 02' | = Sigma 28-105mm F2.8-4 Aspherical
> '26 48 8E 8E 30 30 1C 02' | = Sigma APO Tele Macro 300mm F4
> '26 54 2B 44 24 30 1C 02' | = Sigma 17-35mm F2.8-4 EX Aspherical
> '26 54 37 5C 24 24 1C 02' | = Sigma 24-70mm F2.8 EX DG Macro
> '26 54 37 73 24 34 1C 02' | = Sigma 24-135mm F2.8-4.5
> '26 54 3C 5C 24 24 1C 02' | = Sigma 28-70mm F2.8 EX
> '26 58 31 31 14 14 1C 02' | = Sigma 20mm F1.8 EX DG Aspherical RF
> '26 58 37 37 14 14 1C 02' | = Sigma 24mm F1.8 EX DG Aspherical Macro
> '26 58 3C 3C 14 14 1C 02' | = Sigma 28mm F1.8 EX DG Aspherical Macro
> '27 48 8E 8E 24 24 1D 02' | = AF-I Nikkor 300mm f/2.8D IF-ED
> '27 48 8E 8E 24 24 E1 02' | = AF-I Nikkor 300mm f/2.8D IF-ED + TC-17E
> '27 48 8E 8E 24 24 F1 02' | = AF-I Nikkor 300mm f/2.8D IF-ED + TC-14E
> '27 48 8E 8E 24 24 F2 02' | = AF-I Nikkor 300mm f/2.8D IF-ED + TC-20E
> '27 48 8E 8E 30 30 1D 02' | = Tokina AT-X 304 AF (AF 300mm f/4.0)
> '27 54 8E 8E 24 24 1D 02' | = Tamron SP AF 300mm f/2.8 LD-IF (360E)
> '28 3C A6 A6 30 30 1D 02' | = AF-I Nikkor 600mm f/4D IF-ED
> '28 3C A6 A6 30 30 E1 02' | = AF-I Nikkor 600mm f/4D IF-ED + TC-17E
> '28 3C A6 A6 30 30 F1 02' | = AF-I Nikkor 600mm f/4D IF-ED + TC-14E
> '28 3C A6 A6 30 30 F2 02' | = AF-I Nikkor 600mm f/4D IF-ED + TC-20E
> '2A 54 3C 3C 0C 0C 26 02' | = AF Nikkor 28mm f/1.4D
> '2B 3C 44 60 30 3C 1F 02' | = AF Zoom-Nikkor 35-80mm f/4-5.6D
> '2C 48 6A 6A 18 18 27 02' | = AF DC-Nikkor 105mm f/2D
> '2D 48 80 80 30 30 21 02' | = AF Micro-Nikkor 200mm f/4D IF-ED
> '2E 48 5C 82 30 3C 22 02' | = AF Nikkor 70-210mm f/4-5.6D
> '2E 48 5C 82 30 3C 28 02' | = AF Nikkor 70-210mm f/4-5.6D
> '2F 40 30 44 2C 34 29 02' | = Tokina AF 235 II (AF 20-35mm f/3.5-4.5)
> '2F 40 30 44 2C 34 29 02' | = Tokina AF 193 (AF 19-35mm f/3.5-4.5)
> '2F 48 30 44 24 24 29 02' | = AF Zoom-Nikkor 20-35mm f/2.8D IF
> '2F 48 30 44 24 24 29 02' | = Tokina AT-X 235 AF PRO (AF 20-35mm f/2.8)
> '30 48 98 98 24 24 24 02' | = AF-I Nikkor 400mm f/2.8D IF-ED
> '30 48 98 98 24 24 E1 02' | = AF-I Nikkor 400mm f/2.8D IF-ED + TC-17E
> '30 48 98 98 24 24 F1 02' | = AF-I Nikkor 400mm f/2.8D IF-ED + TC-14E
> '30 48 98 98 24 24 F2 02' | = AF-I Nikkor 400mm f/2.8D IF-ED + TC-20E
> '31 54 56 56 24 24 25 02' | = AF Micro-Nikkor 60mm f/2.8D
> '32 53 64 64 24 24 35 02' | = Tamron SP AF 90mm f/2.8 [Di] Macro 1:1 (172E/272E)
> '32 54 50 50 24 24 35 02' | = Sigma Macro 50mm F2.8 EX DG
> '32 54 6A 6A 24 24 35 02' | = AF Micro-Nikkor 105mm f/2.8D
> '32 54 6A 6A 24 24 35 02' | = Sigma Macro 105mm F2.8 EX DG
> '33 48 2D 2D 24 24 31 02' | = AF Nikkor 18mm f/2.8D
> '33 54 3C 5E 24 24 62 02' | = Tamron SP AF 28-75mm f/2.8 XR Di LD Aspherical (IF) Macro (A09)
> '34 48 29 29 24 24 32 02' | = AF Fisheye Nikkor 16mm f/2.8D
> '35 3C A0 A0 30 30 33 02' | = AF-I Nikkor 500mm f/4D IF-ED
> '35 3C A0 A0 30 30 E1 02' | = AF-I Nikkor 500mm f/4D IF-ED + TC-17E
> '35 3C A0 A0 30 30 F1 02' | = AF-I Nikkor 500mm f/4D IF-ED + TC-14E
> '35 3C A0 A0 30 30 F2 02' | = AF-I Nikkor 500mm f/4D IF-ED + TC-20E
> '36 48 37 37 24 24 34 02' | = AF Nikkor 24mm f/2.8D
> '37 48 30 30 24 24 36 02' | = AF Nikkor 20mm f/2.8D
> '38 4C 62 62 14 14 37 02' | = AF Nikkor 85mm f/1.8D
> '3A 40 3C 5C 2C 34 39 02' | = AF Zoom-Nikkor 28-70mm f/3.5-4.5D
> '3B 48 44 5C 24 24 3A 02' | = AF Zoom-Nikkor 35-70mm f/2.8D N
> '3C 48 60 80 24 24 3B 02' | = AF Zoom-Nikkor 80-200mm f/2.8D ED
> '3D 3C 44 60 30 3C 3E 02' | = AF Zoom-Nikkor 35-80mm f/4-5.6D
> '3E 48 3C 3C 24 24 3D 02' | = AF Nikkor 28mm f/2.8D
> '3F 40 44 6A 2C 34 45 02' | = AF Zoom-Nikkor 35-105mm f/3.5-4.5D
> '41 48 7C 7C 24 24 43 02' | = AF Nikkor 180mm f/2.8D IF-ED
> '42 54 44 44 18 18 44 02' | = AF Nikkor 35mm f/2D
> '43 54 50 50 0C 0C 46 02' | = AF Nikkor 50mm f/1.4D
> '44 44 60 80 34 3C 47 02' | = AF Zoom-Nikkor 80-200mm f/4.5-5.6D
> '45 3D 3C 60 2C 3C 48 02' | = Tamron AF 28-80mm f/3.5-5.6 Aspherical (177D)
> '45 40 3C 60 2C 3C 48 02' | = AF Zoom-Nikkor 28-80mm f/3.5-5.6D
> '45 41 37 72 2C 3C 48 02' | = Tamron SP AF 24-135mm f/3.5-5.6 AD Aspherical (IF) Macro (190D)
> '46 3C 44 60 30 3C 49 02' | = AF Zoom-Nikkor 35-80mm f/4-5.6D N
> '47 42 37 50 2A 34 4A 02' | = AF Zoom-Nikkor 24-50mm f/3.3-4.5D
> '48 38 1F 37 34 3C 4B 06' | = Sigma 12-24mm F4.5-5.6 EX DG Aspherical HSM
> '48 3C 19 31 30 3C 4B 06' | = Sigma 10-20mm F4-5.6 EX DC HSM
> '48 3C 50 A0 30 40 4B 02' | = Sigma 50-500mm F4-6.3 EX APO RF HSM
> '48 3C 8E B0 3C 3C 4B 02' | = Sigma APO 300-800mm F5.6 EX DG HSM
> '48 3C B0 B0 3C 3C 4B 02' | = Sigma APO 800mm F5.6 EX HSM
> '48 44 A0 A0 34 34 4B 02' | = Sigma APO 500mm F4.5 EX HSM
> '48 48 24 24 24 24 4B 02' | = Sigma 14mm F2.8 EX Aspherical HSM
> '48 48 2B 44 24 30 4B 06' | = Sigma 17-35mm F2.8-4 EX DG Aspherical HSM
> '48 48 68 8E 30 30 4B 02' | = Sigma APO 100-300mm F4 EX IF HSM
> '48 48 76 76 24 24 4B 06' | = Sigma APO Macro 150mm F2.8 EX DG HSM
> '48 48 8E 8E 24 24 4B 02' | = AF-S Nikkor 300mm f/2.8D IF-ED
> '48 48 8E 8E 24 24 E1 02' | = AF-S Nikkor 300mm f/2.8D IF-ED + TC-17E
> '48 48 8E 8E 24 24 F1 02' | = AF-S Nikkor 300mm f/2.8D IF-ED + TC-14E
> '48 48 8E 8E 24 24 F2 02' | = AF-S Nikkor 300mm f/2.8D IF-ED + TC-20E
> '48 4C 7C 7C 2C 2C 4B 02' | = Sigma APO Macro 180mm F3.5 EX DG HSM
> '48 4C 7D 7D 2C 2C 4B 02' | = Sigma APO Macro 180mm F3.5 EX DG HSM
> '48 54 3E 3E 0C 0C 4B 06' | = Sigma 30mm F1.4 EX DC HSM
> '48 54 5C 80 24 24 4B 02' | = Sigma 70-200mm F2.8 EX APO IF HSM
> '48 54 6F 8E 24 24 4B 02' | = Sigma APO 120-300mm F2.8 EX DG HSM
> '48 54 8E 8E 24 24 4B 02' | = Sigma APO 300mm F2.8 EX DG HSM
> '49 3C A6 A6 30 30 4C 02' | = AF-S Nikkor 600mm f/4D IF-ED
> '49 3C A6 A6 30 30 E1 02' | = AF-S Nikkor 600mm f/4D IF-ED + TC-17E
> '49 3C A6 A6 30 30 F1 02' | = AF-S Nikkor 600mm f/4D IF-ED + TC-14E
> '49 3C A6 A6 30 30 F2 02' | = AF-S Nikkor 600mm f/4D IF-ED + TC-20E
> '4A 40 11 11 2C 0C 4D 02' | = Samyang 8mm f/3.5 Fish-Eye CS
> '4A 48 1E 1E 24 0C 4D 02' | = Samyang 12mm f/2.8 ED AS NCS Fish-Eye
> '4A 48 24 24 24 0C 4D 02' | = Samyang 10mm f/2.8 ED AS NCS CS
> '4A 48 24 24 24 0C 4D 02' | = Samyang AE 14mm f/2.8 ED AS IF UMC
> '4A 4C 24 24 1E 6C 4D 06' | = Samyang 14mm f/2.4 Premium
> '4A 54 29 29 18 0C 4D 02' | = Samyang 16mm f/2.0 ED AS UMC CS
> '4A 54 62 62 0C 0C 4D 02' | = AF Nikkor 85mm f/1.4D IF
> '4A 58 30 30 14 0C 4D 02' | = Rokinon 20mm f/1.8 ED AS UMC
> '4A 60 36 36 0C 0C 4D 02' | = Samyang 24mm f/1.4 ED AS UMC
> '4A 60 44 44 0C 0C 4D 02' | = Samyang 35mm f/1.4 AS UMC
> '4A 60 62 62 0C 0C 4D 02' | = Samyang AE 85mm f/1.4 AS IF UMC
> '4B 3C A0 A0 30 30 4E 02' | = AF-S Nikkor 500mm f/4D IF-ED
> '4B 3C A0 A0 30 30 E1 02' | = AF-S Nikkor 500mm f/4D IF-ED + TC-17E
> '4B 3C A0 A0 30 30 F1 02' | = AF-S Nikkor 500mm f/4D IF-ED + TC-14E
> '4B 3C A0 A0 30 30 F2 02' | = AF-S Nikkor 500mm f/4D IF-ED + TC-20E
> '4C 40 37 6E 2C 3C 4F 02' | = AF Zoom-Nikkor 24-120mm f/3.5-5.6D IF
> '4D 3E 3C 80 2E 3C 62 02' | = Tamron AF 28-200mm f/3.8-5.6 XR Aspherical (IF) Macro (A03N)
> '4D 40 3C 80 2C 3C 62 02' | = AF Zoom-Nikkor 28-200mm f/3.5-5.6D IF
> '4D 41 3C 8E 2B 40 62 02' | = Tamron AF 28-300mm f/3.5-6.3 XR Di LD Aspherical (IF) (A061)
> '4D 41 3C 8E 2C 40 62 02' | = Tamron AF 28-300mm f/3.5-6.3 XR LD Aspherical (IF) (185D)
> '4E 48 72 72 18 18 51 02' | = AF DC-Nikkor 135mm f/2D
> '4F 40 37 5C 2C 3C 53 06' | = IX-Nikkor 24-70mm f/3.5-5.6
> '50 48 56 7C 30 3C 54 06' | = IX-Nikkor 60-180mm f/4-5.6
> '52 54 44 44 18 18 00 00' | = Zeiss Milvus 35mm f/2
> '53 48 60 80 24 24 57 02' | = AF Zoom-Nikkor 80-200mm f/2.8D ED
> '53 48 60 80 24 24 60 02' | = AF Zoom-Nikkor 80-200mm f/2.8D ED
> '53 54 50 50 0C 0C 00 00' | = Zeiss Milvus 50mm f/1.4
> '54 44 5C 7C 34 3C 58 02' | = AF Zoom-Micro Nikkor 70-180mm f/4.5-5.6D ED
> '54 44 5C 7C 34 3C 61 02' | = AF Zoom-Micro Nikkor 70-180mm f/4.5-5.6D ED
> '54 54 50 50 18 18 00 00' | = Zeiss Milvus 50mm f/2 Macro
> '55 54 62 62 0C 0C 00 00' | = Zeiss Milvus 85mm f/1.4
> '56 3C 5C 8E 30 3C 1C 02' | = Sigma 70-300mm F4-5.6 APO Macro Super II
> '56 48 5C 8E 30 3C 5A 02' | = AF Zoom-Nikkor 70-300mm f/4-5.6D ED
> '56 54 68 68 18 18 00 00' | = Zeiss Milvus 100mm f/2 Macro
> '59 48 98 98 24 24 5D 02' | = AF-S Nikkor 400mm f/2.8D IF-ED
> '59 48 98 98 24 24 E1 02' | = AF-S Nikkor 400mm f/2.8D IF-ED + TC-17E
> '59 48 98 98 24 24 F1 02' | = AF-S Nikkor 400mm f/2.8D IF-ED + TC-14E
> '59 48 98 98 24 24 F2 02' | = AF-S Nikkor 400mm f/2.8D IF-ED + TC-20E
> '5A 3C 3E 56 30 3C 5E 06' | = IX-Nikkor 30-60mm f/4-5.6
> '5B 44 56 7C 34 3C 5F 06' | = IX-Nikkor 60-180mm f/4.5-5.6
> '5D 48 3C 5C 24 24 63 02' | = AF-S Zoom-Nikkor 28-70mm f/2.8D IF-ED
> '5E 48 60 80 24 24 64 02' | = AF-S Zoom-Nikkor 80-200mm f/2.8D IF-ED
> '5F 40 3C 6A 2C 34 65 02' | = AF Zoom-Nikkor 28-105mm f/3.5-4.5D IF
> '60 40 3C 60 2C 3C 66 02' | = AF Zoom-Nikkor 28-80mm f/3.5-5.6D
> '61 44 5E 86 34 3C 67 02' | = AF Zoom-Nikkor 75-240mm f/4.5-5.6D
> '63 48 2B 44 24 24 68 02' | = AF-S Nikkor 17-35mm f/2.8D IF-ED
> '64 00 62 62 24 24 6A 02' | = PC Micro-Nikkor 85mm f/2.8D
> '65 44 60 98 34 3C 6B 0A' | = AF VR Zoom-Nikkor 80-400mm f/4.5-5.6D ED
> '66 40 2D 44 2C 34 6C 02' | = AF Zoom-Nikkor 18-35mm f/3.5-4.5D IF-ED
> '67 48 37 62 24 30 6D 02' | = AF Zoom-Nikkor 24-85mm f/2.8-4D IF
> '67 54 37 5C 24 24 1C 02' | = Sigma 24-70mm F2.8 EX DG Macro
> '68 42 3C 60 2A 3C 6E 06' | = AF Zoom-Nikkor 28-80mm f/3.3-5.6G
> '69 47 5C 8E 30 3C 00 02' | = Tamron AF 70-300mm f/4-5.6 Di LD Macro 1:2 (A17N)
> '69 48 5C 8E 30 3C 6F 02' | = Tamron AF 70-300mm f/4-5.6 LD Macro 1:2 (572D/772D)
> '69 48 5C 8E 30 3C 6F 06' | = AF Zoom-Nikkor 70-300mm f/4-5.6G
> '6A 48 8E 8E 30 30 70 02' | = AF-S Nikkor 300mm f/4D IF-ED
> '6B 48 24 24 24 24 71 02' | = AF Nikkor ED 14mm f/2.8D
> '6D 48 8E 8E 24 24 73 02' | = AF-S Nikkor 300mm f/2.8D IF-ED II
> '6E 48 98 98 24 24 74 02' | = AF-S Nikkor 400mm f/2.8D IF-ED II
> '6F 3C A0 A0 30 30 75 02' | = AF-S Nikkor 500mm f/4D IF-ED II
> '70 3C A6 A6 30 30 76 02' | = AF-S Nikkor 600mm f/4D IF-ED II
> '71 48 64 64 24 24 00 00' | = Voigtlander APO-Skopar 90mm F2.8 SL IIs
> '72 48 4C 4C 24 24 77 00' | = Nikkor 45mm f/2.8 P
> '74 40 37 62 2C 34 78 06' | = AF-S Zoom-Nikkor 24-85mm f/3.5-4.5G IF-ED
> '75 40 3C 68 2C 3C 79 06' | = AF Zoom-Nikkor 28-100mm f/3.5-5.6G
> '76 58 50 50 14 14 7A 02' | = AF Nikkor 50mm f/1.8D
> '77 44 60 98 34 3C 7B 0E' | = Sigma 80-400mm F4.5-5.6 APO DG D OS
> '77 44 61 98 34 3C 7B 0E' | = Sigma 80-400mm F4.5-5.6 EX OS
> '77 48 5C 80 24 24 7B 0E' | = AF-S VR Zoom-Nikkor 70-200mm f/2.8G IF-ED
> '78 40 37 6E 2C 3C 7C 0E' | = AF-S VR Zoom-Nikkor 24-120mm f/3.5-5.6G IF-ED
> '79 40 11 11 2C 2C 1C 06' | = Sigma 8mm F3.5 EX Circular Fisheye
> '79 40 3C 80 2C 3C 7F 06' | = AF Zoom-Nikkor 28-200mm f/3.5-5.6G IF-ED
> '79 48 3C 5C 24 24 1C 06' | = Sigma 28-70mm F2.8 EX DG
> '79 48 5C 5C 24 24 1C 06' | = Sigma Macro 70mm F2.8 EX DG
> '79 54 31 31 0C 0C 4B 06' | = Sigma 20mm F1.4 DG HSM | A
> '7A 3B 53 80 30 3C 4B 06' | = Sigma 55-200mm F4-5.6 DC HSM
> '7A 3C 1F 37 30 30 7E 06' | = AF-S DX Zoom-Nikkor 12-24mm f/4G IF-ED
> '7A 3C 1F 37 30 30 7E 06' | = Tokina AT-X 124 AF PRO DX II (AF 12-24mm f/4)
> '7A 3C 1F 3C 30 30 7E 06' | = Tokina AT-X 12-28 PRO DX (AF 12-28mm f/4)
> '7A 40 2D 50 2C 3C 4B 06' | = Sigma 18-50mm F3.5-5.6 DC HSM
> '7A 40 2D 80 2C 40 4B 0E' | = Sigma 18-200mm F3.5-6.3 DC OS HSM
> '7A 47 2B 5C 24 34 4B 06' | = Sigma 17-70mm F2.8-4.5 DC Macro Asp. IF HSM
> '7A 47 50 76 24 24 4B 06' | = Sigma 50-150mm F2.8 EX APO DC HSM
> '7A 48 1C 29 24 24 7E 06' | = Tokina AT-X 116 PRO DX II (AF 11-16mm f/2.8)
> '7A 48 1C 30 24 24 7E 06' | = Tokina AT-X 11-20 F2.8 PRO DX (AF 11-20mm f/2.8)
> '7A 48 2B 5C 24 34 4B 06' | = Sigma 17-70mm F2.8-4.5 DC Macro Asp. IF HSM
> '7A 48 2D 50 24 24 4B 06' | = Sigma 18-50mm F2.8 EX DC Macro
> '7A 48 5C 80 24 24 4B 06' | = Sigma 70-200mm F2.8 EX APO DG Macro HSM II
> '7A 54 6E 8E 24 24 4B 02' | = Sigma APO 120-300mm F2.8 EX DG HSM
> '7B 48 37 44 18 18 4B 06' | = Sigma 24-35mm F2.0 DG HSM | A
> '7B 48 80 98 30 30 80 0E' | = AF-S VR Zoom-Nikkor 200-400mm f/4G IF-ED
> '7C 54 2B 50 24 24 00 06' | = Tamron SP AF 17-50mm f/2.8 XR Di II LD Aspherical (IF) (A16)
> '7D 48 2B 53 24 24 82 06' | = AF-S DX Zoom-Nikkor 17-55mm f/2.8G IF-ED
> '7E 54 37 37 0C 0C 4B 06' | = Sigma 24mm F1.4 DG HSM | A
> '7F 40 2D 5C 2C 34 84 06' | = AF-S DX Zoom-Nikkor 18-70mm f/3.5-4.5G IF-ED
> '7F 48 2B 5C 24 34 1C 06' | = Sigma 17-70mm F2.8-4.5 DC Macro Asp. IF
> '7F 48 2D 50 24 24 1C 06' | = Sigma 18-50mm F2.8 EX DC Macro
> '80 48 1A 1A 24 24 85 06' | = AF DX Fisheye-Nikkor 10.5mm f/2.8G ED
> '80 48 1C 29 24 24 7A 06' | = Tokina atx-i 11-16mm F2.8 CF
> '81 34 76 A6 38 40 4B 0E' | = Sigma 150-600mm F5-6.3 DG OS HSM | S
> '81 54 80 80 18 18 86 0E' | = AF-S VR Nikkor 200mm f/2G IF-ED
> '82 34 76 A6 38 40 4B 0E' | = Sigma 150-600mm F5-6.3 DG OS HSM | C
> '82 48 8E 8E 24 24 87 0E' | = AF-S VR Nikkor 300mm f/2.8G IF-ED
> '83 00 B0 B0 5A 5A 88 04' | = FSA-L2, EDG 65, 800mm F13 G
> '87 2C 2D 8E 2C 40 4B 0E' | = Sigma 18-300mm F3.5-6.3 DC Macro HSM
> '88 54 50 50 0C 0C 4B 06' | = Sigma 50mm F1.4 DG HSM | A
> '89 30 2D 80 2C 40 4B 0E' | = Sigma 18-200mm F3.5-6.3 DC Macro OS HS | C
> '89 3C 53 80 30 3C 8B 06' | = AF-S DX Zoom-Nikkor 55-200mm f/4-5.6G ED
> '8A 3C 37 6A 30 30 4B 0E' | = Sigma 24-105mm F4 DG OS HSM
> '8A 54 6A 6A 24 24 8C 0E' | = AF-S VR Micro-Nikkor 105mm f/2.8G IF-ED
> '8B 40 2D 80 2C 3C 8D 0E' | = AF-S DX VR Zoom-Nikkor 18-200mm f/3.5-5.6G IF-ED
> '8B 40 2D 80 2C 3C FD 0E' | = AF-S DX VR Zoom-Nikkor 18-200mm f/3.5-5.6G IF-ED [II]
> '8B 48 1C 30 24 24 85 06' | = Tokina AT-X 11-20 F2.8 PRO DX (AF 11-20mm f/2.8)
> '8B 4C 2D 44 14 14 4B 06' | = Sigma 18-35mm F1.8 DC HSM
> '8C 40 2D 53 2C 3C 8E 06' | = AF-S DX Zoom-Nikkor 18-55mm f/3.5-5.6G ED
> '8C 48 29 3C 24 24 86 06' | = Tokina opera 16-28mm F2.8 FF
> '8D 44 5C 8E 34 3C 8F 0E' | = AF-S VR Zoom-Nikkor 70-300mm f/4.5-5.6G IF-ED
> '8D 48 6E 8E 24 24 4B 0E' | = Sigma 120-300mm F2.8 DG OS HSM Sports
> '8D 54 68 68 24 24 87 02' | = Tokina AT-X PRO 100mm F2.8 D Macro
> '8E 3C 2B 5C 24 30 4B 0E' | = Sigma 17-70mm F2.8-4 DC Macro OS HSM | C
> '8F 40 2D 72 2C 3C 91 06' | = AF-S DX Zoom-Nikkor 18-135mm f/3.5-5.6G IF-ED
> '8F 48 2B 50 24 24 4B 0E' | = Sigma 17-50mm F2.8 EX DC OS HSM
> '90 3B 53 80 30 3C 92 0E' | = AF-S DX VR Zoom-Nikkor 55-200mm f/4-5.6G IF-ED
> '90 40 2D 80 2C 40 4B 0E' | = Sigma 18-200mm F3.5-6.3 II DC OS HSM
> '91 54 44 44 0C 0C 4B 06' | = Sigma 35mm F1.4 DG HSM
> '92 2C 2D 88 2C 40 4B 0E' | = Sigma 18-250mm F3.5-6.3 DC Macro OS HSM
> '92 48 24 37 24 24 94 06' | = AF-S Zoom-Nikkor 14-24mm f/2.8G ED
> '93 48 37 5C 24 24 95 06' | = AF-S Zoom-Nikkor 24-70mm f/2.8G ED
> '94 40 2D 53 2C 3C 96 06' | = AF-S DX Zoom-Nikkor 18-55mm f/3.5-5.6G ED II
> '94 48 7C 7C 24 24 4B 0E' | = Sigma APO Macro 180mm F2.8 EX DG OS HSM
> '95 00 37 37 2C 2C 97 06' | = PC-E Nikkor 24mm f/3.5D ED
> '95 4C 37 37 2C 2C 97 02' | = PC-E Nikkor 24mm f/3.5D ED
> '96 38 1F 37 34 3C 4B 06' | = Sigma 12-24mm F4.5-5.6 II DG HSM
> '96 48 98 98 24 24 98 0E' | = AF-S VR Nikkor 400mm f/2.8G ED
> '97 3C A0 A0 30 30 99 0E' | = AF-S VR Nikkor 500mm f/4G ED
> '97 48 6A 6A 24 24 4B 0E' | = Sigma Macro 105mm F2.8 EX DG OS HSM
> '98 3C A6 A6 30 30 9A 0E' | = AF-S VR Nikkor 600mm f/4G ED
> '98 48 50 76 24 24 4B 0E' | = Sigma 50-150mm F2.8 EX APO DC OS HSM
> '99 40 29 62 2C 3C 9B 0E' | = AF-S DX VR Zoom-Nikkor 16-85mm f/3.5-5.6G ED
> '99 48 76 76 24 24 4B 0E' | = Sigma APO Macro 150mm F2.8 EX DG OS HSM
> '9A 40 2D 53 2C 3C 9C 0E' | = AF-S DX VR Zoom-Nikkor 18-55mm f/3.5-5.6G
> '9A 4C 50 50 14 14 9C 06' | = Yongnuo YN50mm F1.8N
> '9B 00 4C 4C 24 24 9D 06' | = PC-E Micro Nikkor 45mm f/2.8D ED
> '9B 54 4C 4C 24 24 9D 02' | = PC-E Micro Nikkor 45mm f/2.8D ED
> '9B 54 62 62 0C 0C 4B 06' | = Sigma 85mm F1.4 EX DG HSM
> '9C 48 5C 80 24 24 4B 0E' | = Sigma 70-200mm F2.8 EX DG OS HSM
> '9C 54 56 56 24 24 9E 06' | = AF-S Micro Nikkor 60mm f/2.8G ED
> '9D 00 62 62 24 24 9F 06' | = PC-E Micro Nikkor 85mm f/2.8D
> '9D 48 2B 50 24 24 4B 0E' | = Sigma 17-50mm F2.8 EX DC OS HSM
> '9D 54 62 62 24 24 9F 02' | = PC-E Micro Nikkor 85mm f/2.8D
> '9E 38 11 29 34 3C 4B 06' | = Sigma 8-16mm F4.5-5.6 DC HSM
> '9E 40 2D 6A 2C 3C A0 0E' | = AF-S DX VR Zoom-Nikkor 18-105mm f/3.5-5.6G ED
> '9F 37 50 A0 34 40 4B 0E' | = Sigma 50-500mm F4.5-6.3 DG OS HSM
> '9F 48 48 48 24 24 A1 06' | = Yongnuo YN40mm F2.8N
> '9F 54 68 68 18 18 A2 06' | = Yongnuo YN100mm F2N
> '9F 58 44 44 14 14 A1 06' | = AF-S DX Nikkor 35mm f/1.8G
> 'A0 37 5C 8E 34 3C A2 06' | = Sony FE 70-300mm F4.5-5.6 G OSS
> 'A0 40 2D 53 2C 3C CA 0E' | = AF-P DX Nikkor 18-55mm f/3.5-5.6G VR
> 'A0 40 2D 53 2C 3C CA 8E' | = AF-P DX Nikkor 18-55mm f/3.5-5.6G
> 'A0 40 2D 74 2C 3C BB 0E' | = AF-S DX Nikkor 18-140mm f/3.5-5.6G ED VR
> 'A0 48 2A 5C 24 30 4B 0E' | = Sigma 17-70mm F2.8-4 DC Macro OS HSM
> 'A0 54 50 50 0C 0C A2 06' | = AF-S Nikkor 50mm f/1.4G
> 'A0 56 44 44 14 14 A2 06' | = Sony FE 35mm F1.8
> 'A1 40 18 37 2C 34 A3 06' | = AF-S DX Nikkor 10-24mm f/3.5-4.5G ED
> 'A1 40 2D 53 2C 3C CB 86' | = AF-P DX Nikkor 18-55mm f/3.5-5.6G
> 'A1 41 19 31 2C 2C 4B 06' | = Sigma 10-20mm F3.5 EX DC HSM
> 'A1 48 6E 8E 24 24 DB 4E' | = AF-S Nikkor 120-300mm f/2.8E FL ED SR VR
> 'A1 54 55 55 0C 0C BC 06' | = AF-S Nikkor 58mm f/1.4G
> 'A2 38 5C 8E 34 40 CD 86' | = AF-P DX Nikkor 70-300mm f/4.5-6.3G VR
> 'A2 40 2D 53 2C 3C BD 0E' | = AF-S DX Nikkor 18-55mm f/3.5-5.6G VR II
> 'A2 48 5C 80 24 24 A4 0E' | = AF-S Nikkor 70-200mm f/2.8G ED VR II
> 'A3 38 5C 8E 34 40 CE 0E' | = AF-P DX Nikkor 70-300mm f/4.5-6.3G ED
> 'A3 38 5C 8E 34 40 CE 8E' | = AF-P DX Nikkor 70-300mm f/4.5-6.3G ED VR
> 'A3 3C 29 44 30 30 A5 0E' | = AF-S Nikkor 16-35mm f/4G ED VR
> 'A3 3C 5C 8E 30 3C 4B 0E' | = Sigma 70-300mm F4-5.6 DG OS
> 'A4 40 2D 8E 2C 40 BF 0E' | = AF-S DX Nikkor 18-300mm f/3.5-6.3G ED VR
> 'A4 47 2D 50 24 34 4B 0E' | = Sigma 18-50mm F2.8-4.5 DC OS HSM
> 'A4 48 5C 80 24 24 CF 0E' | = AF-S Nikkor 70-200mm f/2.8E FL ED VR
> 'A4 48 5C 80 24 24 CF 4E' | = AF-S Nikkor 70-200mm f/2.8E FL ED VR
> 'A4 54 37 37 0C 0C A6 06' | = AF-S Nikkor 24mm f/1.4G ED
> 'A5 40 2D 88 2C 40 4B 0E' | = Sigma 18-250mm F3.5-6.3 DC OS HSM
> 'A5 40 3C 8E 2C 3C A7 0E' | = AF-S Nikkor 28-300mm f/3.5-5.6G ED VR
> 'A5 4C 44 44 14 14 C0 06' | = AF-S Nikkor 35mm f/1.8G ED
> 'A5 54 6A 6A 0C 0C D0 06' | = AF-S Nikkor 105mm f/1.4E ED
> 'A5 54 6A 6A 0C 0C D0 46' | = AF-S Nikkor 105mm f/1.4E ED
> 'A6 48 2F 2F 30 30 D1 06' | = PC Nikkor 19mm f/4E ED
> 'A6 48 2F 2F 30 30 D1 46' | = PC Nikkor 19mm f/4E ED
> 'A6 48 37 5C 24 24 4B 06' | = Sigma 24-70mm F2.8 IF EX DG HSM
> 'A6 48 8E 8E 24 24 A8 0E' | = AF-S Nikkor 300mm f/2.8G IF-ED VR II
> 'A6 48 98 98 24 24 C1 0E' | = AF-S Nikkor 400mm f/2.8E FL ED VR
> 'A7 3C 53 80 30 3C C2 0E' | = AF-S DX Nikkor 55-200mm f/4-5.6G ED VR II
> 'A7 40 11 26 2C 34 D2 06' | = AF-S Fisheye Nikkor 8-15mm f/3.5-4.5E ED
> 'A7 40 11 26 2C 34 D2 46' | = AF-S Fisheye Nikkor 8-15mm f/3.5-4.5E ED
> 'A7 49 80 A0 24 24 4B 06' | = Sigma APO 200-500mm F2.8 EX DG
> 'A7 4B 62 62 2C 2C A9 0E' | = AF-S DX Micro Nikkor 85mm f/3.5G ED VR
> 'A8 38 18 30 34 3C D3 0E' | = AF-P DX Nikkor 10-20mm f/4.5-5.6G VR
> 'A8 38 18 30 34 3C D3 8E' | = AF-P DX Nikkor 10-20mm f/4.5-5.6G VR
> 'A8 48 80 98 30 30 AA 0E' | = AF-S Zoom-Nikkor 200-400mm f/4G IF-ED VR II
> 'A8 48 8E 8E 30 30 C3 0E' | = AF-S Nikkor 300mm f/4E PF ED VR
> 'A8 48 8E 8E 30 30 C3 4E' | = AF-S Nikkor 300mm f/4E PF ED VR
> 'A9 48 7C 98 30 30 D4 0E' | = AF-S Nikkor 180-400mm f/4E TC1.4 FL ED VR
> 'A9 48 7C 98 30 30 D4 4E' | = AF-S Nikkor 180-400mm f/4E TC1.4 FL ED VR
> 'A9 4C 31 31 14 14 C4 06' | = AF-S Nikkor 20mm f/1.8G ED
> 'A9 54 80 80 18 18 AB 0E' | = AF-S Nikkor 200mm f/2G ED VR II
> 'AA 3C 37 6E 30 30 AC 0E' | = AF-S Nikkor 24-120mm f/4G ED VR
> 'AA 48 37 5C 24 24 C5 0E' | = AF-S Nikkor 24-70mm f/2.8E ED VR
> 'AA 48 37 5C 24 24 C5 4E' | = AF-S Nikkor 24-70mm f/2.8E ED VR
> 'AA 48 88 A4 3C 3C D5 0E' | = AF-S Nikkor 180-400mm f/4E TC1.4 FL ED VR + 1.4x TC
> 'AA 48 88 A4 3C 3C D5 4E' | = AF-S Nikkor 180-400mm f/4E TC1.4 FL ED VR + 1.4x TC
> 'AB 3C A0 A0 30 30 C6 4E' | = AF-S Nikkor 500mm f/4E FL ED VR
> 'AB 44 5C 8E 34 3C D6 0E' | = AF-P Nikkor 70-300mm f/4.5-5.6E ED VR
> 'AB 44 5C 8E 34 3C D6 4E' | = AF-P Nikkor 70-300mm f/4.5-5.6E ED VR
> 'AB 44 5C 8E 34 3C D6 CE' | = AF-P Nikkor 70-300mm f/4.5-5.6E ED VR
> 'AC 38 53 8E 34 3C AE 0E' | = AF-S DX Nikkor 55-300mm f/4.5-5.6G ED VR
> 'AC 3C A6 A6 30 30 C7 4E' | = AF-S Nikkor 600mm f/4E FL ED VR
> 'AC 54 3C 3C 0C 0C D7 06' | = AF-S Nikkor 28mm f/1.4E ED
> 'AC 54 3C 3C 0C 0C D7 46' | = AF-S Nikkor 28mm f/1.4E ED
> 'AD 3C 2D 8E 2C 3C AF 0E' | = AF-S DX Nikkor 18-300mm f/3.5-5.6G ED VR
> 'AD 3C A0 A0 3C 3C D8 0E' | = AF-S Nikkor 500mm f/5.6E PF ED VR
> 'AD 3C A0 A0 3C 3C D8 4E' | = AF-S Nikkor 500mm f/5.6E PF ED VR
> 'AD 48 28 60 24 30 C8 0E' | = AF-S DX Nikkor 16-80mm f/2.8-4E ED VR
> 'AD 48 28 60 24 30 C8 4E' | = AF-S DX Nikkor 16-80mm f/2.8-4E ED VR
> 'AE 3C 80 A0 3C 3C C9 0E' | = AF-S Nikkor 200-500mm f/5.6E ED VR
> 'AE 3C 80 A0 3C 3C C9 4E' | = AF-S Nikkor 200-500mm f/5.6E ED VR
> 'AE 54 62 62 0C 0C B0 06' | = AF-S Nikkor 85mm f/1.4G
> 'AF 4C 37 37 14 14 CC 06' | = AF-S Nikkor 24mm f/1.8G ED
> 'AF 54 44 44 0C 0C B1 06' | = AF-S Nikkor 35mm f/1.4G
> 'B0 4C 50 50 14 14 B2 06' | = AF-S Nikkor 50mm f/1.8G
> 'B1 48 48 48 24 24 B3 06' | = AF-S DX Micro Nikkor 40mm f/2.8G
> 'B2 48 5C 80 30 30 B4 0E' | = AF-S Nikkor 70-200mm f/4G ED VR
> 'B3 4C 62 62 14 14 B5 06' | = AF-S Nikkor 85mm f/1.8G
> 'B4 40 37 62 2C 34 B6 0E' | = AF-S Zoom-Nikkor 24-85mm f/3.5-4.5G IF-ED VR
> 'B5 4C 3C 3C 14 14 B7 06' | = AF-S Nikkor 28mm f/1.8G
> 'B6 3C B0 B0 3C 3C B8 0E' | = AF-S VR Nikkor 800mm f/5.6E FL ED
> 'B6 3C B0 B0 3C 3C B8 4E' | = AF-S VR Nikkor 800mm f/5.6E FL ED
> 'B6 48 37 56 24 24 1C 02' | = Sigma 24-60mm F2.8 EX DG
> 'B7 44 60 98 34 3C B9 0E' | = AF-S Nikkor 80-400mm f/4.5-5.6G ED VR
> 'B8 40 2D 44 2C 34 BA 06' | = AF-S Nikkor 18-35mm f/3.5-4.5G ED
> 'BB 48 5C 80 24 24 4B 4E' | = Sigma 70-200mm F2.8 DG OS HSM | S
> 'BD 54 48 48 0C 0C 4B 46' | = Sigma 40mm F1.4 DG HSM | A
> 'BE 54 6A 6A 0C 0C 4B 46' | = Sigma 105mm F1.4 DG HSM | A
> 'BF 3C 1B 1B 30 30 01 04' | = Irix 11mm f/4 Firefly
> 'BF 4E 26 26 1E 1E 01 04' | = Irix 15mm f/2.4 Firefly
> 'C1 48 24 37 24 24 4B 46' | = Sigma 14-24mm F2.8 DG HSM | A
> 'C2 4C 24 24 14 14 4B 06' | = Sigma 14mm F1.8 DG HSM | A
> 'C3 34 68 98 38 40 4B 4E' | = Sigma 100-400mm F5-6.3 DG OS HSM | C
> 'C4 4C 73 73 14 14 4B 46' | = Sigma 135mm F1.8 DG HSM | A
> 'C8 54 44 44 0D 0D DF 46' | = Tamron SP 35mm f/1.4 Di USD (F045)
> 'C8 54 62 62 0C 0C 4B 06' | = Sigma 85mm F1.4 DG HSM | A
> 'C8 54 62 62 0C 0C 4B 46' | = Sigma 85mm F1.4 DG HSM | A
> 'C9 3C 44 76 25 31 DF 4E' | = Tamron 35-150mm f/2.8-4 Di VC OSD (A043)
> 'C9 48 37 5C 24 24 4B 4E' | = Sigma 24-70mm F2.8 DG OS HSM | A
> 'CA 3C 1F 37 30 30 4B 46' | = Sigma 12-24mm F4 DG HSM | A
> 'CA 48 27 3E 24 24 DF 4E' | = Tamron SP 15-30mm f/2.8 Di VC USD G2 (A041)
> 'CB 3C 2B 44 24 31 DF 46' | = Tamron 17-35mm f/2.8-4 Di OSD (A037)
> 'CC 44 68 98 34 41 DF 0E' | = Tamron 100-400mm f/4.5-6.3 Di VC USD
> 'CC 4C 50 68 14 14 4B 06' | = Sigma 50-100mm F1.8 DC HSM | A
> 'CD 3D 2D 70 2E 3C 4B 0E' | = Sigma 18-125mm F3.8-5.6 DC OS HSM
> 'CE 34 76 A0 38 40 4B 0E' | = Sigma 150-500mm F5-6.3 DG OS APO HSM
> 'CE 47 37 5C 25 25 DF 4E' | = Tamron SP 24-70mm f/2.8 Di VC USD G2 (A032)
> 'CF 38 6E 98 34 3C 4B 0E' | = Sigma APO 120-400mm F4.5-5.6 DG OS HSM
> 'CF 47 5C 8E 31 3D DF 0E' | = Tamron SP 70-300mm f/4-5.6 Di VC USD (A030)
> 'D2 3C 8E B0 3C 3C 4B 02' | = Sigma APO 300-800mm F5.6 EX DG HSM
> 'DB 40 11 11 2C 2C 1C 06' | = Sigma 8mm F3.5 EX DG Circular Fisheye
> 'DC 48 19 19 24 24 4B 06' | = Sigma 10mm F2.8 EX DC HSM Fisheye
> 'DE 54 50 50 0C 0C 4B 06' | = Sigma 50mm F1.4 EX DG HSM
> 'E0 3C 5C 8E 30 3C 4B 06' | = Sigma 70-300mm F4-5.6 APO DG Macro HSM
> 'E0 40 2D 98 2C 41 DF 4E' | = Tamron 18-400mm f/3.5-6.3 Di II VC HLD (B028)
> 'E1 40 19 36 2C 35 DF 4E' | = Tamron 10-24mm f/3.5-4.5 Di II VC HLD (B023)
> 'E1 58 37 37 14 14 1C 02' | = Sigma 24mm F1.8 EX DG Aspherical Macro
> 'E2 47 5C 80 24 24 DF 4E' | = Tamron SP 70-200mm f/2.8 Di VC USD G2 (A025)
> 'E3 40 76 A6 38 40 DF 0E' | = Tamron SP 150-600mm f/5-6.3 Di VC USD G2 (A022)
> 'E3 40 76 A6 38 40 DF 4E' | = Tamron SP 150-600mm f/5-6.3 Di VC USD G2
> 'E3 54 50 50 24 24 35 02' | = Sigma Macro 50mm F2.8 EX DG
> 'E4 54 64 64 24 24 DF 0E' | = Tamron SP 90mm f/2.8 Di VC USD Macro 1:1 (F017)
> 'E5 4C 62 62 14 14 C9 4E' | = Tamron SP 85mm f/1.8 Di VC USD (F016)
> 'E5 54 6A 6A 24 24 35 02' | = Sigma Macro 105mm F2.8 EX DG
> 'E6 40 2D 80 2C 40 DF 0E' | = Tamron 18-200mm f/3.5-6.3 Di II VC (B018)
> 'E6 41 3C 8E 2C 40 1C 02' | = Sigma 28-300mm F3.5-6.3 DG Macro
> 'E7 4C 4C 4C 14 14 DF 0E' | = Tamron SP 45mm f/1.8 Di VC USD (F013)
> 'E8 4C 44 44 14 14 DF 0E' | = Tamron SP 35mm f/1.8 Di VC USD (F012)
> 'E9 48 27 3E 24 24 DF 0E' | = Tamron SP 15-30mm f/2.8 Di VC USD (A012)
> 'E9 54 37 5C 24 24 1C 02' | = Sigma 24-70mm F2.8 EX DG Macro
> 'EA 40 29 8E 2C 40 DF 0E' | = Tamron 16-300mm f/3.5-6.3 Di II VC PZD (B016)
> 'EA 48 27 27 24 24 1C 02' | = Sigma 15mm F2.8 EX Diagonal Fisheye
> 'EB 40 76 A6 38 40 DF 0E' | = Tamron SP AF 150-600mm f/5-6.3 VC USD (A011)
> 'EC 3E 3C 8E 2C 40 DF 0E' | = Tamron 28-300mm f/3.5-6.3 Di VC PZD A010
> 'ED 40 2D 80 2C 40 4B 0E' | = Sigma 18-200mm F3.5-6.3 DC OS HSM
> 'EE 48 5C 80 24 24 4B 06' | = Sigma 70-200mm F2.8 EX APO DG Macro HSM II
> 'F0 38 1F 37 34 3C 4B 06' | = Sigma 12-24mm F4.5-5.6 EX DG Aspherical HSM
> 'F0 3F 2D 8A 2C 40 DF 0E' | = Tamron AF 18-270mm f/3.5-6.3 Di II VC PZD (B008)
> 'F1 44 A0 A0 34 34 4B 02' | = Sigma APO 500mm F4.5 EX DG HSM
> 'F1 47 5C 8E 30 3C DF 0E' | = Tamron SP 70-300mm f/4-5.6 Di VC USD (A005)
> 'F3 48 68 8E 30 30 4B 02' | = Sigma APO 100-300mm F4 EX IF HSM
> 'F3 54 2B 50 24 24 84 0E' | = Tamron SP AF 17-50mm f/2.8 XR Di II VC LD Aspherical (IF) (B005)
> 'F4 4C 7C 7C 2C 2C 4B 02' | = Sigma APO Macro 180mm F3.5 EX DG HSM
> 'F4 54 56 56 18 18 84 06' | = Tamron SP AF 60mm f/2.0 Di II Macro 1:1 (G005)
> 'F5 40 2C 8A 2C 40 40 0E' | = Tamron AF 18-270mm f/3.5-6.3 Di II VC LD Aspherical (IF) Macro (B003)
> 'F5 48 76 76 24 24 4B 06' | = Sigma APO Macro 150mm F2.8 EX DG HSM
> 'F6 3F 18 37 2C 34 84 06' | = Tamron SP AF 10-24mm f/3.5-4.5 Di II LD Aspherical (IF) (B001)
> 'F6 3F 18 37 2C 34 DF 06' | = Tamron SP AF 10-24mm f/3.5-4.5 Di II LD Aspherical (IF) (B001)
> 'F6 48 2D 50 24 24 4B 06' | = Sigma 18-50mm F2.8 EX DC Macro
> 'F7 53 5C 80 24 24 40 06' | = Tamron SP AF 70-200mm f/2.8 Di LD (IF) Macro (A001)
> 'F7 53 5C 80 24 24 84 06' | = Tamron SP AF 70-200mm f/2.8 Di LD (IF) Macro (A001)
> 'F8 54 3E 3E 0C 0C 4B 06' | = Sigma 30mm F1.4 EX DC HSM
> 'F8 54 64 64 24 24 DF 06' | = Tamron SP AF 90mm f/2.8 Di Macro 1:1 (272NII)
> 'F8 55 64 64 24 24 84 06' | = Tamron SP AF 90mm f/2.8 Di Macro 1:1 (272NII)
> 'F9 3C 19 31 30 3C 4B 06' | = Sigma 10-20mm F4-5.6 EX DC HSM
> 'F9 40 3C 8E 2C 40 40 0E' | = Tamron AF 28-300mm f/3.5-6.3 XR Di VC LD Aspherical (IF) Macro (A20)
> 'FA 54 3C 5E 24 24 84 06' | = Tamron SP AF 28-75mm f/2.8 XR Di LD Aspherical (IF) Macro (A09NII)
> 'FA 54 3C 5E 24 24 DF 06' | = Tamron SP AF 28-75mm f/2.8 XR Di LD Aspherical (IF) Macro (A09NII)
> 'FA 54 6E 8E 24 24 4B 02' | = Sigma APO 120-300mm F2.8 EX DG HSM
> 'FB 54 2B 50 24 24 84 06' | = Tamron SP AF 17-50mm f/2.8 XR Di II LD Aspherical (IF) (A16NII)
> 'FB 54 8E 8E 24 24 4B 02' | = Sigma APO 300mm F2.8 EX DG HSM
> 'FC 40 2D 80 2C 40 DF 06' | = Tamron AF 18-200mm f/3.5-6.3 XR Di II LD Aspherical (IF) Macro (A14NII)
> 'FD 00 44 44 18 18 DF 00' | = Voigtlander APO-Lanthar 35mm F2
> 'FD 00 48 48 07 07 DF 00' | = Voigtlander Nokton 40mm F1.2 Aspherical
> 'FD 00 50 50 18 18 DF 00' | = Voigtlander APO-Lanthar 50mm F2 Aspherical
> 'FD 00 59 59 18 18 DF 00' | = Voigtlander Macro APO-Lanthar 65mm F2
> 'FD 47 50 76 24 24 4B 06' | = Sigma 50-150mm F2.8 EX APO DC HSM II
> 'FE 47 00 00 24 24 4B 06' | = Sigma 4.5mm F2.8 EX DC HSM Circular Fisheye
> 'FE 48 37 5C 24 24 DF 0E' | = Tamron SP 24-70mm f/2.8 Di VC USD (A007)
> 'FE 53 5C 80 24 24 84 06' | = Tamron SP AF 70-200mm f/2.8 Di LD (IF) Macro (A001)
> 'FE 54 5C 80 24 24 DF 0E' | = Tamron SP 70-200mm f/2.8 Di VC USD (A009)
> 'FE 54 64 64 24 24 DF 0E' | = Tamron SP 90mm f/2.8 Di VC USD Macro 1:1 (F004)
> 'FF 40 2D 80 2C 40 4B 06' | = Sigma 18-200mm F3.5-6.3 DC

(This document generated automatically by Image::ExifTool::BuildTagLookup)
Last revised Apr 18, 2024

<-- ExifTool Tag Names